<?php

class AccountLevelInfo {
	private static $_nameList = null;

	private static function &_getNameList() {
		if(is_null(AccountLevelInfo::$_nameList)) {
			AccountLevelInfo::$_nameList = array();
			AccountLevelInfo::$_nameList['short'][1] = 'ADMIN';
			AccountLevelInfo::$_nameList['name'][1]  = '管理者';
			AccountLevelInfo::$_nameList['short'][2] = 'MANAGER';
			AccountLevelInfo::$_nameList['name'][2]  = 'サイト管理者';
		}
		return AccountLevelInfo::$_nameList;
	}

	/**
	 * 略称一覧取得
	 * @return array 略称一覧（キー：権限レベル/値：略称）
	 */
	static function &getShortNameList() {
		$list =& AccountLevelInfo::_getNameList();
		return $list['short'];
	}

	/**
	 * 略称取得
	 * @param $level [in] 権限レベル
	 * @return string 略称
	 */
	static function getShortName($level) {
		$list =& AccountLevelInfo::getShortNameList();

		if(array_key_exists(intval($level), $list)) {
			return $list[$level];
		} else {
			return '';
		}
	}

	/**
	 * 名称一覧取得
	 * @return array 略称一覧（キー：権限レベル/値：略称）
	 */
	static function &getNameList() {
		$list =& AccountLevelInfo::_getNameList();
		return $list['name'];
	}

	/**
	 * 名称取得
	 * @param $level [in] 権限レベル
	 * @return string 名称
	 */
	static function getName($level) {
		$list =& AccountLevelInfo::getNameList();

		if(array_key_exists(intval($level), $list)) {
			return $list[$level];
		} else {
			return '';
		}
	}
}

class AccountOutlineInfo {
	var $accountId = 0;
	var $dispName = '';
	var $authorityLevel = 0;
	var $domainTitle = '';	//表示用
}

class AccountInfo extends AccountOutlineInfo {
	var $userId = '';
	var $password = '';
	var $memo = '';
	var $domainId = 0;
	var $lastLoginDate = '';	//表示用
	var $registDateStr = '';	//表示用
	var $updateDateStr = '';	//表示用
	var $registUser = '';		//表示用
	var $updateUser = '';		//表示用

	function &check() {
		$returnVal = array();
		$account = new Account('');

		if(trim($this->dispName) === '') {
			$returnVal['dispName'] = Language::MSG_MANDATORY_ERROR;
		}

		if(AccountLevelInfo::getName($this->authorityLevel) === '') {
			$returnVal['authorityLevel'] = Language::MSG_UNKNOWN_AUTHORITY_LEVEL_ERROR;
		}

		if(trim($this->userId) === '') {
			$returnVal['userId'] = Language::MSG_MANDATORY_ERROR;
		} else if(preg_match("/^[!-~]*$/", $this->userId) === 0) {
			$returnVal['userId'] = Language::MSG_CHAR_FORMAT_ERROR;
		} else {
			if($this->accountId === 0 || $this->userId !== $account->getUserId($this->accountId)) {
				if($account->isUseUserId($this->userId, $this->domainId)) {
					$returnVal['userId'] = Language::MSG_ALREADY_USING_ERROR;
				}
			}
		}

		$passLen = strlen(trim($this->password));
		if(trim($this->password) === '') {
			$returnVal['password'] = Language::MSG_MANDATORY_ERROR;
		} else if(preg_match("/^[!-~]*$/", $this->password) === 0) {
			$returnVal['password'] = Language::MSG_CHAR_FORMAT_ERROR;
		} else if($passLen < 8 || $passLen > 16) {
			$returnVal['password'] = Language::MSG_PASSWORD_LENGTH_ERROR;
		}

		return $returnVal;
	}
}
?>