<?php
require_once 'xml_base.php';

class PlayerPlayListItem extends Element {

	public $dispNo = 0;
	public $fileUrl = '';
	public $fileTitle = '';
	public $fileThumbUrl = '';

	public $playerId = 0;
	public $playlistItemId = 0;

	function &getNode($dom, $isDemo) {

		$itemNode = $dom->appendChild($dom->createElement('Item'));
		$attribute = $itemNode->appendChild($dom->createAttribute('no'));
		$attribute->appendChild($dom->createTextNode($this->dispNo));
		if($this->fileUrl !== '') {
			$node = $itemNode->appendChild($dom->createElement('Path'));
			$node = $node->appendChild($dom->createTextNode($this->fileUrl));
		}
		if($this->fileTitle !== '') {
			$node = $itemNode->appendChild($dom->createElement('Title'));
			$node = $node->appendChild($dom->createTextNode($this->fileTitle));
		}
		if($this->fileThumbUrl !== '') {
			$node = $itemNode->appendChild($dom->createElement('ThumbUrl'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->fileThumbUrl, $isDemo)));
		}

		return $itemNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj['no'])) {
			$this->dispNo = intval($obj['no']);
		} else {
			return false;
		}
		if(isset($obj->Path)) {
			$this->fileUrl = (string)$obj->Path;
		}

		if(isset($obj->Title)) {
			$this->fileTitle = (string)$obj->Title;
		}

		if(isset($obj->ThumbUrl)) {
			$this->fileThumbUrl = (string)$obj->ThumbUrl;
		}

		return true;
	}

	function resetId() {
		$this->playerId = 0;
		$this->playlistItemId = 0;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();
		return $resultList;
	}
}

class PlayerElement extends Element {
	public $playerType = 0;
	public $xAxis = null;	//int
	public $yAxis = null;	//int
	public $width = null;	//int
	public $height = null;	//int

	public $fileUrl = '';
	public $fileTitle = '';
	public $fileThumbUrl = '';
	public $isAutoPlay = null;	//bool
	public $isAutoReplay = null;	//bool
	public $isDisplayMenu = null;	//bool
	public $menuPosition = null;	//int
	public $menuBgColor = null;	//str

	public $isDisplayEqualizer = null;	//bool
	public $equalizerBear = null;	//int
	public $equalizerFall = null;	//int

	public $outsideUrl = '';

	public $fileType = 1;				//int
	public $playlistPlayType = 1;		//int
	public $playlistStartNumber = null;	//int

	public $isDisplayPlayAndStopMenu = null;	//bool
	public $isDisplaySeekBarMenu     = null;	//bool
	public $isDisplayPlayTimeMenu    = null;	//bool
	public $isDisplayResizeMenu      = null;	//bool
	public $isDisplaySoundMenu       = null;	//bool

	public $playlistItemList = array();

	public $itemId = 0;	//所属先ItemId
	public $domainId = 0;	//取得時のみ
	public $parentType = 0;

	function &getNode($dom, $isDemo) {
		$playerNode = $dom->appendChild($dom->createElement('Player'));

		$node = $playerNode->appendChild($dom->createElement('Display'));
		$str = Element::getStrFromList(PlayerElement::getPlayerTypeStrList(), $this->playerType);
		if($str === '') {
			$node = $node->appendChild($dom->createTextNode('no'));
			return $playerNode;
		} else {
			$node = $node->appendChild($dom->createTextNode($str));
		}

		$propertyNode = $playerNode->appendChild($dom->createElement('Property'));
		if(isset($this->xAxis)) {
			$node = $propertyNode->appendChild($dom->createElement('PosX', $this->xAxis));
		}
		if(isset($this->yAxis)) {
			$node = $propertyNode->appendChild($dom->createElement('PosY', $this->yAxis));
		}
		if(isset($this->width)) {
			$node = $propertyNode->appendChild($dom->createElement('Width', $this->width));
		}
		if(isset($this->height)) {
			$node = $propertyNode->appendChild($dom->createElement('Height', $this->height));
		}

		if($this->playerType === 1) {
			$flagPlayerNode = $playerNode->appendChild($dom->createElement('FLagPlayer'));

			if($this->fileType === 1) {
				$fileNode = $flagPlayerNode->appendChild($dom->createElement('File'));
				if($this->fileUrl !== '') {
					$node = $fileNode->appendChild($dom->createElement('Path'));
					$node = $node->appendChild($dom->createTextNode($this->fileUrl));
				}
				if($this->fileTitle !== '') {
					$node = $fileNode->appendChild($dom->createElement('Title'));
					$node = $node->appendChild($dom->createTextNode($this->fileTitle));
				}
				if($this->fileThumbUrl !== '') {
					$node = $fileNode->appendChild($dom->createElement('ThumbUrl'));
					$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->fileThumbUrl, $isDemo)));
				}
			} else if($this->fileType === 2) {
				$playListNode = $flagPlayerNode->appendChild($dom->createElement('PlayList'));
				$str = Element::getStrFromList(PlayerElement::getPlayTypeStr(), $this->playlistPlayType);
				if($str !== '') {
					$node = $playListNode->appendChild($dom->createElement('PlayType'));
					$node = $node->appendChild($dom->createTextNode($str));
				}

				if(isset($this->playlistStartNumber )) {
					$node = $playListNode->appendChild($dom->createElement('Select', $this->playlistStartNumber));
				}

				foreach($this->playlistItemList as $element) {
					$node = $playListNode->appendChild($element->getNode($dom, $isDemo));
				}
			}

			$propertyNode = $flagPlayerNode->appendChild($dom->createElement('Property'));

			$str = Element::getStrFromList(PlayerElement::getFileTypeStr(), $this->fileType);
			if($str !== '') {
				$node = $propertyNode->appendChild($dom->createElement('SelectType'));
				$node = $node->appendChild($dom->createTextNode($str));
			}

			if(isset($this->isAutoPlay)) {
				$node = $propertyNode->appendChild($dom->createElement('AutoPlay', Element::getBoolStr($this->isAutoPlay)));
			}
			if(isset($this->isAutoReplay)) {
				$node = $propertyNode->appendChild($dom->createElement('AutoReplay', Element::getBoolStr($this->isAutoReplay)));
			}

			$menuNode = $propertyNode->appendChild($dom->createElement('Menu'));
			if(isset($this->isDisplayMenu)) {
				$node = $menuNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->isDisplayMenu)));

				if($this->isDisplayMenu) {
					$menuItemDispNode = $menuNode->appendChild($dom->createElement('ItemDisplay'));
					if(isset($this->isDisplayPlayAndStopMenu)) {
						$node = $menuItemDispNode->appendChild($dom->createElement('PlayAndStop', Element::getBoolStr($this->isDisplayPlayAndStopMenu)));
					}
					if(isset($this->isDisplaySeekBarMenu)) {
						$node = $menuItemDispNode->appendChild($dom->createElement('SeekBar', Element::getBoolStr($this->isDisplaySeekBarMenu)));
					}
					if(isset($this->isDisplayPlayTimeMenu)) {
						$node = $menuItemDispNode->appendChild($dom->createElement('PlayTime', Element::getBoolStr($this->isDisplayPlayTimeMenu)));
					}
					if(isset($this->isDisplayResizeMenu)) {
						$node = $menuItemDispNode->appendChild($dom->createElement('ReSize', Element::getBoolStr($this->isDisplayResizeMenu)));
					}
					if(isset($this->isDisplaySoundMenu)) {
						$node = $menuItemDispNode->appendChild($dom->createElement('Sound', Element::getBoolStr($this->isDisplaySoundMenu)));
					}
				}
			}
			if(isset($this->menuPosition)) {
				$str = Element::getStrFromList(PlayerElement::getMenuPosStrList(), $this->menuPosition);
				if($str !== '') {
					$node = $menuNode->appendChild($dom->createElement('DisplayType'));
					$node = $node->appendChild($dom->createTextNode($str));
				}
			}
			if($this->menuBgColor !== '') {
				$node = $menuNode->appendChild($dom->createElement('Color', $this->menuBgColor));
			}

			$equalizerNode = $propertyNode->appendChild($dom->createElement('Equalize'));
			if(isset($this->isDisplayEqualizer)) {
				$node = $equalizerNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->isDisplayEqualizer)));
				if($this->isDisplayEqualizer) {
					$node = $equalizerNode->appendChild($dom->createElement('Beat', $this->equalizerBear));
					$node = $equalizerNode->appendChild($dom->createElement('Fall', $this->equalizerFall));
				}
			}

		} else if($this->playerType === 2) {
			$outsideNode = $playerNode->appendChild($dom->createElement('Youtube'));
			$node = $outsideNode->appendChild($dom->createElement('Url'));
			$node = $node->appendChild($dom->createTextNode($this->outsideUrl));

		}

		return $playerNode;
	}

	function setDataFromXmlObj($obj) {

		if(isset($obj->Display)) {
			$this->playerType = Element::getIdFromList(PlayerElement::getPlayerTypeStrList(), (string)$obj->Display);
		}

		if(isset($obj->Property->PosX)) {
			$this->xAxis = intval($obj->Property->PosX);
		}

		if(isset($obj->Property->PosY)) {
			$this->yAxis = intval($obj->Property->PosY);
		}

		if(isset($obj->Property->Width)) {
			$this->width = intval($obj->Property->Width);
		}

		if(isset($obj->Property->Height)) {
			$this->height = intval($obj->Property->Height);
		}

		if(isset($obj->FLagPlayer->File->Path)) {
			$this->fileUrl = (string)$obj->FLagPlayer->File->Path;
		}

		if(isset($obj->FLagPlayer->File->Title)) {
			$this->fileTitle = (string)$obj->FLagPlayer->File->Title;
		}

		if(isset($obj->FLagPlayer->File->ThumbUrl)) {
			$this->fileThumbUrl = (string)$obj->FLagPlayer->File->ThumbUrl;
		}

		if(isset($obj->FLagPlayer->PlayList->PlayType)) {
			$this->playlistPlayType = Element::getIdFromList(PlayerElement::getPlayTypeStr(), (string)$obj->FLagPlayer->PlayList->PlayType);
		}

		if(isset($obj->FLagPlayer->PlayList->Select)) {
			$this->playlistStartNumber = intval($obj->FLagPlayer->PlayList->Select);
		}

		if(isset($obj->FLagPlayer->PlayList->Item)) {
			foreach($obj->FLagPlayer->PlayList->Item as $itemObj) {
				$element = new PlayerPlayListItem();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->playlistItemList[] = $element;
				} else {
					return false;
				}
			}
		}

		if(isset($obj->FLagPlayer->Property->SelectType)) {
			$this->fileType =Element::getIdFromList(PlayerElement::getFileTypeStr(), (string)$obj->FLagPlayer->Property->SelectType);
		}

		if(isset($obj->FLagPlayer->Property->AutoPlay)) {
			$this->isAutoPlay = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->AutoPlay);
		}

		if(isset($obj->FLagPlayer->Property->AutoReplay)) {
			$this->isAutoReplay = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->AutoReplay);
		}

		if(isset($obj->FLagPlayer->Property->Menu->Display)) {
			$this->isDisplayMenu = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Menu->Display);
		}

		if(isset($obj->FLagPlayer->Property->Menu->DisplayType)) {
			$this->menuPosition = Element::getIdFromList(PlayerElement::getMenuPosStrList(), (string)$obj->FLagPlayer->Property->Menu->DisplayType);
		}

		if(isset($obj->FLagPlayer->Property->Menu->Color) && Element::checkColorFormat((string)$obj->FLagPlayer->Property->Menu->Color)) {
			$this->menuBgColor = (string)$obj->FLagPlayer->Property->Menu->Color;
		}

		if(isset($obj->FLagPlayer->Property->Menu->ItemDisplay->PlayAndStop)) {
			$this->isDisplayPlayAndStopMenu = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Menu->ItemDisplay->PlayAndStop);
		}

		if(isset($obj->FLagPlayer->Property->Menu->ItemDisplay->SeekBar)) {
			$this->isDisplaySeekBarMenu = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Menu->ItemDisplay->SeekBar);
		}

		if(isset($obj->FLagPlayer->Property->Menu->ItemDisplay->PlayTime)) {
			$this->isDisplayPlayTimeMenu = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Menu->ItemDisplay->PlayTime);
		}

		if(isset($obj->FLagPlayer->Property->Menu->ItemDisplay->ReSize)) {
			$this->isDisplayResizeMenu = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Menu->ItemDisplay->ReSize);
		}

		if(isset($obj->FLagPlayer->Property->Menu->ItemDisplay->Sound)) {
			$this->isDisplaySoundMenu = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Menu->ItemDisplay->Sound);
		}

		if(isset($obj->FLagPlayer->Property->Equalize->Display)) {
			$this->isDisplayEqualizer = Element::getBoolFromStr((string)$obj->FLagPlayer->Property->Equalize->Display);
		}

		if(isset($obj->FLagPlayer->Property->Equalize->Beat)) {
			$this->equalizerBear = intval($obj->FLagPlayer->Property->Equalize->Beat);
		}

		if(isset($obj->FLagPlayer->Property->Equalize->Fall)) {
			$this->equalizerFall = intval($obj->FLagPlayer->Property->Equalize->Fall);
		}

		if(isset($obj->Youtube->Url)) {
			$this->outsideUrl = (string)$obj->Youtube->Url;
		}

		return true;
	}

	function resetId() {
		$this->itemId = 0;

		foreach($this->playlistItemList as $element) {
			$element->resetId();
		}
	}


	/**
	 * プレイヤー種別文字列一覧取得
	 * @return array プレイヤー種別文字列一覧(キー:ID/値:文字列)
	 */
	static function &getPlayerTypeStrList() {
		$list = array();
		$list[1] = 'flv';
		$list[2] = 'youtube';

		return $list;
	}

	/**
	 * メニュー位置文字列一覧取得
	 * @return array メニュー位置文字列一覧(キー:ID/値:文字列)
	 */
	static function getMenuPosStrList() {
		$list = array();
		$list[1] = 'upper';
		$list[2] = 'under';

		return $list;

	}

	/**
	 * FlagPlayer再生ファイル種別
	 * @return  array 再生ファイル種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getFileTypeStr() {
		$list = array();
		$list[1] = 'single';	//1ファイル
		$list[2] = 'list';		//PlayList

		return $list;
	}

	/**
	 * プレイリスト再生方法種別
	 * @return  array プレイリスト再生方法種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getPlayTypeStr() {
		$list = array();
		$list[1] = 'random';
		$list[2] = 'sequence';

		return $list;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if(is_null($this->xAxis) || $this->xAxis === '') {
			$this->xAxis = null;
		} else if(!is_numeric($this->xAxis)) {
			$resultList['xAxis'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->xAxis = intval($this->xAxis);
		}

		if(is_null($this->yAxis) || $this->yAxis === '') {
			$this->yAxis = null;
		} else if(!is_numeric($this->yAxis)) {
			$resultList['yAxis'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->yAxis = intval($this->yAxis);
		}

		if(is_null($this->width) || $this->width === '') {
			$this->width = null;
		} else if(!is_numeric($this->width)) {
			$resultList['width'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->width = intval($this->width);
		}

		if(is_null($this->height) || $this->height === '') {
			$this->height = null;
		} else if(!is_numeric($this->height)) {
			$resultList['height'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->height = intval($this->height);
		}


		if(is_null($this->menuBgColor) || $this->menuBgColor === '') {
			$this->menuBgColor = null;
		} else if(!Element::checkColorFormat($this->menuBgColor)) {
			$resultList['menuBgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if(is_null($this->equalizerBear) || $this->equalizerBear === '') {
			$this->equalizerBear = null;
		} else if(!is_numeric($this->equalizerBear)) {
			$resultList['equalizerBear'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->equalizerBear = intval($this->equalizerBear);
		}

		if(is_null($this->equalizerFall) || $this->equalizerFall === '') {
			$this->equalizerFall = null;
		} else if(!is_numeric($this->equalizerFall)) {
			$resultList['equalizerFall'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->equalizerFall = intval($this->equalizerFall);
		}

		return $resultList;
	}
}

class NewsItemElement extends Element {

	public $itemId = 0;

	public $dispNo = 0;
	public $title ='';
	public $url = '';
	public $urlTarget = 0;

	function &getNode($dom, $isDemo) {
		$itemNode = $dom->appendChild($dom->createElement('Item'));
		$attribute = $itemNode->appendChild($dom->createAttribute('no'));
		$attribute->appendChild($dom->createTextNode($this->dispNo));

		if($this->title !== '') {
			$node = $itemNode->appendChild($dom->createElement('Title'));
			$node = $node->appendChild($dom->createTextNode($this->title));
		}
		if($this->url !== '') {
			$node = $itemNode->appendChild($dom->createElement('Url'));
			$node = $node->appendChild($dom->createTextNode($this->url));
		}
		$str = Element::getStrFromList(NewsItemElement::getUrlTargetStrList(), $this->urlTarget);
		if($str !== '') {
			$node = $itemNode->appendChild($dom->createElement('Target'));
			$node = $node->appendChild($dom->createTextNode($str));
		}

		return $itemNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj['no'])) {
			$this->dispNo = intval($obj['no']);
		} else {
			return false;
		}
		if(isset($obj->Title)) {
			$this->title = (string)$obj->Title;
		}
		if(isset($obj->Url)) {
			$this->url = (string)$obj->Url;
		}
		if(isset($obj->Target)) {
			$this->urlTarget = Element::getIdFromList(NewsItemElement::getUrlTargetStrList(), (string)$obj->Target);
		}

		return true;
	}

	function resetId() {
		$this->itemId = 0;
	}

	/**
	 * 表示先種別文字列一覧取得
	 * @return array 表示先種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getUrlTargetStrList() {
		$list = array();
		$list[1] = 'new';
		$list[2] = 'self';

		return $list;

	}
}

class NewsSkinElement extends Element {
	public $mainIsDisplayGradation = false;
	public $mainGradationAlpha = 100;
	public $mainBgColor = '';
	public $mainBgAlpha = 100;
	public $innerIsDisplayGradation = false;
	public $innerGradationAlpha = 100;
	public $innerBgColor = '';
	public $innerBgAlpha = 100;

	function &getNode($dom, $isDemo) {
		$skinNode = $dom->appendChild($dom->createElement('Skin'));
		$boxNode = $skinNode->appendChild($dom->createElement('MainBox'));
		$gradationNode = $boxNode->appendChild($dom->createElement('Gradation'));
		$node = $gradationNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->mainIsDisplayGradation)));
		$node = $gradationNode->appendChild($dom->createElement('Alpha', $this->mainGradationAlpha));
		$bgNode = $boxNode->appendChild($dom->createElement('Mat'));
		if($this->mainBgColor !== '') {
			$node = $bgNode->appendChild($dom->createElement('Color', $this->mainBgColor));
		}
		$node = $bgNode->appendChild($dom->createElement('Alpha', $this->mainBgAlpha));

		$boxNode = $skinNode->appendChild($dom->createElement('InnerBox'));
		$gradationNode = $boxNode->appendChild($dom->createElement('Gradation'));
		$node = $gradationNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->innerIsDisplayGradation)));
		$node = $gradationNode->appendChild($dom->createElement('Alpha', $this->innerGradationAlpha));
		$bgNode = $boxNode->appendChild($dom->createElement('Mat'));
		if($this->innerBgColor !== '') {
			$node = $bgNode->appendChild($dom->createElement('Color', $this->innerBgColor));
		}
		$node = $bgNode->appendChild($dom->createElement('Alpha', $this->innerBgAlpha));


		return $skinNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj->MainBox->Gradation->Display)) {
			$this->mainIsDisplayGradation = Element::getBoolFromStr((string)$obj->MainBox->Gradation->Display);
		}

		if(isset($obj->MainBox->Gradation->Alpha)) {
			$this->mainGradationAlpha = intval($obj->MainBox->Gradation->Alpha);
		}

		if(isset($obj->MainBox->Mat->Color) && Element::checkColorFormat((string)$obj->MainBox->Mat->Color)) {
			$this->mainBgColor = (string)$obj->MainBox->Mat->Color;
		}

		if(isset($obj->MainBox->Mat->Alpha)) {
			$this->mainBgAlpha = intval($obj->MainBox->Mat->Alpha);
		}

		if(isset($obj->InnerBox->Gradation->Display)) {
			$this->innerIsDisplayGradation = Element::getBoolFromStr((string)$obj->InnerBox->Gradation->Display);
		}

		if(isset($obj->InnerBox->Gradation->Alpha)) {
			$this->innerGradationAlpha = intval($obj->InnerBox->Gradation->Alpha);
		}

		if(isset($obj->InnerBox->Mat->Color) && Element::checkColorFormat((string)$obj->InnerBox->Mat->Color)) {
			$this->innerBgColor = (string)$obj->InnerBox->Mat->Color;
		}

		if(isset($obj->InnerBox->Mat->Alpha)) {
			$this->innerBgAlpha = intval($obj->InnerBox->Mat->Alpha);
		}

		return true;
	}

	function resetId() {
		//処理なし
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if($this->mainGradationAlpha !== '' && !Element::checkAlphaFormat($this->mainGradationAlpha)) {
			$resultList['mainGradationAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->mainGradationAlpha = intval($this->mainGradationAlpha);
		}

		if($this->mainBgColor !== '' && !Element::checkColorFormat($this->mainBgColor)) {
			$resultList['mainBgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->mainBgAlpha !== '' && !Element::checkAlphaFormat($this->mainBgAlpha)) {
			$resultList['mainBgAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->mainBgAlpha = intval($this->mainBgAlpha);
		}

		if($this->innerGradationAlpha !== '' && !Element::checkAlphaFormat($this->innerGradationAlpha)) {
			$resultList['innerGradationAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->innerGradationAlpha = intval($this->innerGradationAlpha);
		}

		if($this->innerBgColor !== '' && !Element::checkColorFormat($this->innerBgColor)) {
			$resultList['innerBgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->innerBgAlpha !== '' && !Element::checkAlphaFormat($this->innerBgAlpha)) {
			$resultList['innerBgAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->innerBgAlpha = intval($this->innerBgAlpha);
		}

		return $resultList;

	}
}

class NewsElement extends Element {
	public $isDisplay = false;
	public $displayType = 0;
	public $textDisplaytType = 0;
	public $slideWaitTime = 1000;
	public $scrollMovePixel = 1;

	public $xAxis = 0;
	public $yAxis = 0;
	public $width = 20;
	public $height = 200;
	public $padding = 0;
	public $textColor = '';
	public $textShadowColor = '';

	public $skinElement = null;
	public $itemElementList = array();

	public $domainId = 0;	//取得時用

	function &getNode($dom, $isDemo) {
		$newsNode = $dom->appendChild($dom->createElement('NEWS'));
		$node = $newsNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->isDisplay)));

		if($this->isDisplay) {
			$propertyNode = $newsNode->appendChild($dom->createElement('Property'));

			$str = Element::getStrFromList(NewsElement::getDisplayTypeStrList(), $this->displayType);
			if($str !== '') {
				$node = $propertyNode->appendChild($dom->createElement('DisplayType'));
				$node = $node->appendChild($dom->createTextNode($str));
			}
			$str = Element::getStrFromList(NewsElement::getTextDisplayTypeStrList(), $this->textDisplaytType);
			if($str !== '') {
				$node = $propertyNode->appendChild($dom->createElement('Operation'));
				$node = $node->appendChild($dom->createTextNode($str));
			}
			$node = $propertyNode->appendChild($dom->createElement('WaitTime', $this->slideWaitTime));
			$node = $propertyNode->appendChild($dom->createElement('MovePixel', $this->scrollMovePixel));
			$node = $propertyNode->appendChild($dom->createElement('PosX', $this->xAxis));
			$node = $propertyNode->appendChild($dom->createElement('PosY', $this->yAxis));
			$node = $propertyNode->appendChild($dom->createElement('Width', $this->width));
			$node = $propertyNode->appendChild($dom->createElement('Height', $this->height));
			$node = $propertyNode->appendChild($dom->createElement('Blank', $this->padding));
			if($this->textColor !== '') {
				$node = $propertyNode->appendChild($dom->createElement('TextColor', $this->textColor));
			}
			if($this->textShadowColor !== '') {
				$node = $propertyNode->appendChild($dom->createElement('TextShadowColor', $this->textShadowColor));
			}

			if(!is_null($this->skinElement)) {
				$node = $propertyNode->appendChild($this->skinElement->getNode($dom, $isDemo));
			}

			foreach($this->itemElementList as $element) {
				$node = $newsNode->appendChild($element->getNode($dom, $isDemo));
			}
		}

		return $newsNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj->Display)) {
			$this->isDisplay = Element::getBoolFromStr((string)$obj->Display);
		}

		if(isset($obj->Property->DisplayType)) {
			$this->displayType = Element::getIdFromList(NewsElement::getDisplayTypeStrList(), (string)$obj->Property->DisplayType);
		}

		if(isset($obj->Property->Operation)) {
			$this->textDisplaytType = Element::getIdFromList(NewsElement::getTextDisplayTypeStrList(), (string)$obj->Property->Operation);
		}

		if(isset($obj->Property->WaitTime)) {
			$this->slideWaitTime = intval($obj->Property->WaitTime);
		}

		if(isset($obj->Property->MovePixel)) {
			$this->scrollMovePixel = floatval($obj->Property->MovePixel);
		}

		if(isset($obj->Property->PosX)) {
			$this->xAxis = intval($obj->Property->PosX);
		}

		if(isset($obj->Property->PosY)) {
			$this->yAxis = intval($obj->Property->PosY);
		}

		if(isset($obj->Property->Width)) {
			$this->width = intval($obj->Property->Width);
		}

		if(isset($obj->Property->Height)) {
			$this->height = intval($obj->Property->Height);
		}

		if(isset($obj->Property->Blank)) {
			$this->padding = intval($obj->Property->Blank);
		}

		if(isset($obj->Property->TextColor) && Element::checkColorFormat((string)$obj->Property->TextColor)) {
			$this->textColor = (string)$obj->Property->TextColor;
		}

		if(isset($obj->Property->TextShadowColor) && Element::checkColorFormat((string)$obj->Property->TextShadowColor)) {
			$this->textShadowColor = (string)$obj->Property->TextShadowColor;
		}

		if(isset($obj->Property->Skin)) {
			$element = new NewsSkinElement();
			if($element->setDataFromXmlObj($obj->Property->Skin)) {
				$this->skinElement = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->Item)) {
			foreach($obj->Item as $itemObj) {
				$element = new NewsItemElement();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->itemElementList[] = $element;
				} else {
					return false;
				}
			}
		}

		return true;
	}


	function resetId() {
		if(!is_null($this->skinElement)) {
			$this->skinElement->resetId();
		}
		foreach($this->itemElementList as $element) {
			$element->resetId();
		}
	}

	/**
	 * 表示種別文字列一覧取得
	 * @return array 表示種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getDisplayTypeStrList() {
		$list = array();
		$list[1] = 'upper';
		$list[2] = 'under';
		$list[3] = 'myself';

		return $list;

	}

	/**
	 * テキスト表示種別文字列一覧取得
	 * @return array テキスト表示種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getTextDisplayTypeStrList() {
		$list = array();
		$list[1] = 'scroll';
		$list[2] = 'slide';

		return $list;

	}


	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if($this->xAxis !== '' && !is_numeric($this->xAxis)) {
			$resultList['xAxis'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->xAxis = intval($this->xAxis);
		}

		if($this->yAxis !== '' && !is_numeric($this->yAxis)) {
			$resultList['yAxis'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->yAxis = intval($this->yAxis);
		}

		if($this->width !== '' && !is_numeric($this->width)) {
			$resultList['width'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->width = intval($this->width);
		}

		if($this->height !== '' && !is_numeric($this->height)) {
			$resultList['height'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->height = intval($this->height);
		}

		if($this->scrollMovePixel !== '' && !is_numeric($this->scrollMovePixel)) {
			$resultList['scrollMovePixel'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->scrollMovePixel = floatval($this->scrollMovePixel);
		}

		if($this->slideWaitTime !== '' && !is_numeric($this->slideWaitTime)) {
			$resultList['slideWaitTime'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->slideWaitTime = intval($this->slideWaitTime);
		}

		if($this->textColor !== '' && !Element::checkColorFormat($this->textColor)) {
			$resultList['textColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->textShadowColor !== '' && !Element::checkColorFormat($this->textShadowColor)) {
			$resultList['textShadowColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}
		return $resultList;

	}
}

class ItemButtonElement extends Element {

	public $width = 0;
	public $height = 0;
	public $rolloverImage = '';
	public $rolloverColor = '';
	public $rolloverAlpha = 100;
	public $rolloutColor = '';
	public $rolloutAlpha = 100;

	public $bgImage = '';

	public $linkUrl = '';
	public $linkUrlTarget = 0;

	public $playerElement = null;
	public $itemElementList = array();


	public $itemId = 0; //所属ItemId

	function &getNode($dom, $isDemo) {
		$buttonNode = $dom->appendChild($dom->createElement('Button'));

		$propertyNode = $buttonNode->appendChild($dom->createElement('Property'));
		$node = $propertyNode->appendChild($dom->createElement('Width', $this->width));
		$node = $propertyNode->appendChild($dom->createElement('Height', $this->height));

		$rollNode = $propertyNode->appendChild($dom->createElement('RollOver'));
		if($this->rolloverImage !== '') {
			$node = $rollNode->appendChild($dom->createElement('Image'));
			$node = $node->appendChild($dom->createElement('Url'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->rolloverImage, $isDemo)));
		}
		if($this->rolloverColor !== '') {
			$node = $rollNode->appendChild($dom->createElement('Color', $this->rolloverColor));
		}
		$node = $rollNode->appendChild($dom->createElement('Alpha', $this->rolloverAlpha));

		$rollNode = $propertyNode->appendChild($dom->createElement('RollOut'));
		if($this->rolloutColor !== '') {
			$node = $rollNode->appendChild($dom->createElement('Color', $this->rolloutColor));
		}
		$node = $rollNode->appendChild($dom->createElement('Alpha', $this->rolloutAlpha));


		$actionNode = $buttonNode->appendChild($dom->createElement('Action'));

		if($this->bgImage !== '') {
			$node = $actionNode->appendChild($dom->createElement('BgImage'));
			$node = $node->appendChild($dom->createElement('Url'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->bgImage, $isDemo)));
		}

		if($this->linkUrl !== '') {
			$linkNode = $actionNode->appendChild($dom->createElement('Link'));
			if($this->linkUrl !== '') {
				$node = $linkNode->appendChild($dom->createElement('Url'));
				$node = $node->appendChild($dom->createTextNode($this->linkUrl));
			}

			$str = Element::getStrFromList(ItemButtonElement::getLinkTargetStrList(), $this->linkUrlTarget);
			if($str !== '') {
				$node = $linkNode->appendChild($dom->createElement('Target'));
				$node = $node->appendChild($dom->createTextNode($str));
			}
		}

		if(!is_null($this->playerElement)) {
			$node = $actionNode->appendChild($this->playerElement->getNode($dom, $isDemo));
		}

		if(count($this->itemElementList) > 0) {
			$itemChangeNode = $actionNode->appendChild($dom->createElement('ItemChange'));
			foreach($this->itemElementList as $itemElement) {
				$node = $itemChangeNode->appendChild($itemElement->getNode($dom, $isDemo));
			}
		}

		return $buttonNode;
	}

	function setDataFromXmlObj($obj) {

		if(isset($obj->Property->Width)) {
			$this->width = intval($obj->Property->Width);
		}

		if(isset($obj->Property->Height)) {
			$this->height = intval($obj->Property->Height);
		}

		if(isset($obj->Property->RollOver->Image->Url)) {
			$this->rolloverImage = (string)$obj->Property->RollOver->Image->Url;
		}

		if(isset($obj->Property->RollOver->Color) && Element::checkColorFormat((string)$obj->Property->RollOver->Color)) {
			$this->rolloverColor = (string)$obj->Property->RollOver->Color;
		}

		if(isset($obj->Property->RollOver->Alpha)) {
			$this->rolloverAlpha = intval($obj->Property->RollOver->Alpha);
		}

		if(isset($obj->Property->RollOut->Color) && Element::checkColorFormat((string)$obj->Property->RollOut->Color)) {
			$this->rolloutColor = (string)$obj->Property->RollOut->Color;
		}

		if(isset($obj->Property->RollOut->Alpha)) {
			$this->rolloutAlpha = intval($obj->Property->RollOut->Alpha);
		}

		if(isset($obj->Action->BgImage->Url)) {
			$this->bgImage = (string)$obj->Action->BgImage->Url;
		}

		if(isset($obj->Action->Link->Url)) {
			$this->linkUrl = (string)$obj->Action->Link->Url;
		}

		if(isset($obj->Action->Link->Target)) {
			$this->linkUrlTarget = Element::getIdFromList(ItemButtonElement::getLinkTargetStrList(), (string)$obj->Action->Link->Target);
		}

		if(isset($obj->Action->Player)) {
			$element = new PlayerElement();
			if($element->setDataFromXmlObj($obj->Action->Player)) {
				$this->playerElement = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->Action->ItemChange->Item)) {
			foreach($obj->Action->ItemChange->Item as $itemObj) {
				$element = new ItemElement();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->itemElementList[] = $element;
				} else {
					return false;
				}
			}
		}

		return true;
	}

	function resetId() {
		$this->itemId = 0;
		if(!is_null($this->playerElement)) {
			$this->playerElement->resetId();
		}

		if(count($this->itemElementList) > 0) {
			foreach($this->itemElementList as $itemElement) {
				$itemElement->resetId();
			}
		}
	}

	/**
	 * リンク表示先種別文字列一覧取得
	 * @return array リンク表示先種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getLinkTargetStrList() {
		$list = array();
		$list[1] = 'new';
		$list[2] = 'self';

		return $list;

	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if($this->width !== '' && !is_numeric($this->width)) {
			$resultList['width'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->width = intval($this->width);
		}

		if($this->height !== '' && !is_numeric($this->height)) {
			$resultList['height'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->height = intval($this->height);
		}

		if($this->rolloverColor !== '' && !Element::checkColorFormat($this->rolloverColor)) {
			$resultList['rolloverColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->rolloutColor !== '' && !Element::checkColorFormat($this->rolloutColor)) {
			$resultList['rolloutColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->rolloverAlpha !== '' && !Element::checkAlphaFormat($this->rolloverAlpha)) {
			$resultList['rolloverAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->rolloverAlpha = intval($this->rolloverAlpha);
		}

		if($this->rolloutAlpha !== '' && !Element::checkAlphaFormat($this->rolloutAlpha)) {
			$resultList['rolloutAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->rolloutAlpha = intval($this->rolloutAlpha);
		}

		return $resultList;

	}
}

class ItemPlayListItem extends Element {

	public $dispNo = 0;
	public $name = '';
	public $image = '';
	public $linkUrl = '';
	public $linkUrlTarget = 1;

	public $itemId = 0;
	public $playlistItemId = 0;

	function &getNode($dom, $isDemo) {
		$itemNode = $dom->appendChild($dom->createElement('Item'));
		$attribute = $itemNode->appendChild($dom->createAttribute('no'));
		$attribute->appendChild($dom->createTextNode($this->dispNo));
		if($this->name !== '') {
			$node = $itemNode->appendChild($dom->createElement('HiddenName'));
			$node = $node->appendChild($dom->createTextNode($this->name));
		}
		if($this->image !== '') {
			$node = $itemNode->appendChild($dom->createElement('ImageUrl'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->image, $isDemo)));
		}
		if($this->linkUrl !== '') {
			$node = $itemNode->appendChild($dom->createElement('LinkUrl'));
			$node = $node->appendChild($dom->createTextNode($this->linkUrl));
		}
		$str = Element::getStrFromList(ItemPlayListItem::getUrlTargetStrList(), $this->linkUrlTarget);
		if($str !== '') {
			$node = $itemNode->appendChild($dom->createElement('LinkTarget'));
			$node = $node->appendChild($dom->createTextNode($this->linkUrlTarget));
		}

		return $itemNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj['no'])) {
			$this->dispNo = intval($obj['no']);
		} else {
			return false;
		}

		if(isset($obj->HiddenName)) {
			$this->name = (string)$obj->HiddenName;
		}

		if(isset($obj->ImageUrl)) {
			$this->image = (string)$obj->ImageUrl;
		}

		if(isset($obj->LinkUrl)) {
			$this->linkUrl = (string)$obj->LinkUrl;
		}

		if(isset($obj->LinkTarget)) {
			$this->linkUrlTarget = Element::getIdFromList(ItemPlayListItem::getUrlTargetStrList(), (string)$obj->LinkTarget);
		}

		return true;
	}

	function resetId() {
		$this->itemId = 0;
		$this->playlistItemId = 0;
	}

	/**
	 * 表示先種別文字列一覧取得
	 * @return array 表示先種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getUrlTargetStrList() {
		$list = array();
		$list[1] = 'new';
		$list[2] = 'self';

		return $list;

	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();
		return $resultList;
	}

}

class ItemWipeElement extends Element {
	public $type = 1;
	public $widthDivideNumber = 1;
	public $heightDivideNumber = 1;
	public $widthIsMagnified = false;
	public $heightIsMagnified = false;
	public $displayDirection = 1;
	public $speed = 10;
	public $diagonalType = 1;

	public $itemId = 0;

	function &getNode($dom, $isDemo) {
		$wipeNode = $dom->appendChild($dom->createElement('WipeEffect'));

		$str = Element::getStrFromList(ItemWipeElement::getTypeStrList(), $this->type);
		if($str !== '') {
			$node = $wipeNode->appendChild($dom->createElement('Type'));
			$node = $node->appendChild($dom->createTextNode($str));
		}
		$node = $wipeNode->appendChild($dom->createElement('WidthNumber', $this->widthDivideNumber));
		$node = $wipeNode->appendChild($dom->createElement('HeightNumber', $this->heightDivideNumber));
		$node = $wipeNode->appendChild($dom->createElement('WidthScale', Element::getBoolStr($this->widthIsMagnified)));
		$node = $wipeNode->appendChild($dom->createElement('HeightScale', Element::getBoolStr($this->heightIsMagnified )));
		$str = Element::getStrFromList(ItemWipeElement::getDisplayDirectionStrList(), $this->displayDirection);
		if($str !== '') {
			$node = $wipeNode->appendChild($dom->createElement('Revers'));
			$node = $node->appendChild($dom->createTextNode($str));
		}
		$node = $wipeNode->appendChild($dom->createElement('Ratio', $this->speed));
		if($this->type === 2) {
			$str = Element::getStrFromList(ItemWipeElement::getDiagonalTypeStrList(), $this->diagonalType);
			if($str !== '') {
				$node = $wipeNode->appendChild($dom->createElement('DiagonalType'));
				$node = $node->appendChild($dom->createTextNode($str));
			}
		}

		return $wipeNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj->Type)) {
			$this->type = Element::getIdFromList(ItemWipeElement::getTypeStrList(), (string)$obj->Type);
		}

		if(isset($obj->WidthNumber)) {
			$this->widthDivideNumber = intval($obj->WidthNumber);
		}

		if(isset($obj->HeightNumber)) {
			$this->heightDivideNumber = intval($obj->HeightNumber);
		}

		if(isset($obj->WidthScale)) {
			$this->widthIsMagnified = Element::getBoolFromStr((string)$obj->WidthScale);
		}

		if(isset($obj->HeightScale)) {
			$this->heightIsMagnified = Element::getBoolFromStr((string)$obj->HeightScale);
		}

		if(isset($obj->Revers)) {
			$this->displayDirection = Element::getIdFromList(ItemWipeElement::getDisplayDirectionStrList(), (string)$obj->Revers);
		}

		if(isset($obj->Ratio)) {
			$this->speed = intval($obj->Ratio);
		}

		if(isset($obj->DiagonalType)) {
			$this->diagonalType = Element::getIdFromList(ItemWipeElement::getDiagonalTypeStrList(), (string)$obj->DiagonalType);
		}

		return true;
	}

	function resetId() {
		$this->itemId = 0;
	}

	/**
	 * 表示方法文字列一覧取得
	 * @return array 表示方法文字列一覧(キー:ID/値:文字列)
	 */
	static function getTypeStrList() {
		$list = array();
		$list[1] = 'straight';
		$list[2] = 'diagonal';

		return $list;
	}

	/**
	 * 表示方向文字列一覧取得
	 * @return array 表示方向文字列一覧(キー:ID/値:文字列)
	 */
	static function getDisplayDirectionStrList() {
		$list = array();
		$list[1] = 'yes';
		$list[2] = 'no';

		return $list;
	}

	/**
	 * 斜め表示の表示開始位置文字列一覧取得
	 * @return array 斜め表示の表示開始位置文字列一覧(キー:ID/値:文字列)
	 */
	static function getDiagonalTypeStrList() {
		$list = array();
		$list[1] = 'center';
		$list[2] = 'up';
		$list[3] = 'down';

		return $list;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if($this->widthDivideNumber !== '' && !is_numeric($this->widthDivideNumber)) {
			$resultList['widthDivideNumber'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->widthDivideNumber = intval($this->widthDivideNumber);
		}

		if($this->heightDivideNumber !== '' && !is_numeric($this->heightDivideNumber)) {
			$resultList['heightDivideNumber'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->heightDivideNumber = intval($this->heightDivideNumber);
		}

		if($this->speed !== '' && !is_numeric($this->speed)) {
			$resultList['speed'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->speed = intval($this->speed);
		}

		return $resultList;
	}
}

class ItemElement extends Element {
	public $name = '';
	public $dispNo = 0;
	public $isDisplay = false;
	public $layer = 0;
	public $xAxis = 0;
	public $yAxis = 0;
	public $image = '';
	public $imageFadeinEffect = 0;
	public $imageSlideinAngle = 0;
	public $imageSlideinMoveSize = 0;
	public $imageSlideinMoveSpeed = 0;
	public $delayTime = 0;
	public $imageType = 1;

	public $playlistPlayType = 1;
	public $playlistPlayWait = 0;

	public $itemButtonElement = null;
	public $itemWipeElement = null;
	public $playlistItemList = array();

	public $itemId = 0;
	public $parentItemId = 0;
	public $parentType = 0;

	function &getNode($dom, $isDemo) {
		$itemNode = $dom->appendChild($dom->createElement('Item'));
		$attribute = $itemNode->appendChild($dom->createAttribute('no'));
		$attribute->appendChild($dom->createTextNode($this->dispNo));

		if($this->name !== '') {
			$node = $itemNode->appendChild($dom->createElement('HiddenName'));
			$node = $node->appendChild($dom->createTextNode($this->name));
		}

		$node = $itemNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->isDisplay)));
		if($this->isDisplay) {
			$str = Element::getStrFromList(ItemElement::getLayerStrList(), $this->layer);
			if($str !== '') {
				$node = $itemNode->appendChild($dom->createElement('Layer'));
				$node = $node->appendChild($dom->createTextNode($str));
			}

			$propertyNode = $itemNode->appendChild($dom->createElement('Property'));
			$node = $propertyNode->appendChild($dom->createElement('PosX', $this->xAxis));
			$node = $propertyNode->appendChild($dom->createElement('PosY', $this->yAxis));
			$node = $propertyNode->appendChild($dom->createElement('Delay', $this->delayTime));

			if($this->image !== '' || count($this->playlistItemList) > 0) {
				$imageNode = $propertyNode->appendChild($dom->createElement('Image'));

				$str = Element::getStrFromList(ItemElement::getFileTypeStr(), $this->imageType);
				if($str !== '') {
					$node = $imageNode->appendChild($dom->createElement('SelectType'));
					$node = $node->appendChild($dom->createTextNode($str));
				}

				if($this->imageType === 1) {
					$node = $imageNode->appendChild($dom->createElement('Url'));
					$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->image, $isDemo)));
				} else if($this->imageType === 2) {
					$playListNode = $imageNode->appendChild($dom->createElement('List'));
					$node = $playListNode->appendChild($dom->createElement('Wait', $this->playlistPlayWait));
					$str = Element::getStrFromList(ItemElement::getPlayTypeStr(), $this->playlistPlayType);
					if($str !== '') {
						$node = $playListNode->appendChild($dom->createElement('Type'));
						$node = $node->appendChild($dom->createTextNode($str));
					}
					foreach($this->playlistItemList as $element) {
						$node = $playListNode->appendChild($element->getNode($dom, $isDemo));
					}
				}

				$node = $imageNode->appendChild($dom->createElement('FadeInEffect'));
				$node = $node->appendChild($dom->createElement('Ratio', $this->imageFadeinEffect));

				$slieinNode = $imageNode->appendChild($dom->createElement('SlideInEffect'));
				$node = $slieinNode->appendChild($dom->createElement('Angle', $this->imageSlideinAngle));
				$node = $slieinNode->appendChild($dom->createElement('MovedDistance', $this->imageSlideinMoveSize));
				$node = $slieinNode->appendChild($dom->createElement('Ratio', $this->imageSlideinMoveSpeed));

				if(!is_null($this->itemWipeElement)) {
					$node = $imageNode->appendChild($this->itemWipeElement->getNode($dom, $isDemo));
				}
			}

			if(!is_null($this->itemButtonElement)) {
				$node = $itemNode->appendChild($this->itemButtonElement->getNode($dom, $isDemo));
			}
		}

		return $itemNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj['no'])) {
			$this->dispNo = intval($obj['no']);
		} else {
			return false;
		}

		if(isset($obj->HiddenName)) {
			$this->name = (string)$obj->HiddenName;
		}

		if(isset($obj->Display)) {
			$this->isDisplay = Element::getBoolFromStr((string)$obj->Display);
		}

		if(isset($obj->Layer)) {
			$this->layer = Element::getIdFromList(ItemElement::getLayerStrList(), (string)$obj->Layer);
		}

		if(isset($obj->Property->PosX)) {
			$this->xAxis = intval($obj->Property->PosX);
		}

		if(isset($obj->Property->PosY)) {
			$this->yAxis = intval($obj->Property->PosY);
		}

		if(isset($obj->Property->Delay)) {
			$this->delayTime = intval($obj->Property->Delay);
		}

		if(isset($obj->Property->Image->SelectType)) {
			$this->imageType = Element::getIdFromList(ItemElement::getFileTypeStr(), (string)$obj->Property->Image->SelectType);
		}

		if(isset($obj->Property->Image->Url)) {
			$this->image = (string)$obj->Property->Image->Url;
		}

		if(isset($obj->Property->Image->List->Wait)) {
			$this->playlistPlayWait = intval($obj->Property->Image->List->Wait);
		}

		if(isset($obj->Property->Image->List->Type)) {
			$this->playlistPlayType = Element::getIdFromList(ItemElement::getPlayTypeStr(), (string)$obj->Property->Image->List->Type);
		}

		if(isset($obj->Property->Image->List->Item)) {
			foreach($obj->Property->Image->List->Item as $itemObj) {
				$element = new ItemPlayListItem();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->playlistItemList[] = $element;
				} else {
					return false;
				}
			}
		}

		if(isset($obj->Property->Image->FadeInEffect->Ratio)) {
			$this->imageFadeinEffect = intval($obj->Property->Image->FadeInEffect->Ratio);
		}

		if(isset($obj->Property->Image->SlideInEffect->Angle)) {
			$this->imageSlideinAngle = intval($obj->Property->Image->SlideInEffect->Angle);
		}

		if(isset($obj->Property->Image->SlideInEffect->MovedDistance)) {
			$this->imageSlideinMoveSize = intval($obj->Property->Image->SlideInEffect->MovedDistance);
		}

		if(isset($obj->Property->Image->SlideInEffect->Ratio)) {
			$this->imageSlideinMoveSpeed = intval($obj->Property->Image->SlideInEffect->Ratio);
		}

		if(isset($obj->Button)) {
			$element = new ItemButtonElement();
			if($element->setDataFromXmlObj($obj->Button)) {
				$this->itemButtonElement = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->Property->Image->WipeEffect)) {
			$element = new ItemWipeElement();
			if($element->setDataFromXmlObj($obj->Property->Image->WipeEffect)) {
				$this->itemWipeElement = $element;
			} else {
				return false;
			}
		}
		return true;
	}

	function resetId() {
		$this->itemId = 0;
		$this->parentItemId = 0;

		foreach($this->playlistItemList as $element) {
			$element->resetId();
		}

		if(!is_null($this->itemButtonElement)) {
			$this->itemButtonElement->resetId();
		}
		if(!is_null($this->itemWipeElement)) {
			$this->itemWipeElement->resetId();
		}
	}

	/**
	 * 表示深度文字列一覧取得
	 * @return array 表示深度文字列一覧(キー:ID/値:文字列)
	 */
	static function getLayerStrList() {
		$list = array();
		$list[1] = 'upper';
		$list[2] = 'under';

		return $list;

	}

	/**
	 * 表示ファイル種別
	 * @return  array 表示ファイル種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getFileTypeStr() {
		$list = array();
		$list[1] = 'single';	//1ファイル
		$list[2] = 'list';		//PlayList

		return $list;
	}

	/**
	 * プレイリスト再生方法種別
	 * @return  array プレイリスト再生方法種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getPlayTypeStr() {
		$list = array();
		$list[1] = 'random';
		$list[2] = 'sequence';

		return $list;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if((strlen(bin2hex($this->name)) / 2) > 30) {
			$resultList['name'] = Language::MSG_LONG_NAME_ERROR;
		}

		if($this->xAxis === '' || !is_numeric($this->xAxis)) {
			$resultList['xAxis'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->xAxis = intval($this->xAxis);
		}

		if($this->yAxis === '' || !is_numeric($this->yAxis)) {
			$resultList['yAxis'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->yAxis = intval($this->yAxis);
		}

		if($this->delayTime === '' || !is_numeric($this->delayTime)) {
			$resultList['delayTime'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->delayTime = intval($this->delayTime);
		}

		if($this->playlistPlayWait === '' || !is_numeric($this->playlistPlayWait)) {
			$resultList['playlistPlayWait'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->playlistPlayWait = intval($this->playlistPlayWait);
		}

		if($this->imageFadeinEffect !== '' && !Element::checkPercentageFormat($this->imageFadeinEffect)) {
			$resultList['imageFadeinEffect'] = Language::MSG_PERCENTAGE_FORMAT_ERROR;
		} else {
			$this->imageFadeinEffect = intval($this->imageFadeinEffect);
		}

		if(($this->imageSlideinAngle !== '' && !is_numeric($this->imageFadeinEffect))
		|| intval($this->imageSlideinAngle) < 0 || intval($this->imageSlideinAngle) > 360) {
			$resultList['imageSlideinAngle'] = Language::MSG_ANGLE_FORMAT_ERROR;
		} else {
			$this->imageSlideinAngle = intval($this->imageSlideinAngle);
		}

		if($this->imageSlideinMoveSize !== '' && !is_numeric($this->imageSlideinMoveSize)) {
			$resultList['imageSlideinMoveSize'] = Language::MSG_NUMERIC_ERROR;
		} else {
			$this->imageSlideinMoveSize = intval($this->imageSlideinMoveSize);
		}

		if($this->imageSlideinMoveSpeed !== '' && !Element::checkPercentageFormat($this->imageSlideinMoveSpeed)) {
			$resultList['imageSlideinMoveSpeed'] = Language::MSG_PERCENTAGE_FORMAT_ERROR;
		} else {
			$this->imageSlideinMoveSpeed = intval($this->imageSlideinMoveSpeed);
		}

		return $resultList;
	}
}

class LinkElement extends Element {

	public $itemElementList = array();

	public $domainId = 0;	//取得時のみ

	function &getNode($dom, $isDemo) {
		$linkNode = $dom->createElement('LINK');

		foreach($this->itemElementList as $itemElement) {
			$node = $linkNode->appendChild($itemElement->getNode($dom, $isDemo));
		}

		return $linkNode;
	}

	function setDataFromXmlObj($obj) {
		if(isset($obj->Item)) {
			foreach($obj->Item as $itemObj) {
				$element = new ItemElement();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->itemElementList[] = $element;
				} else {
					return false;
				}
			}
		}

		return true;
	}

	function resetId() {
		foreach($this->itemElementList as $itemElement) {
			$itemElement->resetId();
		}
	}

}

class HtmlPropertyElement extends Element {

	public $bodyMarginTop = 0;
	public $bodyMarginBottom = 0;
	public $bodyMarginLeft = 0;
	public $bodyMarginRight = 0;
	public $bodyMarginLeftIsAuto = false;
	public $bodyMarginRightIsAuto = false;
	public $bodyPaddingTop = 0;
	public $bodyPaddingBottom = 0;
	public $bodyPaddingLeft = 0;
	public $bodyPaddingRight = 0;
	public $bodyPaddingLeftIsAuto = false;
	public $bodyPaddingRightIsAuto = false;
	public $bodyLayoutType = 0;
	public $bodyBgColor = 'FFFFFF';
	public $bodyImageUrl = '';
	public $bodyImageRepeatType = 0;

	public $flashWidth = 940;
	public $flashHeight = 640;
	public $flashMarginTop = 0;
	public $flashMarginBottom = 0;
	public $flashMarginLeft = 0;
	public $flashMarginRight = 0;
	public $flashMarginLeftIsAuto = false;
	public $flashMarginRightIsAuto = false;
	public $flashPaddingTop = 0;
	public $flashPaddingBottom = 0;
	public $flashPaddingLeft = 0;
	public $flashPaddingRight = 0;
	public $flashPaddingLeftIsAuto = false;
	public $flashPaddingRightIsAuto = false;

	public $domainId = 0;	//取得時のみ

	function &getNode($dom, $isDemo) {
		$htmlNode = $dom->appendChild($dom->createElement('HtmlProperty'));

		$bodyNode = $htmlNode->appendChild($dom->createElement('Body'));
		$marginNode = $bodyNode->appendChild($dom->createElement('Margin'));
		$node = $marginNode->appendChild($dom->createElement('Top', $this->bodyMarginTop));
		$node = $marginNode->appendChild($dom->createElement('Bottom', $this->bodyMarginBottom));
		$node = $marginNode->appendChild($this->createAutoValueElement($dom, 'Left', $this->bodyMarginLeftIsAuto, $this->bodyMarginLeft));
		$node = $marginNode->appendChild($this->createAutoValueElement($dom, 'Right', $this->bodyMarginRightIsAuto, $this->bodyMarginRight));

		$paddingNode = $bodyNode->appendChild($dom->createElement('Padding'));
		$node = $paddingNode->appendChild($dom->createElement('Top', $this->bodyPaddingTop));
		$node = $paddingNode->appendChild($dom->createElement('Bottom', $this->bodyPaddingBottom));
		$node = $paddingNode->appendChild($this->createAutoValueElement($dom, 'Left', $this->bodyPaddingLeftIsAuto, $this->bodyPaddingLeft));
		$node = $paddingNode->appendChild($this->createAutoValueElement($dom, 'Right', $this->bodyPaddingRightIsAuto, $this->bodyPaddingRight));

		$bgNode = $bodyNode->appendChild($dom->createElement('Background'));
		$node = $bgNode->appendChild($dom->createElement('Layout'));
		$node = $node->appendChild($dom->createTextNode(Element::getStrFromList(HtmlPropertyElement::getLayoutStrList(), $this->bodyLayoutType)));
		if($this->bodyBgColor !== '') {
			$node = $bgNode->appendChild($dom->createElement('Color', $this->bodyBgColor));
		}
		$imageNode = $bgNode->appendChild($dom->createElement('Image'));
		$node = $imageNode->appendChild($dom->createElement('Url'));
		$node = $node->appendChild($dom->createTextNode($this->bodyImageUrl));
		$node = $imageNode->appendChild($dom->createElement('Repeat'));
		$node = $node->appendChild($dom->createTextNode(Element::getStrFromList(HtmlPropertyElement::getRepeatStrList(), $this->bodyImageRepeatType)));

		$flashNode = $htmlNode->appendChild($dom->createElement('Flash'));
		$node = $flashNode->appendChild($dom->createElement('Width', $this->flashWidth));
		$node = $flashNode->appendChild($dom->createElement('Height', $this->flashHeight));
		$marginNode = $flashNode->appendChild($dom->createElement('Margin'));
		$node = $marginNode->appendChild($dom->createElement('Top', $this->flashMarginTop));
		$node = $marginNode->appendChild($dom->createElement('Bottom', $this->flashMarginBottom));
		$node = $marginNode->appendChild($this->createAutoValueElement($dom, 'Left', $this->flashMarginLeftIsAuto, $this->flashMarginLeft));
		$node = $marginNode->appendChild($this->createAutoValueElement($dom, 'Right', $this->flashMarginRightIsAuto, $this->flashMarginRight));

		$paddingNode = $flashNode->appendChild($dom->createElement('Padding'));
		$node = $paddingNode->appendChild($dom->createElement('Top', $this->flashPaddingTop));
		$node = $paddingNode->appendChild($dom->createElement('Bottom', $this->flashPaddingBottom));
		$node = $paddingNode->appendChild($this->createAutoValueElement($dom, 'Left', $this->flashPaddingLeftIsAuto, $this->flashPaddingLeft));
		$node = $paddingNode->appendChild($this->createAutoValueElement($dom, 'Right', $this->flashPaddingRightIsAuto, $this->flashPaddingRight));

		return $htmlNode;
	}

	function setDataFromXmlObj($obj) {

		if(isset($obj->Body)) {
			if(isset($obj->Body->Margin->Top)) {
				$this->bodyMarginTop = intval($obj->Body->Margin->Top);
			}
			if(isset($obj->Body->Margin->Bottom)) {
				$this->bodyMarginBottom = intval($obj->Body->Margin->Bottom);
			}
			if(isset($obj->Body->Margin->Left)) {
				$tmpStr = (string)$obj->Body->Margin->Left;
				if($tmpStr === 'auto') {
					$this->bodyMarginLeftIsAuto = true;
					$this->bodyMarginLeft = 0;
				} else {
					$this->bodyMarginLeftIsAuto = false;
					$this->bodyMarginLeft = intval($obj->Body->Margin->Left);
				}
			}
			if(isset($obj->Body->Margin->Right)) {
				$tmpStr = (string)$obj->Body->Margin->Right;
				if($tmpStr === 'auto') {
					$this->bodyMarginRightIsAuto = true;
					$this->bodyMarginRight = 0;
				} else {
					$this->bodyMarginRightIsAuto = false;
					$this->bodyMarginRight = intval($obj->Body->Margin->Right);
				}
			}

			if(isset($obj->Body->Padding->Top)) {
				$this->bodyPaddingTop = intval($obj->Body->Padding->Top);
			}
			if(isset($obj->Body->Padding->Bottom)) {
				$this->bodyPaddingBottom = intval($obj->Body->Padding->Bottom);
			}
			if(isset($obj->Body->Padding->Left)) {
				$tmpStr = (string)$obj->Body->Padding->Left;
				if($tmpStr === 'auto') {
					$this->bodyPaddingLeftIsAuto = true;
					$this->bodyPaddingLeft = 0;
				} else {
					$this->bodyPaddingLeftIsAuto = false;
					$this->bodyPaddingLeft = intval($obj->Body->Padding->Left);
				}
			}
			if(isset($obj->Body->Padding->Right)) {
				$tmpStr = (string)$obj->Body->Padding->Right;
				if($tmpStr === 'auto') {
					$this->bodyPaddingRightIsAuto = true;
					$this->bodyPaddingRight = 0;
				} else {
					$this->bodyPaddingRightIsAuto = false;
					$this->bodyPaddingRight = intval($obj->Body->Padding->Right);
				}
			}

			if(isset($obj->Body->Background->Layout)) {
				$this->bodyLayoutType = intval($obj->Body->Background->Layout);
			}

			if(isset($obj->Body->Background->Color) && Element::checkColorFormat((string)$obj->Body->Background->Color)) {
				$this->bodyBgColor = (string)$obj->Body->Background->Color;
			}

			if(isset($obj->Body->Background->Image->Url)) {
				$this->bodyImageUrl = (string)$obj->Body->Background->Image->Url;
			}

			if(isset($obj->Body->Background->Image->Repeat)) {
				$this->bodyImageRepeatType = Element::getIdFromList(HtmlPropertyElement::getRepeatStrList(), (string)$obj->Body->Background->Image->Repeat);
			}
		}

		if(isset($obj->Flash)) {
			if(isset($obj->Flash->Width)) {
				$this->flashWidth = intval($obj->Flash->Width);
			}

			if(isset($obj->Flash->Height)) {
				$this->flashHeight = intval($obj->Flash->Height);
			}

			if(isset($obj->Flash->Margin->Top)) {
				$this->flashMarginTop = intval($obj->Flash->Margin->Top);
			}
			if(isset($obj->Flash->Margin->Bottom)) {
				$this->flashMarginBottom = intval($obj->Flash->Margin->Bottom);
			}
			if(isset($obj->Flash->Margin->Left)) {
				$tmpStr = (string)$obj->Flash->Margin->Left;
				if($tmpStr === 'auto') {
					$this->flashMarginLeftIsAuto = true;
					$this->flashMarginLeft = 0;
				} else {
					$this->flashMarginLeftIsAuto = false;
					$this->flashMarginLeft = intval($obj->Flash->Margin->Left);
				}
			}
			if(isset($obj->Flash->Margin->Right)) {
				$tmpStr = (string)$obj->Flash->Margin->Right;
				if($tmpStr === 'auto') {
					$this->flashMarginRightIsAuto = true;
					$this->flashMarginRight = 0;
				} else {
					$this->flashMarginRightIsAuto = false;
					$this->flashMarginRight = intval($obj->Flash->Margin->Right);
				}
			}

			if(isset($obj->Flash->Padding->Top)) {
				$this->flashPaddingTop = intval($obj->Flash->Padding->Top);
			}
			if(isset($obj->Flash->Padding->Bottom)) {
				$this->flashPaddingBottom = intval($obj->Flash->Padding->Bottom);
			}
			if(isset($obj->Flash->Padding->Left)) {
				$tmpStr = (string)$obj->Flash->Padding->Left;
				if($tmpStr === 'auto') {
					$this->flashPaddingLeftIsAuto = true;
					$this->flashPaddingLeft = 0;
				} else {
					$this->flashPaddingLeftIsAuto = false;
					$this->flashPaddingLeft = intval($obj->Flash->Padding->Left);
				}
			}
			if(isset($obj->Flash->Padding->Right)) {
				$tmpStr = (string)$obj->Flash->Padding->Right;
				if($tmpStr === 'auto') {
					$this->flashPaddingRightIsAuto = true;
					$this->flashPaddingRight = 0;
				} else {
					$this->flashPaddingRightIsAuto = false;
					$this->flashPaddingRight = intval($obj->Flash->Padding->Right);
				}
			}
		}

		return true;
	}

	function resetId() {
		//処理無し
	}

	/**
	 * auto/値のノードを作成する
	 * @param $dom [in] DOMオブジェクト
	 * @param $tagName [in] タグ名
	 * @param $isAuto [in] autoかどうか
	 * @param $value [in] autoでない場合の値
	 * @return ノード
	 */
	function &createAutoValueElement($dom, $tagName, $isAuto, $value) {
		$element = $dom->createElement($tagName);
		if($isAuto) {
			$element->appendChild($dom->createTextNode('auto'));
		} else {
			$element->appendChild($dom->createTextNode($value));
		}
		return $element;
	}

	/**
	 * 繰り返し文字列一覧取得
	 * @return array 繰り返し文字列一覧(キー:ID/値:文字列)
	 */
	static function &getRepeatStrList() {
		$list = array();
		$list[0] = 'no-repeat';
		$list[1] = 'repeat-y';
		$list[2] = 'repeat-x';
		$list[3] = 'repeat';
		return $list;
	}

	/**
	 * レイアウト種別文字列一覧取得
	 * @return array レイアウト種別文字列一覧(キー:ID/値:文字列)
	 */
	static function &getLayoutStrList() {
		$list = array();
		$list[0] = 'center';
		$list[1] = 'left';
		$list[2] = 'right';
		return $list;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();

		if($this->bodyBgColor === '' || !Element::checkColorFormat($this->bodyBgColor)) {
			$resultList['bodyBgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}
		if($this->bodyMarginTop === '' || !is_numeric($this->bodyMarginTop)) {
			$resultList['bodyMarginTop'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyMarginTop = intval($this->bodyMarginTop);
		}
		if($this->bodyMarginBottom === '' || !is_numeric($this->bodyMarginBottom)) {
			$resultList['bodyMarginBottom'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyMarginBottom = intval($this->bodyMarginBottom);
		}
		if($this->bodyMarginLeft === '' || !is_numeric($this->bodyMarginLeft)) {
			$resultList['bodyMarginLeft'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyMarginLeft = intval($this->bodyMarginLeft);
		}
		if($this->bodyMarginRight === '' || !is_numeric($this->bodyMarginRight)) {
			$resultList['bodyMarginRight'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyMarginRight = intval($this->bodyMarginRight);
		}
		if($this->bodyPaddingTop === '' || !is_numeric($this->bodyPaddingTop)) {
			$resultList['bodyPaddingTop'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyPaddingTop = intval($this->bodyPaddingTop);
		}
		if($this->bodyPaddingBottom === '' || !is_numeric($this->bodyPaddingBottom)) {
			$resultList['bodyPaddingBottom'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyPaddingBottom = intval($this->bodyPaddingBottom);
		}
		if($this->bodyPaddingLeft === '' || !is_numeric($this->bodyPaddingLeft)) {
			$resultList['bodyPaddingLeft'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyPaddingLeft = intval($this->bodyPaddingLeft);
		}
		if($this->bodyPaddingRight === '' || !is_numeric($this->bodyPaddingRight)) {
			$resultList['bodyPaddingRight'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->bodyPaddingRight = intval($this->bodyPaddingRight);
		}
		if($this->flashWidth === '' || !is_numeric($this->flashWidth)) {
			$resultList['flashWidth'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashWidth = intval($this->flashWidth);
		}
		if($this->flashHeight === '' || !is_numeric($this->flashHeight)) {
			$resultList['flashHeight'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashHeight = intval($this->flashHeight);
		}
		if($this->flashMarginTop === '' || !is_numeric($this->flashMarginTop)) {
			$resultList['flashMarginTop'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashMarginTop = intval($this->flashMarginTop);
		}
		if($this->flashMarginBottom === '' || !is_numeric($this->flashMarginBottom)) {
			$resultList['flashMarginBottom'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashMarginBottom = intval($this->flashMarginBottom);
		}
		if($this->flashMarginLeft === '' || !is_numeric($this->flashMarginLeft)) {
			$resultList['flashMarginLeft'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashMarginLeft = intval($this->flashMarginLeft);
		}
		if($this->flashMarginRight === '' || !is_numeric($this->flashMarginRight)) {
			$resultList['flashMarginRight'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashMarginRight = intval($this->flashMarginRight);
		}
		if($this->flashPaddingTop === '' || !is_numeric($this->flashPaddingTop)) {
			$resultList['flashPaddingTop'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashPaddingTop = intval($this->flashPaddingTop);
		}
		if($this->flashPaddingBottom === '' || !is_numeric($this->flashPaddingBottom)) {
			$resultList['flashPaddingBottom'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashPaddingBottom = intval($this->flashPaddingBottom);
		}
		if($this->flashPaddingLeft === '' || !is_numeric($this->flashPaddingLeft)) {
			$resultList['flashPaddingLeft'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashPaddingLeft = intval($this->flashPaddingLeft);
		}
		if($this->flashPaddingRight === '' || !is_numeric($this->flashPaddingRight)) {
			$resultList['flashPaddingRight'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->flashPaddingRight = intval($this->flashPaddingRight);
		}

		return $resultList;
	}
}

class FlagXmlInfo extends Element {

	public $logoPos = 0;
	public $bgColor = '';
	public $bgImage = '';

	public $elementList = array();

	public $updateDateStr = '';
	public $updateUser = '';

	function &getNode($dom, $isDemo) {
		require_once SYSTEM_PATH.'template/swf_info.php';

		$dataNode = $dom->createElement('DATA');

		$node = $dataNode->appendChild($dom->createElement('Copyright'));
		$node = $node->appendChild($dom->createTextNode('(C)2009 maverica corporation. ALL RIGHTS RESERVED.'));

		$node = $dataNode->appendChild($dom->createElement('Version'));
		$node = $node->appendChild($dom->createTextNode(SwfInfo::FLAG_VERSION));

		$str = Element::getStrFromList(FlagXmlInfo::getLogoPosStrList(), $this->logoPos);
		if($str !== '') {
			$node = $dataNode->appendChild($dom->createElement('Logo'));
			$node = $node->appendChild($dom->createTextNode($str));
		}

		if($this->bgColor !== '') {
			$node = $dataNode->appendChild($dom->createElement('BgColor', $this->bgColor));
		}

		if($this->bgImage !== '') {
			$node = $dataNode->appendChild($dom->createElement('Image'));
			$node = $node->appendChild($dom->createElement('Url'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->bgImage, $isDemo)));
		}

		foreach($this->elementList as $element) {
			$node = $dataNode->appendChild($element->getNode($dom, $isDemo));
		}

		return $dataNode;
	}

	function setDataFromXmlObj($obj) {

		if(!isset($obj->Copyright)) {
			return false;
		}

		if(!isset($obj->Version)) {
			return false;
		}

		if(isset($obj->Logo)) {
			$this->logoPos = Element::getIdFromList(FlagXmlInfo::getLogoPosStrList(), (string)$obj->Logo);
		}

		if(isset($obj->BgColor) && Element::checkColorFormat((string)$obj->BgColor)) {
			$this->bgColor = (string)$obj->BgColor;
		}

		if(isset($obj->Image->Url)) {
			$this->bgImage = (string)$obj->Image->Url;
		}

		if(isset($obj->HtmlProperty)) {
			$element = new HtmlPropertyElement();
			if($element->setDataFromXmlObj($obj->HtmlProperty)) {
				$this->elementList[] = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->Player)) {
			$element = new PlayerElement();
			if($element->setDataFromXmlObj($obj->Player)) {
				$this->elementList[] = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->NEWS)) {
			$element = new NewsElement();
			if($element->setDataFromXmlObj($obj->NEWS)) {
				$this->elementList[] = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->LINK)) {
			$element = new LinkElement();
			if($element->setDataFromXmlObj($obj->LINK)) {
				$this->elementList[] = $element;
			} else {
				return false;
			}
		}

		return true;
	}

	function resetId() {
		foreach($this->elementList as $element) {
			$element->resetId();
		}
	}

	/**
	 * ファイルから読み込み
	 * @param $filePath [in] 対象XMLファイル
	 * @return bool 成功/失敗
	 */
	function loadFile($filePath) {
		$xml = simplexml_load_file($filePath);

		return $this->setDataFromXmlObj($xml);
	}

	/**
	 * XML出力
	 * @param $filePath [in] 出力先ファイル
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return bool 成功/失敗
	 */
	function saveFile($filePath, $isDemo = false) {
		$dom = new DOMDocument('1.0', 'UTF-8');
		$dom->formatOutput = true;

		$dataNode = $dom->appendChild($this->getNode($dom, $isDemo));

		return ($dom->save($filePath) !== FALSE);
	}

	/**
	 * ロゴ位置文字列一覧取得
	 * @return array ロゴ位置文字列一覧(キー:ID/値:文字列)
	 */
	static function &getLogoPosStrList() {
		$list = array();
		$list[1] = 'upper_right';
		$list[2] = 'upper_left';
		$list[3] = 'under_right';
		$list[4] = 'under_left';

		return $list;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();
		if($this->bgColor !== '' && !Element::checkColorFormat($this->bgColor)) {
			$resultList['bgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}
		return $resultList;
	}
}
?>