<?php
class PartsInfo {
	private static $_partsList = array();

	/**
	 * パーツリスト取得
	 * @return array パーツリスト
	 */
	static function &getList() {
		if(count(self::$_partsList) === 0) {
			self::$_partsList['slider']['name'] = Language::SLIDER;
			self::$_partsList['slider']['swf'] = 'flag_slider.swf';
			self::$_partsList['slider']['xml'] = 'flag_slider*.xml';
			self::$_partsList['slider']['uploader'] = true;
			self::$_partsList['slider']['subfile'] = '';

			self::$_partsList['photo']['name'] = Language::PHOTO_GALLERY;
			self::$_partsList['photo']['swf'] = 'flag_photo.swf';
			self::$_partsList['photo']['xml'] = 'flag_photo*.xml';
			self::$_partsList['photo']['uploader'] = true;
			self::$_partsList['photo']['subfile'] = '';

			self::$_partsList['text']['name'] = Language::TEXT_PARTS;
			self::$_partsList['text']['swf'] = 'flag_text.swf';
			self::$_partsList['text']['xml'] = 'flag_text*.xml';
			self::$_partsList['text']['uploader'] = false;
			self::$_partsList['text']['subfile'] = 'flag_text*.txt';
		}

		return self::$_partsList;
	}

	/**
	 * パーツ種別から、パーツ情報を取得する。
	 * @param $type [in] 種別
	 * @return array/null パーツ情報（ない場合はnull)
	 */
	static function getInfo($type) {
		$list = & self::getList();

		if(array_key_exists($type, $list)) {
			return $list[$type];
		} else {
			return null;
		}
	}

	/**
	 * 利用可能なパーツ情報一覧取得
	 * @return array パーツリスト
	 */
	static function getActiveList() {
		$retList = array();

		$dirBase = dirname(__FILE__).'/../../../template/';
		$list = & self::getList();
		foreach($list as $type => $infoList) {
			if(is_file($dirBase.$infoList['swf'])) {
				$retList[$type] = $infoList;
			}
		}
		return $retList;
	}

	/**
	 * パーツが利用可能かチェックする
	 * @param $type [in] 種別
	 * @return bool 利用可否
	 */
	static function isActive($type) {
		$info = self::getInfo($type);
		if(is_null($info)) {
			return false;
		}

		$dirBase = dirname(__FILE__).'/../../../template/';
		return is_file($dirBase.$info['swf']);
	}

	/**
	 * アップローダーが利用可能かチェックする
	 * @param $type [in] 種別
	 * @return bool 利用可否
	 */
	static function isUploader($type) {
		$info = self::getInfo($type);
		if(is_null($info)) {
			return false;
		}

		return $info['uploader'];
	}
}
?>