<?php
require_once 'xml_base.php';
require_once 'flag_xml.php';

class PhotoImageItemElemet extends Element {

	public $dispNo = 0;
	public $name = '';
	public $imageUrl = '';

	public $imageId = 0;
	public $photoId = 0;

	function &getNode($dom, $isDemo) {
		$itemNode = $dom->createElement('Item');
		$attribute = $itemNode->appendChild($dom->createAttribute('no'));
		$attribute->appendChild($dom->createTextNode($this->dispNo));

		if($this->name !== '') {
			$node = $itemNode->appendChild($dom->createElement('HiddenName'));
			$node = $node->appendChild($dom->createTextNode($this->name));
		}

		if($this->imageUrl !== '') {
			$node = $itemNode->appendChild($dom->createElement('ImageUrl'));
			$node = $node->appendChild($dom->createTextNode($this->imageUrl));
		}

		return $itemNode;
	}

	function setDataFromXmlObj($obj) {

		if(isset($obj['no'])) {
			$this->dispNo = intval($obj['no']);
		} else {
			return false;
		}

		if(isset($obj->HiddenName)) {
			$this->name = (string)$obj->HiddenName;
		}

		if(isset($obj->ImageUrl)) {
			$this->imageUrl = (string)$obj->ImageUrl;
		}

		return true;
	}

	function resetId() {
		$this->imageId = 0;
		$this->photoId = 0;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$list = array();
		//対象無し
		return $list;
	}
}

class PhotoXmlInfo extends Element {

	public $name = '';
	public $bgColor = '';
	public $bgAlpha = 100;
	public $width = 320;
	public $height = 240;
	public $isSequentialMode = true;

	public $figureNumber = 1;
	public $startValue = 0;
	public $endValue = 0;
	public $fileExtension = '';
	public $filePath = '';

	public $imageSize = 0;
	public $isDisplayFrame = true;
	public $frameOuterColor = 'FFFFFF';
	public $frameInnerColor = '000000';

	public $imageItemList = array();

	public $number = 0;

	public $photoId = 0;

	function &getNode($dom, $isDemo) {
		require_once SYSTEM_PATH.'template/swf_info.php';

		$dataNode = $dom->createElement('DATA');

		$node = $dataNode->appendChild($dom->createElement('Copyright'));
		$node = $node->appendChild($dom->createTextNode('(C)2009 maverica corporation. ALL RIGHTS RESERVED.'));

		$node = $dataNode->appendChild($dom->createElement('Version'));
		$node = $node->appendChild($dom->createTextNode(SwfInfo::PARTS_PHOTO_VERSION));

		if($this->name !== '') {
			$node = $dataNode->appendChild($dom->createElement('HiddenName'));
			$node = $node->appendChild($dom->createTextNode($this->name));
		}

		$propertyNode = $dataNode->appendChild($dom->createElement('Property'));

		if($this->bgColor !== '') {
			$node = $propertyNode->appendChild($dom->createElement('BgColor', $this->bgColor));
		}
		$node = $propertyNode->appendChild($dom->createElement('BgAlpha', $this->bgAlpha));
		$node = $propertyNode->appendChild($dom->createElement('Width', $this->width));
		$node = $propertyNode->appendChild($dom->createElement('Height', $this->height));

		$frameNode = $propertyNode->appendChild($dom->createElement('ImageFrame'));
		$node = $frameNode->appendChild($dom->createElement('Size', $this->imageSize));
		$node = $frameNode->appendChild($dom->createElement('Display', Element::getBoolStr($this->isDisplayFrame)));
		if($this->isDisplayFrame) {
			if($this->frameOuterColor !== '') {
				$node = $frameNode->appendChild($dom->createElement('OutFrameColor', $this->frameOuterColor));
			}
			if($this->frameInnerColor !== '') {
				$node = $frameNode->appendChild($dom->createElement('InnerColor', $this->frameInnerColor));
			}
		}

		$node = $propertyNode->appendChild($dom->createElement('Sequential', Element::getBoolStr($this->isSequentialMode)));
		if($this->isSequentialMode) {
			$node = $propertyNode->appendChild($dom->createElement('Digit', $this->figureNumber));
			$node = $propertyNode->appendChild($dom->createElement('ImageMin', $this->startValue));
			$node = $propertyNode->appendChild($dom->createElement('ImageMax', $this->endValue));
			$node = $propertyNode->appendChild($dom->createElement('Extension'));
			$node = $node->appendChild($dom->createTextNode($this->fileExtension));

			if($this->filePath !== '') {
				$node = $propertyNode->appendChild($dom->createElement('ImagePath'));
				$node = $node->appendChild($dom->createTextNode($this->filePath));
			}
		} else {
			foreach($this->imageItemList as $element) {
				$node = $dataNode->appendChild($element->getNode($dom, $isDemo));
			}
		}

		return $dataNode;
	}

	function setDataFromXmlObj($obj) {

		if(!isset($obj->Copyright)) {
			return false;
		}

		if(!isset($obj->Version)) {
			return false;
		}

		if(isset($obj->HiddenName)) {
			$this->name = (string)$obj->HiddenName;
		}

		if(isset($obj->Property)) {
			if(isset($obj->Property->BgColor) && Element::checkColorFormat((string)$obj->Property->BgColor)) {
				$this->bgColor = (string)$obj->Property->BgColor;
			}

			if(isset($obj->Property->BgAlpha)) {
				$this->bgAlpha = intval($obj->Property->BgAlpha);
			}

			if(isset($obj->Property->Width)) {
				$this->width = intval($obj->Property->Width);
			}

			if(isset($obj->Property->Height)) {
				$this->height = intval($obj->Property->Height);
			}

			if(isset($obj->Property->Sequential)) {
				$this->isSequentialMode = Element::getBoolFromStr((string)$obj->Property->Sequential);
			}

			if(isset($obj->Property->Digit)) {
				$this->figureNumber = intval($obj->Property->Digit);
			}

			if(isset($obj->Property->ImageMin)) {
				$this->startValue = intval($obj->Property->ImageMin);
			}

			if(isset($obj->Property->ImageMax)) {
				$this->endValue = intval($obj->Property->ImageMax);
			}

			if(isset($obj->Property->Extension)) {
				$this->fileExtension = (string)$obj->Property->Extension;
			}

			if(isset($obj->Property->ImagePath)) {
				$this->filePath = (string)$obj->Property->ImagePath;
			}

			if(isset($obj->Property->ImageFrame)) {
				if(isset($obj->Property->ImageFrame->Size)) {
					$this->imageSize = intval($obj->Property->ImageFrame->Size);
				}
				if(isset($obj->Property->ImageFrame->Display)) {
					$this->isDisplayFrame = Element::getBoolFromStr((string)$obj->Property->ImageFrame->Display);
				}
				if(isset($obj->Property->ImageFrame->OutFrameColor) && Element::checkColorFormat((string)$obj->Property->ImageFrame->OutFrameColor)) {
					$this->frameOuterColor = (string)$obj->Property->ImageFrame->OutFrameColor;
				}
				if(isset($obj->Property->ImageFrame->InnerColor) && Element::checkColorFormat((string)$obj->Property->ImageFrame->InnerColor)) {
					$this->frameInnerColor = (string)$obj->Property->ImageFrame->InnerColor;
				}
			}
		}

		if(isset($obj->Item)) {
			foreach($obj->Item as $itemObj) {
				$element = new PhotoImageItemElemet();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->imageItemList[] = $element;
				} else {
					return false;
				}
			}
		}

		return true;
	}

	function resetId() {
		$this->photoId = 0;
		foreach($this->imageItemList as $element) {
			$element->resetId();
		}
	}

	/**
	 * ファイルから読み込み
	 * @param $filePath [in] 対象XMLファイル
	 * @return bool 成功/失敗
	 */
	function loadFile($filePath) {
		$xml = simplexml_load_file($filePath);

		return $this->setDataFromXmlObj($xml);
	}

	/**
	 * サブファイル読み込み
	 * @param $filePath [in] 対象ファイル
	 * @return bool 成功/失敗
	 */
	function loadSubFile($filePath) {
		//処理無し
		return true;
	}

	/**
	 * XML出力
	 * @param $filePath [in] 出力先ファイル
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return bool 成功/失敗
	 */
	function saveFile($filePath, $isDemo = false) {
		$dom = new DOMDocument('1.0', 'UTF-8');
		$dom->formatOutput = true;

		$dataNode = $dom->appendChild($this->getNode($dom, $isDemo));

		return ($dom->save($filePath) !== FALSE);
	}

	/**
	 * サブファイル出力
	 * @param $filePath [in] 出力先ファイル
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return bool 成功/失敗
	 */
	function saveSubFile($filePath, $isDemo = false) {
		//処理無し
		return true;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();
		if($this->bgColor !== '' && !Element::checkColorFormat($this->bgColor)) {
			$resultList['bgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->bgAlpha !== '' && !Element::checkAlphaFormat($this->bgAlpha)) {
			$resultList['bgAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->bgAlpha = intval($this->bgAlpha);
		}

		if($this->width !== '' && !is_numeric($this->width)) {
			$resultList['width'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->width = intval($this->width);
		}

		if($this->height !== '' && !is_numeric($this->height)) {
			$resultList['height'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->height = intval($this->height);
		}

		if(!is_numeric($this->imageSize)) {
			$resultList['imageSize'] = Language::MSG_IMAGE_SIZE_ERROR;
		} else if(intval($this->imageSize) < 0 || intval($this->imageSize) > 2999) {
			$resultList['imageSize'] = Language::MSG_IMAGE_SIZE_ERROR;
		} else {
			$this->imageSize = intval($this->imageSize);
		}

		if($this->isDisplayFrame) {
			if($this->frameOuterColor !== '' && !Element::checkColorFormat($this->frameOuterColor)) {
				$resultList['frameOuterColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
			}
			if($this->frameInnerColor !== '' && !Element::checkColorFormat($this->frameInnerColor)) {
				$resultList['frameInnerColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
			}
		}

		if($this->isSequentialMode) {
			if($this->figureNumber !== '' && !is_numeric($this->figureNumber)) {
				$resultList['figureNumber'] = Language::MSG_NUMERIC_FORMAT_ERROR;
			} else if(intval($this->figureNumber) <= 0) {
				$resultList['figureNumber'] = Language::MSG_FIGURE_NUMBER_ERROR;
			} else {
				$this->figureNumber = intval($this->figureNumber);
			}

			if($this->startValue !== '' && !is_numeric($this->startValue)) {
				$resultList['startValue'] = Language::MSG_NUMERIC_FORMAT_ERROR;
			} else {
				$this->startValue = intval($this->startValue);
			}

			if($this->endValue !== '' && !is_numeric($this->endValue)) {
				$resultList['endValue'] = Language::MSG_NUMERIC_FORMAT_ERROR;
			} else {
				$this->endValue = intval($this->endValue);
			}

			if(empty($resultList['endValue']) && empty($resultList['startValue'])) {
				if($this->endValue < $this->startValue) {
					$resultList['startValue'] = Language::MSG_START_NUMBER_ERROR;
					$resultList['endValue'] = Language::MSG_END_NUMBER_ERROR;
				}
			}

			if($this->fileExtension === '') {
				$resultList['fileExtension'] = Language::MSG_MANDATORY_ERROR;
			}
		}

		return $resultList;
	}
}
?>