<?

/**
 * データアクセス基底クラス(PostgresSQL用)
 *
 */
class DataAccessBase {
	/**
	 * DBコネクション
	 * @var unknown_type
	 */
	protected static $dbConn = null;

	/**
	 * 操作ユーザー名
	 * @var string
	 */
	protected $userName = '';

	/**
	 * 利用可能かチェックする
	 * @param $settingList [in] 設定に必要なパラメータリスト
	 * @return bool 可否
	 */
	static function checkSetting($settingList) {
		$dbConn = pg_connect(
			  'host='.$settingList['dbServer']
			.' dbname='.$settingList['dbName']
			.' user='.$settingList['dbUserName']
			.' password='.$settingList['dbPassword']
		);

		//すでに利用されているDBかをチェック
		$sql = "SELECT COUNT(TABLENAME) AS cnt FROM PG_TABLES WHERE NOT TABLENAME LIKE 'pg%' AND NOT SCHEMANAME = 'information_schema'";
		$rs = pg_query($dbConn, $sql);
		if($rs === FALSE  || pg_num_rows($rs) !== 1) {
			return false;
		} else {
			$row = pg_fetch_array($rs, 0, PGSQL_ASSOC);
			return (intval($row['cnt'])===0);
		}
	}

	/**
	 * コンストラクタ
	 *
	 * @param unknown_type $dbConn [in] DBコネクション
	 * @param string $userName [in] 操作ユーザー名
	 * @return DataAccessBase
	 */
	function DataAccessBase($userName) {
		if(is_null(self::$dbConn)) {
			$dbConn = pg_connect(
				  'host='.Config::DB_SERVER
				.' dbname='.Config::DB_NAME
				.' user='.Config::DB_USER_NAME
				.' password='.Config::DB_PASSWORD
			);
			if($dbConn !== FALSE) {
				self::$dbConn = $dbConn;
			}
		}

		$this->userName = $userName;
	}

	/**
	 * 文字列をエスケープしてシングルクォートでくくる
	 *
	 * @param string $str [in] 文字列
	 * @return string 変換後文字列
	 */
	protected function dbStr($str) {
		return "'".pg_escape_string($str)."'";
	}

	/**
	 * 文字列をエスケープしてシングルクォートでくくる。文字がない場合は[NULL]を返す
	 *
	 * @param string $str [in] 文字列
	 * @return string 変換後文字列
	 */
	protected function dbStrNull($str) {
		if(strval($str) === ''){
			return 'NULL';
		} else{
			return $this->dbStr($str);
		}
	}
}
?>