<?php
require_once dirname(__FILE__).'/../domain.php';

class Domain extends DataAccessBase {

	/**
	 * 概要一覧取得
	 * @return array DomainOutlineInfoリスト
	 */
	function &getOutlineList() {
		$list = array();

		$sql  = 'SELECT domain_id, domain_title';
		$sql .= ' FROM domain';
		$sql .= ' ORDER BY domain_id DESC';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$info = new DomainOutlineInfo();
			$info->domainId  = intval($row['domain_id']);
			$info->domainTitle = $row['domain_title'];
			$list[$info->domainId] = $info;
		}

		return $list;
	}

	/**
	 * 指定ドメイン名が利用中かどうかチェックする
	 * @param $domainName [in] ドメイン名
	 * @return bool 利用状況
	 */
	function isUseDomainName($domainName) {
		$sql = 'SELECT domain_title FROM domain WHERE domain_name='.$this->dbStr($domainName);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		return (pg_num_rows($res) !== 0);
	}

	/**
	 * 指定出力先が利用中かどうかチェックする
	 * @param $outputPath [in] 出力先
	 * @return bool 利用状況
	 */
	function isUseOutputPath($outputPath, $myDomainId) {
		$sql = 'SELECT output_path FROM domain WHERE output_path='.$this->dbStr($outputPath).' AND domain_id<>'.intval($myDomainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		return (pg_num_rows($res) !== 0);
	}

	/**
	 * ドメイン情報登録
	 * @param $info [in] DomainInfo
	 * @return 登録したID
	 */
	function regist($info) {
		$columns  = ' domain_title';
		$values   = ' '.$this->dbStr($info->domainTitle);
		$columns .= ',domain_name';
		$values  .= ','.$this->dbStr($info->domainName);
		$columns .= ',output_path';
		$values  .= ','.$this->dbStr($info->outputPath);
		$columns .= ',iframe_src_type';
		$values  .= ','.intval($info->iframeSrcType);
		$columns .= ',input_iframe_src';
		$values  .= ','.$this->dbStr($info->inputIframeSrc);
		$columns .= ',is_not_output';
		$values  .= ',1';
		$columns .= ',regist_date';
		$values  .= ',NOW()';
		$columns .= ',update_date';
		$values  .= ',NOW()';
		$columns .= ',regist_user';
		$values  .= ','.$this->dbStr($this->userName);
		$columns .= ',update_user';
		$values  .= ','.$this->dbStr($this->userName);

		$sql = 'INSERT INTO domain ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return 0;
		} else {
			$res = pg_query(self::$dbConn, "SELECT CURRVAL('domain_domain_id_seq') AS currval");
			if($res === FALSE || pg_num_rows($res) !== 1) {
				return 0;
			} else {
				$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
				return intval($row['currval']);
			}
		}
	}

	/**
	 * ドメイン情報更新
	 * タイトル（名前）、横幅、高さを更新
	 * @param $info [in] ドメイン情報
	 * @return bool 成功／失敗
	 */
	function update($info) {
		$setval  = ' domain_title='.$this->dbStr($info->domainTitle);
		$setval .= ',iframe_src_type='.intval($info->iframeSrcType);
		$setval .= ',output_path='.$this->dbStr($info->outputPath);
		$setval .= ',input_iframe_src='.$this->dbStr($info->inputIframeSrc);
		$setval .= ',update_date=now()';
		$setval .= ',update_user='.$this->dbStr($this->userName);

		$sql = 'UPDATE domain SET '.$setval.' WHERE domain_id='.intval($info->domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * ドメイン情報取得
	 * @param $domainId [in] ドメインID
	 * @return DomainInfo ドメイン情報
	 */
	function getInfo($domainId) {
		$info = new DomainInfo();

		$sql  = 'SELECT domain_id, domain_title, domain_name, output_path, iframe_src_type, input_iframe_src, regist_user, update_user';
		$sql .= ", to_char(regist_date, 'YYYY/MM/DD HH24:MI:SS') AS regist_date_str";
		$sql .= ", to_char(update_date, 'YYYY/MM/DD HH24:MI:SS') AS update_date_str";
		$sql .= ' FROM domain WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->domainId  = intval($row['domain_id']);
		$info->domainTitle = $row['domain_title'];
		$info->domainName = $row['domain_name'];
		$info->outputPath = $row['output_path'];
		$info->iframeSrcType = intval($row['iframe_src_type']);
		$info->inputIframeSrc = $row['input_iframe_src'];
		$info->registDateStr = $row['regist_date_str'];
		$info->registUser = $row['regist_user'];
		$info->updateDateStr = $row['update_date_str'];
		$info->updateUser = $row['update_user'];

		return $info;

	}

	/**
	 * ドメイン削除
	 * 関連テーブルのデータもすべて削除する
	 * @param $domainId [in] ドメインID
	 * @return bool 成功／失敗
	 */
	function delete($domainId) {
		// 関連テーブル全削除
		require_once dirname(__FILE__).'/../parts.php';
		$partsList =& PartsInfo::getList();

		foreach($partsList as $partsType => $partsInfoList) {
			$tmpStr = ucfirst($partsType);
			require_once SYSTEM_INCLUDE_DATA_PATH.$partsType.'/'.$partsType.'_xml.php';
			eval('$xmlDb = new '.$tmpStr.'Xml($_SESSION[\'UserName\']);');
			if(!$xmlDb->deleteAll(intval($domainId))) {
				return false;
			}
		}

		require_once 'flag_xml.php';
		$flagXml = new FlagXml($this->userName);
		if(!$flagXml->delete($domainId)) {
			return false;
		}

		$sql = 'DELETE FROM account WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM domain WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * ドメイン名取得
	 * @param $domainId [in] ドメインID
	 * @return string ドメイン名
	 */
	function getDomainTitle($domainId) {
		$sql  = 'SELECT domain_title';
		$sql .= ' FROM domain WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return '';
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return $row['domain_title'];

	}


	/**
	 * ドメインの出力先パス取得
	 * @param $domainId [in] ドメインID
	 * @return string 出力先パス
	 */
	function getOutputPath($domainId) {

		$sql  = 'SELECT output_path';
		$sql .= ' FROM domain WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return '';
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return $row['output_path'];
	}

	/**
	 * 未出力に設定する。
	 * @param $domainId [in] ドメインID
	 * @return bool 成功／失敗
	 */
	function setNotOutput($domainId) {
		$setval  = ' is_not_output=1';

		$sql = 'UPDATE domain SET '.$setval.' WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}
}
?>