<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class ItemData extends DataAccessBase {

	/**
	 * 親に所属するアイテムの最大表示順(件数から割り出したもの)を取得する
	 * @param $domainId [in] ドメインID
	 * @return intval 最大の表示順
	 */
	function getMaxDispNo($domainId) {
		$sql  = 'SELECT COUNT(disp_no) AS max FROM item_element WHERE domain_id='.intval($domainId).' AND parent_item_id=0';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return 0;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return intval($row['max']);
	}

	/**
	 * 概要一覧取得（ツリー用）
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @return array 概要一覧
	 */
	function &getOutlineList($domainId, $parentItemId, $parentType = 0) {
		$list = array();

		$sql  = 'SELECT a.item_id, a.disp_no, a.name, b.item_id AS button_id FROM item_element a LEFT JOIN item_button b ON a.item_id=b.item_id WHERE a.domain_id='.intval($domainId).' AND a.parent_type = '.intval($parentType);
		if(empty($parentItemId)) {
			$sql .= ' AND a.parent_item_id=0';
		} else {
			$sql .= ' AND a.parent_item_id='.intval($parentItemId);
		}
		$sql .= ' ORDER BY a.disp_no ASC, a.item_id ASC';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$itemId = intval($row['item_id']);
			$dispNo = intval($row['disp_no']);
			$list[$dispNo]['itemId'] = $itemId;
			$list[$dispNo]['name'] = $row['name'];
			$list[$dispNo]['dispNo'] = $dispNo;
			$list[$dispNo]['isUseButton'] = (isset($row['button_id']) && intval($row['button_id']) > 0);
			$list[$dispNo]['child'] = $this->getOutlineList($domainId, $itemId);
		}

		return $list;


	}

	/**
	 * item_element一覧を取得する(item_buttom,wipe_settingまで含む)
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return ItemElement
	 */
	function &getList($domainId, $parentItemId, $parentType, $isAll = false) {
		$list = array();

		$sql  = 'SELECT a.item_id, a.parent_item_id, a.domain_id, a.name, a.disp_no, a.is_display, a.layer, a.x_axis, a.y_axis, a.image';
		$sql .= ', a.image_fadein_effect, a.image_slidein_angle, a.image_slidein_move_size, image_slidein_move_speed';
		$sql .= ', a.delay_time, a.image_type, a.playlist_play_type, a.playlist_play_wait';
		$sql .= ', b.item_id AS button_item_id, b.width, b.height, b.rollover_color, b.rollover_alpha, b.rollout_color, b.rollout_alpha, b.link_url, b.link_url_target, b.bg_image';
		$sql .= ', b.rollover_image';
		$sql .= ', c.item_id AS wipe_id, c.type, c.width_divide_number, c.height_divide_number, c.width_is_magnified, c.height_is_magnified, c.display_direction, c.speed, c.diagonal_type';
		$sql .= ' FROM item_element a LEFT JOIN item_button b ON a.item_id=b.item_id';
		$sql .= ' LEFT JOIN wipe_setting c ON a.item_id=c.item_id';
		$sql .= ' WHERE domain_id='.intval($domainId).' AND a.parent_type='.intval($parentType);
		$sql .= ' AND ';
		if(empty($parentItemId)) {
			$sql .= '(a.parent_item_id IS NULL OR a.parent_item_id=0)';
		} else {
			$sql .= 'a.parent_item_id='.intval($parentItemId);
		}
		$sql .= ' ORDER BY a.disp_no ASC, a.item_id ASC';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$info = new ItemElement();
			$info->itemId = intval($row['item_id']);
			$info->parentItemId = (empty($row['parent_item_id'])?0:intval($row['parent_item_id']));

			$info->name = $row['name'];
			$info->dispNo = intval($row['disp_no']);
			$info->isDisplay = (intval($row['is_display'])===1);
			$info->layer = intval($row['layer']);
			$info->xAxis = intval($row['x_axis']);
			$info->yAxis = intval($row['y_axis']);
			$info->image = $row['image'];
			$info->imageFadeinEffect = intval($row['image_fadein_effect']);
			$info->imageSlideinAngle = intval($row['image_slidein_angle']);
			$info->imageSlideinMoveSize = intval($row['image_slidein_move_size']);
			$info->imageSlideinMoveSpeed = intval($row['image_slidein_move_speed']);

			$info->delayTime = intval($row['delay_time']);
			$info->imageType = intval($row['image_type']);
			$info->playlistPlayType = intval($row['playlist_play_type']);
			$info->playlistPlayWait = intval($row['playlist_play_wait']);

			if(!empty($row['button_item_id'])) {
				$info->itemButtonElement = new ItemButtonElement();
				$info->itemButtonElement->itemId = intval($row['button_item_id']);
				$info->itemButtonElement->width = intval($row['width']);
				$info->itemButtonElement->height = intval($row['height']);
				$info->itemButtonElement->rolloverImage = $row['rollover_image'];
				$info->itemButtonElement->rolloverColor = $row['rollover_color'];
				$info->itemButtonElement->rolloverAlpha = intval($row['rollover_alpha']);
				$info->itemButtonElement->rolloutColor = $row['rollout_color'];
				$info->itemButtonElement->rolloutAlpha = intval($row['rollout_alpha']);
				$info->itemButtonElement->bgImage = $row['bg_image'];
				$info->itemButtonElement->linkUrl = $row['link_url'];
				$info->itemButtonElement->linkUrlTarget = intval($row['link_url_target']);

				if($isAll) {
					require_once 'player_data.php';
					$childElement = new PlayerData($this->userName);
					$playerElement = $childElement->get($domainId, $info->itemId, 0);
					if($playerElement->domainId > 0) {
						$info->itemButtonElement->playerElement = $playerElement;
					}
					$info->itemButtonElement->itemElementList = $this->getList($domainId, $info->itemId, 0, $isAll);
				}
			}

			if(!empty($row['wipe_id'])) {
				$info->itemWipeElement = new ItemWipeElement();
				$info->itemWipeElement->itemId = intval($row['wipe_id']);
				$info->itemWipeElement->type = intval($row['type']);
				$info->itemWipeElement->widthDivideNumber = intval($row['width_divide_number']);
				$info->itemWipeElement->heightDivideNumber = intval($row['height_divide_number']);
				$info->itemWipeElement->widthIsMagnified = (intval($row['width_is_magnified'])===1);
				$info->itemWipeElement->heightIsMagnified = (intval($row['height_is_magnified'])===1);
				$info->itemWipeElement->displayDirection = intval($row['display_direction']);
				$info->itemWipeElement->speed = intval($row['speed']);
				$info->itemWipeElement->diagonalType = intval($row['diagonal_type']);
			}

			if($isAll) {
				$info->playlistItemList = $this->getItemList($domainId, $info->itemId);
			}

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * item_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ItemID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return NewsElement
	 */
	function &get($domainId, $itemId, $isAll = false) {
		$info = new ItemElement();

		$sql  = 'SELECT a.item_id, a.parent_type, a.parent_item_id, a.domain_id, a.name, a.disp_no, a.is_display, a.layer, a.x_axis, a.y_axis, a.image';
		$sql .= ', a.image_fadein_effect, a.image_slidein_angle, a.image_slidein_move_size, image_slidein_move_speed';
		$sql .= ', a.delay_time, a.image_type, a.playlist_play_type, a.playlist_play_wait';
		$sql .= ', b.item_id AS button_item_id, b.width, b.height, b.rollover_color, b.rollover_alpha, b.rollout_color, b.rollout_alpha, b.link_url, b.link_url_target, b.bg_image';
		$sql .= ', b.rollover_image';
		$sql .= ', c.item_id AS wipe_id, c.type, c.width_divide_number, c.height_divide_number, c.width_is_magnified, c.height_is_magnified, c.display_direction, c.speed, c.diagonal_type';
		$sql .= ' FROM item_element a LEFT JOIN item_button b ON a.item_id=b.item_id';
		$sql .= ' LEFT JOIN wipe_setting c ON a.item_id=c.item_id';
		$sql .= ' WHERE domain_id='.intval($domainId);
		$sql .= ' AND a.item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->itemId = intval($row['item_id']);
		$info->parentType = intval($row['parent_type']);
		$info->parentItemId = (empty($row['parent_item_id'])?0:intval($row['parent_item_id']));

		$info->name = $row['name'];
		$info->dispNo = intval($row['disp_no']);
		$info->isDisplay = (intval($row['is_display'])===1);
		$info->layer = intval($row['layer']);
		$info->xAxis = intval($row['x_axis']);
		$info->yAxis = intval($row['y_axis']);
		$info->image = $row['image'];
		$info->imageFadeinEffect = intval($row['image_fadein_effect']);
		$info->imageSlideinAngle = intval($row['image_slidein_angle']);
		$info->imageSlideinMoveSize = intval($row['image_slidein_move_size']);
		$info->imageSlideinMoveSpeed = intval($row['image_slidein_move_speed']);

		$info->delayTime = intval($row['delay_time']);
		$info->imageType = intval($row['image_type']);
		$info->playlistPlayType = intval($row['playlist_play_type']);
		$info->playlistPlayWait = intval($row['playlist_play_wait']);

		if($isAll) {
			if(!empty($row['button_item_id'])) {
				$info->itemButtonElement = new ItemButtonElement();
				$info->itemButtonElement->itemId = intval($row['button_item_id']);
				$info->itemButtonElement->width = intval($row['width']);
				$info->itemButtonElement->height = intval($row['height']);
				$info->itemButtonElement->rolloverImage = $row['rollover_image'];
				$info->itemButtonElement->rolloverColor = $row['rollover_color'];
				$info->itemButtonElement->rolloverAlpha = intval($row['rollover_alpha']);
				$info->itemButtonElement->rolloutColor = $row['rollout_color'];
				$info->itemButtonElement->rolloutAlpha = intval($row['rollout_alpha']);
				$info->itemButtonElement->bgImage = $row['bg_image'];
				$info->itemButtonElement->linkUrl = $row['link_url'];
				$info->itemButtonElement->linkUrlTarget = intval($row['link_url_target']);

				if($isAll) {
					require_once 'player_data.php';
					$childElement = new PlayerData($this->userName);
					$playerElement = $childElement->get($domainId, $info->itemId);
					if($playerElement->domainId > 0) {
						$info->itemButtonElement->playerElement = $playerElement;
					}
					$info->itemButtonElement->itemElementList = $this->getList($domainId, $info->itemId, 0, $isAll);
				}
			}

			if(!empty($row['wipe_id'])) {
				$info->itemWipeElement = new ItemWipeElement();
				$info->itemWipeElement->itemId = intval($row['wipe_id']);
				$info->itemWipeElement->type = intval($row['type']);
				$info->itemWipeElement->widthDivideNumber = intval($row['width_divide_number']);
				$info->itemWipeElement->heightDivideNumber = intval($row['height_divide_number']);
				$info->itemWipeElement->widthIsMagnified = (intval($row['width_is_magnified'])===1);
				$info->itemWipeElement->heightIsMagnified = (intval($row['height_is_magnified'])===1);
				$info->itemWipeElement->displayDirection = intval($row['display_direction']);
				$info->itemWipeElement->speed = intval($row['speed']);
				$info->itemWipeElement->diagonalType = intval($row['diagonal_type']);
			}

			$info->playlistItemList = $this->getItemList($domainId, $info->itemId);
		}

		return $info;
	}

	/**
	 * item_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if(intval($info->itemId) > 0) {
			if(!$this->_updateElement($domainId, $info)) {
				return false;
			}
			$itemId = intval($info->itemId);
		} else {
			if(!$this->_insertElement($domainId, $info)) {
				return false;
			}

			$res = pg_query(self::$dbConn, "SELECT CURRVAL('item_element_item_id_seq') AS currval");
			if($res === FALSE || pg_num_rows($res) !== 1) {
				return false;
			} else {
				$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
				$itemId = intval($row['currval']);
			}
		}

		if($isAll) {
			if(isset($info->itemButtonElement)) {
				if(!$this->setButton($domainId, $itemId, $info->itemButtonElement, $isAll)) {
					return false;
				}
			}

			if(isset($info->itemWipeElement)) {
				$info->itemWipeElement->itemId = $itemId;
				if(!$this->setWipe($domainId, $info->itemWipeElement)) {
					return false;
				}
			}

			foreach($info->playlistItemList as $itemElement) {
				$itemElement->itemId = $itemId;
				if(!$this->setPlaylistItem($domainId, $itemElement)) {
					return false;
				}
			}
		}

		return true;
	}

	private function _insertElement($domainId, $info) {
		$columns  = ' domain_id';
		$values   = ' '.intval($domainId);
		$columns .= ',parent_type';
		$values  .= ','.intval($info->parentType);
		$columns .= ',parent_item_id';
		$values  .= ','.intval($info->parentItemId);
		$columns .= ',name';
		$values  .= ','.$this->dbStr($info->name);
		$columns .= ',disp_no';
		$values  .= ','.intval($info->dispNo);
		$columns .= ',is_display';
		$values  .= ','.($info->isDisplay?1:0);
		$columns .= ',layer';
		$values  .= ','.intval($info->layer);
		$columns .= ',x_axis';
		$values  .= ','.intval($info->xAxis);
		$columns .= ',y_axis';
		$values  .= ','.intval($info->yAxis);
		$columns .= ',image';
		$values  .= ','.$this->dbStr($info->image);
		$columns .= ',image_fadein_effect';
		$values  .= ','.intval($info->imageFadeinEffect);
		$columns .= ',image_slidein_angle';
		$values  .= ','.intval($info->imageSlideinAngle);
		$columns .= ',image_slidein_move_size';
		$values  .= ','.intval($info->imageSlideinMoveSize);
		$columns .= ',image_slidein_move_speed';
		$values  .= ','.intval($info->imageSlideinMoveSpeed);
		$columns .= ',delay_time';
		$values  .= ','.intval($info->delayTime);
		$columns .= ',image_type';
		$values  .= ','.intval($info->imageType);
		$columns .= ',playlist_play_type';
		$values  .= ','.intval($info->playlistPlayType);
		$columns .= ',playlist_play_wait';
		$values  .= ','.intval($info->playlistPlayWait);

		$sql = 'INSERT INTO item_element ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _updateElement($domainId, $info) {
		$setval  = ' parent_item_id='.intval($info->parentItemId);
		$setval .= ',name='.$this->dbStr($info->name);
		$setval .= ',disp_no='.intval($info->dispNo);
		$setval .= ',is_display='.($info->isDisplay?1:0);
		$setval .= ',layer='.intval($info->layer);
		$setval .= ',x_axis='.intval($info->xAxis);
		$setval .= ',y_axis='.intval($info->yAxis);
		$setval .= ',image='.$this->dbStr($info->image);
		$setval .= ',image_fadein_effect='.intval($info->imageFadeinEffect);
		$setval .= ',image_slidein_angle='.intval($info->imageSlideinAngle);
		$setval .= ',image_slidein_move_size='.intval($info->imageSlideinMoveSize);
		$setval .= ',image_slidein_move_speed='.intval($info->imageSlideinMoveSpeed);

		$setval .= ',delay_time='.intval($info->delayTime);
		$setval .= ',image_type='.intval($info->imageType);
		$setval .= ',playlist_play_type='.intval($info->playlistPlayType);
		$setval .= ',playlist_play_wait='.intval($info->playlistPlayWait);

		$sql = 'UPDATE item_element SET '.$setval.' WHERE domain_id='.intval($domainId).' AND item_id='.intval($info->itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 親アイテム表示位置変更
	 * 子階層が参照している表示位置もすべて変更する。
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeTopItemDispNo($domainId, $itemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$sql  = 'SELECT disp_no FROM item_element WHERE parent_item_id=0 AND domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$oldDispNo = intval($row['disp_no']);
		if($newDispNo === $oldDispNo) {
			return true;
		}

		// 一度退避
		$sql = 'UPDATE item_element SET disp_no=0 WHERE domain_id='.intval($domainId).' AND disp_no='.$oldDispNo;
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		if($oldDispNo > $newDispNo) {
			//前に移動
			$sql = 'UPDATE item_element SET disp_no=disp_no+1 WHERE domain_id='.intval($domainId).' AND disp_no>='.intval($newDispNo).' AND disp_no<'.intval($oldDispNo).' AND disp_no<>0';
		} else {
			//後ろに移動
			$sql = 'UPDATE item_element SET disp_no=disp_no-1 WHERE domain_id='.intval($domainId).' AND disp_no>'.intval($oldDispNo).' AND disp_no<='.intval($newDispNo).' AND disp_no<>0';
		}
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE item_element SET disp_no='.intval($newDispNo).' WHERE domain_id='.intval($domainId).' AND disp_no=0';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 削除可能かチェックする
	 * 親階層の場合、子階層が無いかつ操作対象に指定されていないことが条件。
	 * 子階層の場合、子階層が無いことが条件。
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 可否
	 */
	function isCanDelete($domainId, $itemId) {

		$sql  = 'SELECT a.parent_item_id, (SELECT COUNT(b.item_id) FROM item_element b WHERE b.parent_item_id=a.item_id AND b.domain_id=a.domain_id AND b.parent_type=0) AS child_cnt';
		$sql .= ', (SELECT COUNT(c.item_id) FROM item_element c WHERE c.disp_no = a.disp_no AND c.item_id <> a.item_id AND c.domain_id=a.domain_id) AS no_cnt';
		$sql .= ' FROM item_element a';
		$sql .= ' WHERE a.domain_id='.intval($domainId);
		$sql .= ' AND a.item_id='.intval($itemId);

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		if(intval($row['parent_item_id']) > 0 && intval($row['child_cnt']) === 0) {
			return true;
		} else if(intval($row['parent_item_id']) === 0 && intval($row['child_cnt']) === 0 && intval($row['no_cnt']) === 0) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * アイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $itemId) {
		$sql  = 'SELECT disp_no, parent_item_id FROM item_element WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$dispNo = intval($row['disp_no']);
		$parentItemId = intval($row['parent_item_id']);

		$sql = 'DELETE FROM playlist_item WHERE player_id IN (SELECT player_id FROM player_element WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId).' AND parent_type = 0)';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM player_element WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId).' AND parent_type=0';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM item_button WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM wipe_setting WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM imagelist_item WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM item_element WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		if($parentItemId === 0) {
			$sql = 'UPDATE item_element SET disp_no=disp_no-1 WHERE domain_id='.intval($domainId).' AND disp_no>'.intval($dispNo);
			$res = pg_query(self::$dbConn, $sql);
			if($res === FALSE) {
				return false;
			} else {
				return true;
			}
		} else {
			return true;
		}
	}

	/**
	 * 指定した表示順が利用中かどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @param $dispNo [in] チェック対象表示位置
	 * @return unknown_type
	 */
	function isUseDispNo($domainId, $parentItemId, $parentType, $dispNo) {
		$sql  = 'SELECT COUNT(disp_no) AS cnt  FROM item_element WHERE domain_id='.intval($domainId).' AND parent_item_id='.intval($parentItemId).' AND parent_type='.intval($parentType).'  AND disp_no='.intval($dispNo);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return true;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return (intval($row['cnt']) > 0);
	}

	//////////////////////////
	// ボタン

	/**
	 * ボタンを利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 利用状況
	 */
	function isUseButton($domainId, $itemId) {
		$sql = 'SELECT item_id FROM item_button WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * プレイヤーを利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $parentType [in] 親アイテム種別
	 * @return bool 利用状況
	 */
	function isUsePlayer($domainId, $itemId, $parentType = 0) {
		$sql = 'SELECT player_id FROM player_element WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId).' AND parent_type='.intval($parentType);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		} else {
			return true;
		}
	}
	/**
	 * item_button_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function setButton($domainId, $itemId, $info, $isAll = false) {
		$sql = 'SELECT item_id FROM item_button WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$cnt = pg_num_rows($res);
		if($cnt > 1) {
			return false;
		} else if($cnt === 1) {
			if(!$this->_updateButtonElement($info)) {
				return false;
			}
		} else {
			if(!$this->_insertButtonElement(intval($itemId), $info)) {
				return false;
			}
		}

		if($isAll) {
			if(isset($info->playerElement)) {
				require_once 'player_data.php';
				$childElement = new PlayerData($this->userName);
				$info->playerElement->itemId = $itemId;
				if(!$childElement->set($domainId, $info->playerElement, $isAll)) {
					return false;
				}
			}
			if(count($info->itemElementList) > 0) {
				foreach($info->itemElementList as $itemElement) {
					$itemElement->parentItemId = $itemId;
					if(!$this->set($domainId, $itemElement, $isAll)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	private function _insertButtonElement($itemId, $info) {
		$columns  = ' item_id';
		$values   = ' '.intval($itemId);
		$columns .= ',width';
		$values  .= ','.intval($info->width);
		$columns .= ',height';
		$values  .= ','.intval($info->height);
		$columns .= ',rollover_image';
		$values  .= ','.$this->dbStr($info->rolloverImage);
		$columns .= ',rollover_color';
		$values  .= ','.$this->dbStr($info->rolloverColor);
		$columns .= ',rollover_alpha';
		$values  .= ','.intval($info->rolloverAlpha);
		$columns .= ',rollout_color';
		$values  .= ','.$this->dbStr($info->rolloutColor);
		$columns .= ',rollout_alpha';
		$values  .= ','.intval($info->rolloutAlpha);
		$columns .= ',link_url';
		$values  .= ','.$this->dbStr($info->linkUrl);
		$columns .= ',link_url_target';
		$values  .= ','.intval($info->linkUrlTarget);
		$columns .= ',bg_image';
		$values  .= ','.$this->dbStr($info->bgImage);

		$sql = 'INSERT INTO item_button ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _updateButtonElement($info) {
		$setval  = ' width='.intval($info->width);
		$setval .= ',height='.intval($info->height);
		$setval .= ',rollover_image='.$this->dbStr($info->rolloverImage);
		$setval .= ',rollover_color='.$this->dbStr($info->rolloverColor);
		$setval .= ',rollover_alpha='.intval($info->rolloverAlpha);
		$setval .= ',rollout_color='.$this->dbStr($info->rolloutColor);
		$setval .= ',rollout_alpha='.intval($info->rolloutAlpha);
		$setval .= ',link_url='.$this->dbStr($info->linkUrl);
		$setval .= ',link_url_target='.intval($info->linkUrlTarget);
		$setval .= ',bg_image='.$this->dbStr($info->bgImage);

		$sql = 'UPDATE item_button SET '.$setval.' WHERE item_id='.intval($info->itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}


/**
	 * item_button_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ItemID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return NewsElement
	 */
	function &getButton($domainId, $itemId, $isAll = false) {
		$info = new ItemButtonElement();

		$sql  = 'SELECT b.item_id, b.width, b.height, b.rollover_color, b.rollover_alpha, b.rollout_color, b.rollout_alpha, b.link_url, b.link_url_target, b.bg_image';
		$sql .= ', b.rollover_image';
		$sql .= ' FROM item_button b';
		$sql .= ' WHERE b.item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->itemId = intval($row['item_id']);
		$info->width = intval($row['width']);
		$info->height = intval($row['height']);
		$info->rolloverImage = $row['rollover_image'];
		$info->rolloverColor = $row['rollover_color'];
		$info->rolloverAlpha = intval($row['rollover_alpha']);
		$info->rolloutColor = $row['rollout_color'];
		$info->rolloutAlpha = intval($row['rollout_alpha']);
		$info->bgImage = $row['bg_image'];
		$info->linkUrl = $row['link_url'];
		$info->linkUrlTarget = intval($row['link_url_target']);

		if($isAll) {
			require_once 'player_data.php';
			$childElement = new PlayerData($this->userName);
			$playerElement = $childElement->get($domainId, $info->itemId);
			if($playerElement->domainId > 0) {
				$info->playerElement = $playerElement;
			}
			$info->itemElementList = $this->getList($domainId, $info->itemId, 0, $isAll);
		}

		return $info;
	}

	/**
	 * ボタンアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 成功/失敗
	 */
	function deleteButton($domainId, $itemId) {
		$sql = 'DELETE FROM playlist_item WHERE player_id IN (SELECT player_id FROM player_element WHERE parent_type=0 AND domain_id='.intval($domainId).' AND item_id='.intval($itemId).')';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM player_element WHERE parent_type=0 AND domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM item_button WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 操作対象表示番号一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 所属アイテムID
	 * @param $parentType [in] 親アイテム種別
	 * @return array キー：表示順／値：名前
	 */
	function &getTargetDispNoList($domainId, $parentItemId, $parentType = 0) {
		$list = array();

		$sql  = 'SELECT item_id, disp_no, name FROM item_element WHERE domain_id='.intval($domainId).' AND parent_item_id=0';
		$sql .= ' AND disp_no NOT IN (SELECT disp_no FROM item_element WHERE domain_id='.intval($domainId).' AND parent_item_id='.intval($parentItemId).' AND parent_type='.intval($parentType).')';
		$sql .= ' ORDER BY disp_no ASC, item_id ASC';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$list[intval($row['disp_no'])] = $row['name'];
		}

		return $list;


	}


	/**
	 * 削除可能かチェックする
	 * 子階層が無いことが条件。
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 可否
	 */
	function isCanDeleteButton($domainId, $itemId) {

		$sql  = 'SELECT COUNT(item_id) AS child_cnt';
		$sql .= ' FROM item_element';
		$sql .= ' WHERE domain_id='.intval($domainId);
		$sql .= ' AND parent_item_id='.intval($itemId);
		$sql .= ' AND parent_type=0';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		if(intval($row['child_cnt']) === 0) {
			return true;
		} else {
			return false;
		}
	}

	//////////////////////////
	// 表示効果設定

	/**
	 * 表示効果を利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 利用状況
	 */
	function isUseWipe($domainId, $itemId) {
		$sql = 'SELECT item_id FROM wipe_setting WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 表示効果取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return ItemWipeElement
	 */
	function &getWipe($domainId, $itemId) {
		$info = new ItemWipeElement();

		$sql = 'SELECT * FROM wipe_setting WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->type = intval($row['type']);
		$info->widthDivideNumber = intval($row['width_divide_number']);
		$info->heightDivideNumber = intval($row['height_divide_number']);
		$info->widthIsMagnified = (intval($row['width_is_magnified'])===1);
		$info->heightIsMagnified = (intval($row['height_is_magnified'])===1);
		$info->displayDirection = intval($row['display_direction']);
		$info->speed = intval($row['speed']);
		$info->diagonalType = intval($row['diagonal_type']);

		$info->itemId = intval($row['item_id']);

		return $info;

	}

	/**
	 * wipe_settingにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemElement
	 * @return bool 成功/失敗
	 */
	function setWipe($domainId, $info) {
		$sql = 'SELECT item_id FROM wipe_setting WHERE item_id='.intval($info->itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$cnt = pg_num_rows($res);
		if($cnt > 1) {
			return false;
		} else if($cnt === 1) {
			if(!$this->_updateWipeElement($info)) {
				return false;
			}
		} else {
			if(!$this->_insertWipeElement($info)) {
				return false;
			}
		}

		return true;
	}

	private function _insertWipeElement($info) {
		$columns  = ' item_id';
		$values   = ' '.intval($info->itemId);
		$columns .= ',type';
		$values  .= ','.intval($info->type);
		$columns .= ',width_divide_number';
		$values  .= ','.intval($info->widthDivideNumber);
		$columns .= ',height_divide_number';
		$values  .= ','.intval($info->heightDivideNumber);
		$columns .= ',width_is_magnified';
		$values  .= ','.($info->widthIsMagnified?1:0);
		$columns .= ',height_is_magnified';
		$values  .= ','.($info->heightIsMagnified?1:0);
		$columns .= ',display_direction';
		$values  .= ','.intval($info->displayDirection);
		$columns .= ',speed';
		$values  .= ','.intval($info->speed);
		$columns .= ',diagonal_type';
		$values  .= ','.intval($info->diagonalType);

		$sql = 'INSERT INTO wipe_setting ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _updateWipeElement($info) {
		$setval  = ' type='.intval($info->type);
		$setval .= ',width_divide_number='.intval($info->widthDivideNumber);
		$setval .= ',height_divide_number='.intval($info->heightDivideNumber);
		$setval .= ',width_is_magnified='.($info->widthIsMagnified?1:0);
		$setval .= ',height_is_magnified='.($info->heightIsMagnified?1:0);
		$setval .= ',display_direction='.intval($info->displayDirection);
		$setval .= ',speed='.intval($info->speed);
		$setval .= ',diagonal_type='.intval($info->diagonalType);

		$sql = 'UPDATE wipe_setting SET '.$setval.' WHERE item_id='.intval($info->itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 表示効果削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 成功/失敗
	 */
	function deleteWipe($domainId, $itemId) {
		$sql = 'DELETE FROM wipe_setting WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	//////////////////////////
	// プレイリストアイテム

	/**
	 * プレイリストのアイテム一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return array ItemPlayListItem一覧
	 */
	function &getItemList($domainId, $itemId) {
		$list = array();

		$sql = 'SELECT * FROM imagelist_item WHERE item_id='.intval($itemId).' ORDER BY disp_no';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$itemInfo = new ItemPlayListItem();
			$itemInfo->dispNo = intval($row['disp_no']);
			$itemInfo->name = $row['name'];
			$itemInfo->image = $row['image'];
			$itemInfo->linkUrl = $row['link_url'];
			$itemInfo->linkUrlTarget = intval($row['link_url_target']);
			$itemInfo->itemId = intval($row['item_id']);
			$itemInfo->playlistItemId = intval($row['imagelist_item_id']);

			$list[$itemInfo->dispNo] = $itemInfo;
		}

		return $list;
	}

	/**
	 * プレイリストアイテム取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @return ItemPlayListItem
	 */
	function &getPlayListItem($domainId, $itemId, $playlistItemId) {
		$itemInfo = new ItemPlayListItem();

		$sql = 'SELECT * FROM imagelist_item WHERE imagelist_item_id='.intval($playlistItemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $itemInfo;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$itemInfo->dispNo = intval($row['disp_no']);
		$itemInfo->name = $row['name'];
		$itemInfo->image = $row['image'];
		$itemInfo->linkUrl = $row['link_url'];
		$itemInfo->linkUrlTarget = intval($row['link_url_target']);
		$itemInfo->itemId = intval($row['item_id']);
		$itemInfo->playlistItemId = intval($row['imagelist_item_id']);

		return $itemInfo;
	}

	/**
	 * itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function setPlaylistItem($domainId, $info) {
		if($info->playlistItemId > 0) {
			if(!$this->updatePlaylistItemElement($domainId, $info)) {
				return false;
			}
		} else {
			if($this->insertPlaylistItemElement($domainId, $info) === 0) {
				return false;
			}
		}

		return true;
	}

	/**
	 * アイテムを挿入する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemPlayListItem
	 * @return intval アイテムID
	 */
	function insertPlaylistItemElement($domainId, $info) {
		$columns  = ' item_id';
		$values   = ' '.intval($info->itemId);
		$columns .= ',disp_no';
		$values  .= ','.intval($info->dispNo);
		$columns .= ',name';
		$values  .= ','.$this->dbStr($info->name);
		$columns .= ',image';
		$values  .= ','.$this->dbStr($info->image);
		$columns .= ',link_url';
		$values  .= ','.$this->dbStr($info->linkUrl);
		$columns .= ',link_url_target';
		$values  .= ','.intval($info->linkUrlTarget);

		$sql = 'INSERT INTO imagelist_item ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		if($res !== FALSE) {
			$res = pg_query(self::$dbConn, "SELECT CURRVAL('imagelist_item_imagelist_item_id_seq') AS currval");
			if($res === FALSE || pg_num_rows($res) !== 1) {
				return 0;
			} else {
				$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
				return intval($row['currval']);
			}

		} else {
			return 0;
		}
	}

	/**
	 * アイテムを更新する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemPlayListItem
	 * @return bool 成功/失敗
	 */
	function updatePlaylistItemElement($domainId, $info) {
		$setval  = ' item_id='.intval($info->itemId);
		$setval .= ',disp_no='.intval($info->dispNo);
		$setval .= ',name='.$this->dbStr($info->name);
		$setval .= ',image='.$this->dbStr($info->image);
		$setval .= ',link_url='.$this->dbStr($info->linkUrl);
		$setval .= ',link_url_target='.intval($info->linkUrlTarget);

		$sql = 'UPDATE imagelist_item SET '.$setval.' WHERE imagelist_item_id='.intval($info->playlistItemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 表示順の最大値取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] プレイヤーID
	 * @return intval 表示順の最大値
	 */
	function getPlaylistItemMaxDispNo($domainId, $itemId) {
		$sql = 'SELECT MAX(disp_no) AS max_value FROM imagelist_item WHERE item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return 0;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return intval($row['max_value']);
	}
	/**
	 * 表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changePlaylistItemDispNo($domainId, $itemId, $playlistItemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$sql  = 'SELECT disp_no FROM imagelist_item WHERE imagelist_item_id='.intval($playlistItemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$oldDispNo = intval($row['disp_no']);
		if($newDispNo === $oldDispNo) {
			return true;
		}

		if($oldDispNo > $newDispNo) {
			//前に移動
			$sql = 'UPDATE imagelist_item SET disp_no=disp_no+1 WHERE item_id='.intval($itemId).' AND disp_no>='.intval($newDispNo).' AND disp_no<'.intval($oldDispNo);
		} else {
			//後ろに移動
			$sql = 'UPDATE imagelist_item SET disp_no=disp_no-1 WHERE item_id='.intval($itemId).' AND disp_no>'.intval($oldDispNo).' AND disp_no<='.intval($newDispNo);
		}
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE imagelist_item SET disp_no='.intval($newDispNo).' WHERE imagelist_item_id='.intval($playlistItemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * プレイリストアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @return bool 成功/失敗
	 */
	function deletePlaylistItem($domainId, $itemId, $playlistItemId) {
		$sql  = 'SELECT disp_no FROM imagelist_item WHERE imagelist_item_id='.intval($playlistItemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$dispNo = intval($row['disp_no']);

		$sql = 'DELETE FROM imagelist_item WHERE imagelist_item_id='.intval($playlistItemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE imagelist_item SET disp_no=disp_no-1 WHERE item_id='.intval($itemId).' AND disp_no>'.intval($dispNo);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}
}

?>