<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class NewsData extends DataAccessBase {

	/**
	 * news_element登録状況確認
	 * @param $domainId [in] ドメインID
	 * @return bool 登録状況
	 */
	function isRegist($domainId) {
		$sql  = 'SELECT domain_id FROM news_element WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * news_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return NewsElement
	 */
	function &get($domainId, $isAll = false) {
		$info = new NewsElement();

		$sql  = 'SELECT is_display, display_type, text_display_type, slide_wait_time, scroll_move_pixel, x_axis, y_axis, width, height, padding, text_color, text_shadow_color';
		$sql .= ' FROM news_element WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->isDisplay = (intval($row['is_display'])===1);
		$info->displayType = intval($row['display_type']);
		$info->textDisplaytType = intval($row['text_display_type']);
		$info->slideWaitTime = intval($row['slide_wait_time']);
		$info->scrollMovePixel = floatval($row['scroll_move_pixel']);
		$info->xAxis = intval($row['x_axis']);
		$info->yAxis = intval($row['y_axis']);
		$info->width = intval($row['width']);
		$info->height = intval($row['height']);
		$info->padding = intval($row['padding']);
		$info->textColor = $row['text_color'];
		$info->textShadowColor = $row['text_shadow_color'];
		$info->domainId = intval($domainId);

		if($isAll) {
			$info->skinElement = $this->getSkin($domainId);

			$info->itemElementList = $this->getItemList($domainId);
		}

		return $info;
	}

	/**
	 * news_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		$sql = 'SELECT domain_id FROM news_element WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$cnt = pg_num_rows($res);
		if($cnt > 1) {
			return false;
		} else if($cnt === 1) {
			if(!$this->_updateNewsElement($domainId, $info)) {
				return false;
			}
		} else {
			if(!$this->_insertNewsElement($domainId, $info)) {
				return false;
			}
		}

		if($isAll) {
			if(isset($info->skinElement)) {
				if(!$this->setSkin($domainId, $info->skinElement)) {
					return false;
				}
			}

			if(count($info->itemElementList) > 0) {
				foreach($info->itemElementList as $itemElement) {
					if(!$this->setItem($domainId, $itemElement)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	private function _insertNewsElement($domainId, $info) {
		$columns  = ' domain_id';
		$values   = ' '.intval($domainId);
		$columns .= ',is_display';
		$values  .= ','.($info->isDisplay?1:0);
		$columns .= ',display_type';
		$values  .= ','.intval($info->displayType);
		$columns .= ',text_display_type';
		$values  .= ','.intval($info->textDisplaytType);
		$columns .= ',slide_wait_time';
		$values  .= ','.intval($info->slideWaitTime);
		$columns .= ',scroll_move_pixel';
		$values  .= ','.floatval($info->scrollMovePixel);
		$columns .= ',x_axis';
		$values  .= ','.intval($info->xAxis);
		$columns .= ',y_axis';
		$values  .= ','.intval($info->yAxis);
		$columns .= ',width';
		$values  .= ','.intval($info->width);
		$columns .= ',height';
		$values  .= ','.intval($info->height);
		$columns .= ',padding';
		$values  .= ','.intval($info->padding);
		$columns .= ',text_color';
		$values  .= ','.$this->dbStr($info->textColor);
		$columns .= ',text_shadow_color';
		$values  .= ','.$this->dbStr($info->textShadowColor);

		$sql = 'INSERT INTO news_element ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _updateNewsElement($domainId, $info) {
		$setval  = ' is_display='.($info->isDisplay?1:0);
		$setval .= ',display_type='.intval($info->displayType);
		$setval .= ',text_display_type='.intval($info->textDisplaytType);
		$setval .= ',slide_wait_time='.intval($info->slideWaitTime);
		$setval .= ',scroll_move_pixel='.floatval($info->scrollMovePixel);
		$setval .= ',x_axis='.intval($info->xAxis);
		$setval .= ',y_axis='.intval($info->yAxis);
		$setval .= ',width='.intval($info->width);
		$setval .= ',height='.intval($info->height);
		$setval .= ',padding='.intval($info->padding);
		$setval .= ',text_color='.$this->dbStr($info->textColor);
		$setval .= ',text_shadow_color='.$this->dbStr($info->textShadowColor);

		$sql = 'UPDATE news_element SET '.$setval.' WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/////////////
	/**
	 * news_skinを取得する
	 * @param $domainId [in] ドメインID
	 * @return NewsSkinElement
	 */
	function &getSkin($domainId) {
		$info = new NewsSkinElement();

		$sql  = 'SELECT main_is_display_gradation, main_gradation_alpha, main_bg_color, main_bg_alpha, inner_is_display_gradation, inner_gradation_alpha, inner_bg_color, inner_bg_alpha';
		$sql .= ' FROM news_skin WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->mainIsDisplayGradation = (intval($row['main_is_display_gradation'])===1);
		$info->mainGradationAlpha = intval($row['main_gradation_alpha']);
		$info->mainBgColor = $row['main_bg_color'];
		$info->mainBgAlpha = intval($row['main_bg_alpha']);
		$info->innerIsDisplayGradation = (intval($row['inner_is_display_gradation'])===1);
		$info->innerGradationAlpha = intval($row['inner_gradation_alpha']);
		$info->innerBgColor = $row['inner_bg_color'];
		$info->innerBgAlpha = intval($row['inner_bg_alpha']);

		return $info;
	}

	/**
	 * news_skinにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsSkinElement
	 * @return bool 成功/失敗
	 */
	function setSkin($domainId, $info) {
		$sql = 'SELECT domain_id FROM news_skin WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$cnt = pg_num_rows($res);
		if($cnt > 1) {
			return false;
		} else if($cnt === 1) {
			if(!$this->_updateNewsSkinElement($domainId, $info)) {
				return false;
			}
		} else {
			if(!$this->_insertNewsSkinElement($domainId, $info)) {
				return false;
			}
		}

		return true;
	}

	private function _insertNewsSkinElement($domainId, $info) {
		$columns  = ' domain_id';
		$values   = ' '.intval($domainId);
		$columns .= ',main_is_display_gradation';
		$values  .= ','.($info->mainIsDisplayGradation?1:0);
		$columns .= ',main_gradation_alpha';
		$values  .= ','.intval($info->mainGradationAlpha);
		$columns .= ',main_bg_color';
		$values  .= ','.$this->dbStr($info->mainBgColor);
		$columns .= ',main_bg_alpha';
		$values  .= ','.intval($info->mainBgAlpha);
		$columns .= ',inner_is_display_gradation';
		$values  .= ','.($info->innerIsDisplayGradation?1:0);
		$columns .= ',inner_gradation_alpha';
		$values  .= ','.intval($info->innerGradationAlpha);
		$columns .= ',inner_bg_color';
		$values  .= ','.$this->dbStr($info->innerBgColor);
		$columns .= ',inner_bg_alpha';
		$values  .= ','.intval($info->innerBgAlpha);

		$sql = 'INSERT INTO news_skin ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _updateNewsSkinElement($domainId, $info) {
		$setval  = ' main_is_display_gradation='.($info->mainIsDisplayGradation?1:0);
		$setval .= ',main_gradation_alpha='.intval($info->mainGradationAlpha);
		$setval .= ',main_bg_color='.$this->dbStr($info->mainBgColor);
		$setval .= ',main_bg_alpha='.intval($info->mainBgAlpha);
		$setval .= ',inner_is_display_gradation='.($info->innerIsDisplayGradation?1:0);
		$setval .= ',inner_gradation_alpha='.intval($info->innerGradationAlpha);
		$setval .= ',inner_bg_color='.$this->dbStr($info->innerBgColor);
		$setval .= ',inner_bg_alpha='.intval($info->innerBgAlpha);

		$sql = 'UPDATE news_skin SET '.$setval.' WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/////////////
	/**
	 * news_item一覧を取得する
	 * @param $domainId [in] ドメインID
	 * @return NewsItemElement
	 */
	function &getItemList($domainId) {
		$list = array();

		$sql  = 'SELECT item_id, domain_id, disp_no, title, url, url_target';
		$sql .= ' FROM news_item WHERE domain_id='.intval($domainId);
		$sql .= ' ORDER BY disp_no ASC, item_id ASC';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$info = new NewsItemElement();
			$info->itemId = intval($row['item_id']);

			$info->dispNo =intval($row['disp_no']);
			$info->title = $row['title'];
			$info->url = $row['url'];
			$info->urlTarget = intval($row['url_target']);

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * news_itemを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ニュース記事ID
	 * @return NewsItemElement
	 */
	function &getItem($domainId, $itemId) {
		$info = new NewsItemElement();

		$sql  = 'SELECT item_id, domain_id, disp_no, title, url, url_target';
		$sql .= ' FROM news_item WHERE domain_id='.intval($domainId);
		$sql .= ' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->itemId = intval($row['item_id']);
		$info->dispNo =intval($row['disp_no']);
		$info->title = $row['title'];
		$info->url = $row['url'];
		$info->urlTarget = intval($row['url_target']);

		return $info;
	}

	/**
	 * news_itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function setItem($domainId, $info) {
		if($info->itemId > 0) {
			if(!$this->updateNewsItemElement($domainId, $info)) {
				return false;
			}
		} else {
			if($this->insertNewsItemElement($domainId, $info) === 0) {
				return false;
			}
		}

		return true;
	}

	/**
	 * アイテムを挿入する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return intval アイテムID
	 */
	function insertNewsItemElement($domainId, $info) {
		$columns  = ' domain_id';
		$values   = ' '.intval($domainId);
		$columns .= ',disp_no';
		$values  .= ','.intval($info->dispNo);
		$columns .= ',title';
		$values  .= ','.$this->dbStr($info->title);
		$columns .= ',url';
		$values  .= ','.$this->dbStr($info->url);
		$columns .= ',url_target';
		$values  .= ','.intval($info->urlTarget);

		$sql = 'INSERT INTO news_item ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return 0;
		} else {
			$res = pg_query(self::$dbConn, "SELECT CURRVAL('news_item_item_id_seq') AS currval");
			if($res === FALSE || pg_num_rows($res) !== 1) {
				return 0;
			} else {
				$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
				return intval($row['currval']);
			}
		}
	}

	/**
	 * アイテムを更新する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function updateNewsItemElement($domainId, $info) {
		$setval  = ' disp_no='.intval($info->dispNo);
		$setval .= ',title='.$this->dbStr($info->title);
		$setval .= ',url='.$this->dbStr($info->url);
		$setval .= ',url_target='.intval($info->urlTarget);

		$sql = 'UPDATE news_item SET '.$setval.' WHERE domain_id='.intval($domainId).' AND item_id='.intval($info->itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ニュースアイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeDispNo($domainId, $itemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$sql  = 'SELECT disp_no FROM news_item WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$oldDispNo = intval($row['disp_no']);
		if($newDispNo === $oldDispNo) {
			return true;
		}

		if($oldDispNo > $newDispNo) {
			//前に移動
			$sql = 'UPDATE news_item SET disp_no=disp_no+1 WHERE domain_id='.intval($domainId).' AND disp_no>='.intval($newDispNo).' AND disp_no<'.intval($oldDispNo);
		} else {
			//後ろに移動
			$sql = 'UPDATE news_item SET disp_no=disp_no-1 WHERE domain_id='.intval($domainId).' AND disp_no>'.intval($oldDispNo).' AND disp_no<='.intval($newDispNo);
		}
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE news_item SET disp_no='.intval($newDispNo).' WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * ニュースアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ニュースアイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $itemId) {
		$sql  = 'SELECT disp_no FROM news_item WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$dispNo = intval($row['disp_no']);

		$sql = 'DELETE FROM news_item WHERE domain_id='.intval($domainId).' AND item_id='.intval($itemId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE news_item SET disp_no=disp_no-1 WHERE domain_id='.intval($domainId).' AND disp_no>'.intval($dispNo);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * 表示順の最大値取得
	 * @param $domainId [in] ドメインID
	 * @return intval 表示順の最大値
	 */
	function getMaxDispNo($domainId) {
		$sql  = 'SELECT MAX(disp_no) as max FROM news_item WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return 0;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return intval($row['max']);
	}
}