<?php
require_once dirname(__FILE__).'/../../photo_xml.php';

class PhotoImageItem extends DataAccessBase {

	/**
	 * アイテムの最大表示順(件数から割り出したもの)を取得する
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @return intval 最大の表示順
	 */
	function getMaxDispNo($domainId, $photoId) {
		$sql  = 'SELECT COUNT(disp_no) AS max FROM photo_image_item WHERE photo_id='.intval($photoId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return 0;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return intval($row['max']);
	}

	/**
	 * photo_image_item一覧を取得する
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return PhotoImageItemElemet
	 */
	function &getList($domainId, $photoId, $isAll = false) {
		$list = array();

		$sql  = 'SELECT a.image_id, a.name, a.disp_no, a.image_url';
		$sql .= ' FROM photo_image_item a ';
		$sql .= ' WHERE photo_id='.intval($photoId);
		$sql .= ' ORDER BY disp_no ASC, photo_id ASC';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$info = new PhotoImageItemElemet();
			$info->imageId = intval($row['image_id']);
			$info->photoId = intval($photoId);
			$info->dispNo = intval($row['disp_no']);
			$info->name = $row['name'];
			$info->imageUrl = $row['image_url'];

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * photo_image_itemを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return PhotoImageItemElemet
	 */
	function &get($domainId, $photoId, $imageId, $isAll = false) {
		$info = new PhotoImageItemElemet();

		$sql  = 'SELECT a.image_id, a.name, a.disp_no, a.image_url';
		$sql .= ' FROM photo_image_item a';
		$sql .= ' WHERE photo_id='.intval($photoId).' AND a.image_id='.intval($imageId);
		$sql .= ' ORDER BY disp_no ASC, photo_id ASC';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info = new PhotoImageItemElemet();
		$info->imageId = intval($row['image_id']);
		$info->photoId = intval($photoId);
		$info->dispNo = intval($row['disp_no']);
		$info->name = $row['name'];
		$info->imageUrl = $row['image_url'];

		return $info;
	}

	/**
	 * photo_image_itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] PhotoImageItemElemet
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if(intval($info->imageId > 0)) {
			if(!$this->_updateElement($info)) {
				return false;
			}
			$imageId = intval($info->imageId);
		} else {
			if(!$this->_insertElement($info)) {
				return false;
			}

			$res = pg_query(self::$dbConn, "SELECT CURRVAL('photo_image_item_image_id_seq') AS currval");
			if($res === FALSE || pg_num_rows($res) !== 1) {
				return false;
			} else {
				$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
				$imageId = intval($row['currval']);
			}
		}

		return true;
	}

	private function _insertElement($info) {
		$columns  = ' photo_id';
		$values   = ' '.intval($info->photoId);
		$columns .= ',name';
		$values  .= ','.$this->dbStr($info->name);
		$columns .= ',disp_no';
		$values  .= ','.intval($info->dispNo);
		$columns .= ',image_url';
		$values  .= ','.$this->dbStr($info->imageUrl);

		$sql = 'INSERT INTO photo_image_item ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _updateElement($info) {
		$setval  = ' name='.$this->dbStr($info->name);
		$setval .= ',disp_no='.intval($info->dispNo);
		$setval .= ',image_url='.$this->dbStr($info->imageUrl);

		$sql = 'UPDATE photo_image_item SET '.$setval.' WHERE photo_id='.intval($info->photoId).' AND image_id='.intval($info->imageId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * イメージアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @param $imageId [in] イメージアイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $photoId, $imageId) {
		$sql  = 'SELECT disp_no FROM photo_image_item WHERE photo_id='.intval($photoId).' AND image_id='.intval($imageId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$dispNo = intval($row['disp_no']);

		$sql = 'DELETE FROM photo_image_item WHERE photo_id='.intval($photoId).' AND image_id='.intval($imageId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE photo_image_item SET disp_no=disp_no-1 WHERE photo_id='.intval($photoId).' AND disp_no>'.intval($dispNo);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * アイテム表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeDispNo($domainId, $photoId, $imageId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$sql  = 'SELECT disp_no FROM photo_image_item WHERE photo_id='.intval($photoId).' AND image_id='.intval($imageId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$oldDispNo = intval($row['disp_no']);
		if($newDispNo === $oldDispNo) {
			return true;
		}

		if($oldDispNo > $newDispNo) {
			//前に移動
			$sql = 'UPDATE photo_image_item SET disp_no=disp_no+1 WHERE photo_id='.intval($photoId).' AND disp_no>='.intval($newDispNo).' AND disp_no<'.intval($oldDispNo).' AND disp_no<>0';
		} else {
			//後ろに移動
			$sql = 'UPDATE photo_image_item SET disp_no=disp_no-1 WHERE photo_id='.intval($photoId).' AND disp_no>'.intval($oldDispNo).' AND disp_no<='.intval($newDispNo).' AND disp_no<>0';
		}
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'UPDATE photo_image_item SET disp_no='.intval($newDispNo).' WHERE photo_id='.intval($photoId).' AND image_id='.intval($imageId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}
}

?>
