<?php
require_once dirname(__FILE__).'/../../slider_xml.php';

class SliderXml extends DataAccessBase {

	/**
	 * スライダー一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $isAll  [in] 子ノードも処理するかどうか
	 * @return array SliderXmlInfo配列
	 */
	function &getList($domainId, $isAll = false) {
		$list = array();

		$sql  = 'SELECT slider_id, number, name, direction_type, is_mirror_effect, is_blur_effect, bg_color, bg_alpha, width, height, thumb_width, thumb_height, sort_type';
		$sql .= ' FROM slider_data';
		$sql .= ' WHERE domain_id='.intval($domainId);
		$sql .= ' ORDER BY number ASC, slider_id ASC';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return $list;
		}

		while($row = pg_fetch_array($res, NULL, PGSQL_ASSOC)) {
			$info = new SliderXmlInfo();
			$info->sliderId = intval($row['slider_id']);
			$info->number = intval($row['number']);
			$info->name = $row['name'];
			$info->directionType = intval($row['direction_type']);
			$info->isMirrorEffect = (intval($row['is_mirror_effect'])===1);
			$info->isBlurEffect = (intval($row['is_blur_effect'])===1);
			$info->bgColor = $row['bg_color'];
			$info->bgAlpha = intval($row['bg_alpha']);
			$info->width = intval($row['width']);
			$info->height = intval($row['height']);
			$info->thumbWidth = intval($row['thumb_width']);
			$info->thumbHeight = intval($row['thumb_height']);
			$info->sortType = intval($row['sort_type']);

			if($isAll) {
				require_once 'image_item.php';
				$childElement = new SliderImageItem($this->userName);
				$info->imageItemList = $childElement->getList($domainId, $info->sliderId, $isAll);
			}

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * slider_dataを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return FlagXmlInfo
	 */
	function &get($domainId, $sliderId, $isAll = false) {
		$info = new SliderXmlInfo();

		$sql  = 'SELECT slider_id, number, name, direction_type, is_mirror_effect, is_blur_effect, bg_color, bg_alpha, width, height, thumb_width, thumb_height, sort_type';
		$sql .= ' FROM slider_data';
		$sql .= ' WHERE domain_id='.intval($domainId).' AND slider_id='.intval($sliderId);
		$sql .= ' ORDER BY number ASC, slider_id ASC';

		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return $info;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		$info->sliderId = intval($row['slider_id']);
		$info->number = intval($row['number']);
		$info->name = $row['name'];
		$info->directionType = intval($row['direction_type']);
		$info->isMirrorEffect = (intval($row['is_mirror_effect'])===1);
		$info->isBlurEffect = (intval($row['is_blur_effect'])===1);
		$info->bgColor = $row['bg_color'];
		$info->bgAlpha = intval($row['bg_alpha']);
		$info->width = intval($row['width']);
		$info->height = intval($row['height']);
		$info->thumbWidth = intval($row['thumb_width']);
		$info->thumbHeight = intval($row['thumb_height']);
		$info->sortType = intval($row['sort_type']);

		if($isAll) {
			require_once 'image_item.php';
			$childElement = new SliderImageItem($this->userName);
			$info->imageItemList = $childElement->getList($domainId, $info->sliderId, $isAll);
		}

		return $info;
	}

	/**
	 * slider_dataにデータを設定する
	 * すべて書き換える場合、先にdeleteする必要がある。
	 * @param $domainId [in] ドメインID
	 * @param $info [in] FlagXmlInfo
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if($info->sliderId > 0) {
			if(!$this->_update($domainId, $info)) {
				return false;
			}
			$sliderId = $info->sliderId;
		} else {
			if(!$this->_insert($domainId, $info)) {
				return false;
			}

			$res = pg_query(self::$dbConn, "SELECT CURRVAL('slider_data_slider_id_seq') AS currval");
			if($res === FALSE || pg_num_rows($res) !== 1) {
				return false;
			} else {
				$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
				$sliderId = intval($row['currval']);
			}
		}

		if($isAll) {
			if(isset($info->imageItemList)) {
				require_once 'image_item.php';
				$childElement = new SliderImageItem($this->userName);
				foreach($info->imageItemList as $imageItem) {
					$imageItem->sliderId = $sliderId;
					if(!$childElement->set($domainId, $imageItem, $isAll)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	private function _insert($domainId, $info) {
		$columns  = ' domain_id';
		$values   = ' '.intval($domainId);
		$columns .= ',number';
		$values  .= ','.intval($info->number);
		$columns .= ',name';
		$values  .= ','.$this->dbStr($info->name);
		$columns .= ',direction_type';
		$values  .= ','.intval($info->directionType);
		$columns .= ',is_mirror_effect';
		$values  .= ','.($info->isMirrorEffect?1:0);
		$columns .= ',is_blur_effect';
		$values  .= ','.($info->isBlurEffect?1:0);
		$columns .= ',bg_color';
		$values  .= ','.$this->dbStr($info->bgColor);
		$columns .= ',bg_alpha';
		$values  .= ','.intval($info->bgAlpha);
		$columns .= ',width';
		$values  .= ','.intval($info->width);
		$columns .= ',height';
		$values  .= ','.intval($info->height);
		$columns .= ',thumb_width';
		$values  .= ','.intval($info->thumbWidth);
		$columns .= ',thumb_height';
		$values  .= ','.intval($info->thumbHeight);
		$columns .= ',sort_type';
		$values  .= ','.intval($info->sortType);

		$sql = 'INSERT INTO slider_data ('.$columns.') VALUES ('.$values.')';
		$res = pg_query(self::$dbConn, $sql);
		return ($res !== FALSE);
	}

	private function _update($domainId, $info) {
		$setval  = ' name='.$this->dbStr($info->name);
		$setval .= ',direction_type='.intval($info->directionType);
		$setval .= ',is_mirror_effect='.($info->isMirrorEffect?1:0);
		$setval .= ',is_blur_effect='.($info->isBlurEffect?1:0);
		$setval .= ',bg_color='.$this->dbStr($info->bgColor);
		$setval .= ',bg_alpha='.intval($info->bgAlpha);
		$setval .= ',width='.intval($info->width);
		$setval .= ',height='.intval($info->height);
		$setval .= ',thumb_width='.intval($info->thumbWidth);
		$setval .= ',thumb_height='.intval($info->thumbHeight);
		$setval .= ',sort_type='.intval($info->sortType);

		$sql = 'UPDATE slider_data SET '.$setval.' WHERE domain_id='.intval($domainId).' AND slider_id='.intval($info->sliderId);
		$res = pg_query(self::$dbConn, $sql);
		if($res == FALSE) {
			return false;
		} else {
			return true;
		}
	}


	/**
	 * 全削除
	 * @param $domainId [in] ドメインID
	 * @return bool 成功/失敗
	 */
	function deleteAll($domainId) {
		//Item削除
		$sql = 'DELETE FROM slider_item_action WHERE image_id IN (SELECT image_id FROM slider_image_item, slider_data WHERE slider_image_item.slider_id=slider_data.slider_id AND domain_id='.intval($domainId).')';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		//本体削除
		$sql = 'DELETE FROM slider_image_item WHERE slider_id IN (SELECT slider_id FROM slider_data WHERE domain_id='.intval($domainId).')';
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		}

		$sql = 'DELETE FROM slider_data WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * スライダー番号の最大値取得
	 * @param $domainId [in] ドメイン番号
	 * @return intval スライダー番号最大値
	 */
	function getMaxNumber($domainId) {
		$sql = 'SELECT MAX(number) as max_val FROM slider_data WHERE domain_id='.intval($domainId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return 0;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return intval($row['max_val']);
	}

	/**
	 * 削除可能かチェックする
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @return bool 削除可否
	 */
	function isCanDelete($domainId, $sliderId) {
		$sql = 'SELECT COUNT(image_id) as cnt FROM slider_image_item WHERE slider_id='.intval($sliderId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE || pg_num_rows($res) !== 1) {
			return false;
		}

		$row = pg_fetch_array($res, 0, PGSQL_ASSOC);
		return (intval($row['cnt'])===0);

	}

	/**
	 * 削除
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $sliderId) {
		$sql = 'DELETE FROM slider_data WHERE domain_id='.intval($domainId).' AND slider_id='.intval($sliderId);
		$res = pg_query(self::$dbConn, $sql);
		if($res === FALSE) {
			return false;
		} else {
			return true;
		}
	}

}