<?php
require_once 'xml_base.php';
require_once 'flag_xml.php';

class SliderActionElement extends Element {

	public $bgImage = '';

	public $linkUrl = '';
	public $linkUrlTarget = 0;

	public $playerElement = null;
	public $itemElementList = array();


	public $itemId = 0; //所属ItemId

	function &getNode($dom, $isDemo) {

		$actionNode = $dom->createElement('Action');

		if($this->bgImage !== '') {
			$node = $actionNode->appendChild($dom->createElement('BgImage'));
			$node = $node->appendChild($dom->createElement('Url'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->bgImage, $isDemo)));
		}

		if($this->linkUrl !== '') {
			$linkNode = $actionNode->appendChild($dom->createElement('Link'));
			if($this->linkUrl !== '') {
				$node = $linkNode->appendChild($dom->createElement('Url'));
				$node = $node->appendChild($dom->createTextNode($this->linkUrl));
			}

			$str = Element::getStrFromList(ItemButtonElement::getLinkTargetStrList(), $this->linkUrlTarget);
			if($str !== '') {
				$node = $linkNode->appendChild($dom->createElement('Target'));
				$node = $node->appendChild($dom->createTextNode($str));
			}
		}

		if(!is_null($this->playerElement)) {
			$node = $actionNode->appendChild($this->playerElement->getNode($dom, $isDemo));
		}

		if(count($this->itemElementList) > 0) {
			$itemChangeNode = $actionNode->appendChild($dom->createElement('ItemChange'));
			foreach($this->itemElementList as $itemElement) {
				$node = $itemChangeNode->appendChild($itemElement->getNode($dom, $isDemo));
			}
		}

		return $actionNode;
	}

	function setDataFromXmlObj($obj) {

		if(isset($obj->BgImage->Url)) {
			$this->bgImage = (string)$obj->BgImage->Url;
		}

		if(isset($obj->Link->Url)) {
			$this->linkUrl = (string)$obj->Link->Url;
		}

		if(isset($obj->Link->Target)) {
			$this->linkUrlTarget = Element::getIdFromList(ItemButtonElement::getLinkTargetStrList(), (string)$obj->Link->Target);
		}

		if(isset($obj->Player)) {
			$element = new PlayerElement();
			if($element->setDataFromXmlObj($obj->Player)) {
				$this->playerElement = $element;
			} else {
				return false;
			}
		}

		if(isset($obj->ItemChange->Item)) {
			foreach($obj->ItemChange->Item as $itemObj) {
				$element = new ItemElement();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->itemElementList[] = $element;
				} else {
					return false;
				}
			}
		}

		return true;
	}

	function resetId() {
		$this->itemId = 0;
		if(!is_null($this->playerElement)) {
			$this->playerElement->resetId();
		}

		if(count($this->itemElementList) > 0) {
			foreach($this->itemElementList as $itemElement) {
				$itemElement->resetId();
			}
		}
	}


	/**
	 * リンク表示先種別文字列一覧取得
	 * @return array リンク表示先種別文字列一覧(キー:ID/値:文字列)
	 */
	static function getLinkTargetStrList() {
		$list = array();
		$list[1] = 'new';
		$list[2] = 'self';

		return $list;

	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();
		//対象無し
		return $resultList;

	}
}

class SliderImageItemElemet extends Element {

	public $dispNo = 0;
	public $name = '';
	public $imageUrl = '';

	public $actionElement = null;

	public $imageId = 0;
	public $sliderId = 0;

	function &getNode($dom, $isDemo) {
		$itemNode = $dom->createElement('Item');
		$attribute = $itemNode->appendChild($dom->createAttribute('no'));
		$attribute->appendChild($dom->createTextNode($this->dispNo));

		if($this->name !== '') {
			$node = $itemNode->appendChild($dom->createElement('HiddenName'));
			$node = $node->appendChild($dom->createTextNode($this->name));
		}

		if($this->imageUrl !== '') {
			$node = $itemNode->appendChild($dom->createElement('ImageUrl'));
			$node = $node->appendChild($dom->createTextNode(Element::addTimeStrToUrl($this->imageUrl, $isDemo)));
		}

		if(isset($this->actionElement)) {
			$node = $itemNode->appendChild($this->actionElement->getNode($dom, $isDemo));
		}

		return $itemNode;
	}

	function setDataFromXmlObj($obj) {

		if(isset($obj['no'])) {
			$this->dispNo = intval($obj['no']);
		} else {
			return false;
		}

		if(isset($obj->HiddenName)) {
			$this->name = (string)$obj->HiddenName;
		}

		if(isset($obj->ImageUrl)) {
			$this->imageUrl = (string)$obj->ImageUrl;
		}

		if(isset($obj->Action)) {
			$this->actionElement = new SliderActionElement();
			if(!$this->actionElement->setDataFromXmlObj($obj->Action)) {
				$this->actionElement = null;
				return false;
			}
		}

		return true;
	}

	function resetId() {
		$this->imageId  = 0;
		$this->sliderId = 0;

		if(isset($this->actionElement)) {
			$this->actionElement->resetId();
		}
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$list = array();
		//対象無し
		return $list;
	}
}

class SliderXmlInfo extends Element {

	public $name = '';
	public $directionType = 0;
	public $isMirrorEffect = false;
	public $isBlurEffect = false;
	public $bgColor = '';
	public $bgAlpha = 100;
	public $width = 0;
	public $height = 0;
	public $thumbWidth = 0;
	public $thumbHeight = 0;
	public $sortType = 0;

	public $imageItemList = array();

	public $number = 0;

	public $sliderId = 0;

	function &getNode($dom, $isDemo) {
		require_once SYSTEM_PATH.'template/swf_info.php';

		$dataNode = $dom->createElement('DATA');

		$node = $dataNode->appendChild($dom->createElement('Copyright'));
		$node = $node->appendChild($dom->createTextNode('(C)2009 maverica corporation. ALL RIGHTS RESERVED.'));

		$node = $dataNode->appendChild($dom->createElement('Version'));
		$node = $node->appendChild($dom->createTextNode(SwfInfo::PARTS_SLIDER_VERSION));

		if($this->name !== '') {
			$node = $dataNode->appendChild($dom->createElement('HiddenName'));
			$node = $node->appendChild($dom->createTextNode($this->name));
		}

		$propertyNode = $dataNode->appendChild($dom->createElement('Property'));

		$str = Element::getStrFromList(SliderXmlInfo::getDirectionTypeStrList(), $this->directionType);
		if($str !== '') {
			$node = $propertyNode->appendChild($dom->createElement('isHorizontal'));
			$node = $node->appendChild($dom->createTextNode($str));
		}

		$node = $propertyNode->appendChild($dom->createElement('MirrorEffect', Element::getBoolStr($this->isMirrorEffect)));
		$node = $propertyNode->appendChild($dom->createElement('BlurEffect', Element::getBoolStr($this->isBlurEffect)));

		if($this->bgColor !== '') {
			$node = $propertyNode->appendChild($dom->createElement('BgColor', $this->bgColor));
		}

		$node = $propertyNode->appendChild($dom->createElement('BgAlpha', $this->bgAlpha));
		$node = $propertyNode->appendChild($dom->createElement('Width', $this->width));
		$node = $propertyNode->appendChild($dom->createElement('Height', $this->height));
		$node = $propertyNode->appendChild($dom->createElement('ThumbWidth', $this->thumbWidth));
		$node = $propertyNode->appendChild($dom->createElement('ThumbHeight', $this->thumbHeight));
		$str = Element::getStrFromList(SliderXmlInfo::getSortTypeStrList(), $this->sortType);
		if($str !== '') {
			$node = $propertyNode->appendChild($dom->createElement('ItemSort'));
			$node = $node->appendChild($dom->createTextNode($str));
		}

		foreach($this->imageItemList as $element) {
			$node = $dataNode->appendChild($element->getNode($dom, $isDemo));
		}

		return $dataNode;
	}

	function setDataFromXmlObj($obj) {

		if(!isset($obj->Copyright)) {
			return false;
		}

		if(!isset($obj->Version)) {
			return false;
		}

		if(isset($obj->HiddenName)) {
			$this->name = (string)$obj->HiddenName;
		}

		if(isset($obj->Property->isHorizontal)) {
			$this->directionType = Element::getIdFromList(SliderXmlInfo::getDirectionTypeStrList(), (string)$obj->Property->isHorizontal);
		}

		if(isset($obj->Property->MirrorEffect)) {
			$this->isMirrorEffect = Element::getBoolFromStr((string)$obj->Property->MirrorEffect);
		}

		if(isset($obj->Property->BlurEffect)) {
			$this->isBlurEffect = Element::getBoolFromStr((string)$obj->Property->BlurEffect);
		}

		if(isset($obj->Property->BgColor) && Element::checkColorFormat((string)$obj->Property->BgColor)) {
			$this->bgColor = (string)$obj->Property->BgColor;
		}

		if(isset($obj->Property->BgAlpha)) {
			$this->bgAlpha = intval($obj->Property->BgAlpha);
		}

		if(isset($obj->Property->Width)) {
			$this->width = intval($obj->Property->Width);
		}

		if(isset($obj->Property->Height)) {
			$this->height = intval($obj->Property->Height);
		}

		if(isset($obj->Property->ThumbWidth)) {
			$this->thumbWidth = intval($obj->Property->ThumbWidth);
		}

		if(isset($obj->Property->ThumbHeight)) {
			$this->thumbHeight = intval($obj->Property->ThumbHeight);
		}

		if(isset($obj->Property->ItemSort)) {
			$this->sortType = Element::getIdFromList(SliderXmlInfo::getSortTypeStrList(), (string)$obj->Property->ItemSort);
		}

		if(isset($obj->Item)) {
			foreach($obj->Item as $itemObj) {
				$element = new SliderImageItemElemet();
				if($element->setDataFromXmlObj($itemObj)) {
					$this->imageItemList[] = $element;
				} else {
					return false;
				}
			}
		}

		return true;
	}


	function resetId() {
		$this->sliderId = 0;
		foreach($this->imageItemList as $element) {
			$element->resetId();
		}

	}


	/**
	 * ファイルから読み込み
	 * @param $filePath [in] 対象XMLファイル
	 * @return bool 成功/失敗
	 */
	function loadFile($filePath) {
		$xml = simplexml_load_file($filePath);

		return $this->setDataFromXmlObj($xml);
	}

	/**
	 * XML出力
	 * @param $filePath [in] 出力先ファイル
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return bool 成功/失敗
	 */
	function saveFile($filePath, $isDemo = false) {
		$dom = new DOMDocument('1.0', 'UTF-8');
		$dom->formatOutput = true;

		$dataNode = $dom->appendChild($this->getNode($dom, $isDemo));

		return ($dom->save($filePath) !== FALSE);
	}

	/**
	 * サブファイル読み込み
	 * @param $filePath [in] 対象ファイル
	 * @return bool 成功/失敗
	 */
	function loadSubFile($filePath) {
		//処理無し
		return true;
	}

	/**
	 * サブファイル出力
	 * @param $filePath [in] 出力先ファイル
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return bool 成功/失敗
	 */
	function saveSubFile($filePath, $isDemo = false) {
		//処理無し
		return true;
	}

	/**
	 * 表示方向文字列一覧取得
	 * @return array 表示方向文字列一覧(キー:ID/値:文字列)
	 */
	static function &getDirectionTypeStrList() {
		$list = array();
		$list[0] = 'no';
		$list[1] = 'yes';

		return $list;
	}

	/**
	 * 並び順方向文字列一覧取得
	 * @return array 並び順方向文字列一覧(キー:ID/値:文字列)
	 */
	static function &getSortTypeStrList() {
		$list = array();
		$list[0] = 'asc';
		$list[1] = 'desc';

		return $list;
	}

	/**
	 * 設定した内容をチェックする
	 * @return array エラーリスト
	 */
	function &check() {
		$resultList = array();
		if($this->bgColor !== '' && !Element::checkColorFormat($this->bgColor)) {
			$resultList['bgColor'] = Language::PLEASE_INPUT_COLOR_NUMBER;
		}

		if($this->bgAlpha !== '' && !Element::checkAlphaFormat($this->bgAlpha)) {
			$resultList['bgAlpha'] = Language::MSG_ALPHA_FORMAT_ERROR;
		} else {
			$this->bgAlpha = intval($this->bgAlpha);
		}

		if($this->width !== '' && !is_numeric($this->width)) {
			$resultList['width'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->width = intval($this->width);
		}

		if($this->height !== '' && !is_numeric($this->height)) {
			$resultList['height'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->height = intval($this->height);
		}

		if($this->thumbWidth !== '' && !is_numeric($this->thumbWidth)) {
			$resultList['thumbWidth'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->thumbWidth = intval($this->thumbWidth);
		}

		if($this->thumbHeight !== '' && !is_numeric($this->thumbHeight)) {
			$resultList['thumbHeight'] = Language::MSG_NUMERIC_FORMAT_ERROR;
		} else {
			$this->thumbHeight = intval($this->thumbHeight);
		}
		return $resultList;
	}
}
?>