<?php
require_once dirname(__FILE__).'/../account.php';

class Account extends DataAccessBase {
	const SECURE_KEY = "coreblo-FLAG'S Secure Key";

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_isWrite = false;

	function Account($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(Config::TEXT_DATA_PATH.'account.xml', self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
		}
	}

	private function &_getXmlObj() {
		return parent::getXmlObj(Config::TEXT_DATA_PATH.'account.xml', self::$_fileHandle, self::$_xmlObj);
	}


	/**
	 * ユーザーIDが利用中かどうかチェックする
	 * @param $userId [in] ユーザーID
	 * @param $domainId [in] ドメインID
	 * @return bool 利用中かどうか
	 */
	function isUseUserId($userId, $domainId) {
		$obj =& $this->_getXmlObj();
		foreach($obj->AccountData as $record) {
			if(((string)$record->UserId) === $userId) {
				if(intval($record->DomainId) === intval($domainId)) {
					return true;
				}
			}
		}

		return false;
	}

	/**
	 * ユーザーIDを取得する
	 * @param $accountId [in] アカウントID
	 * @return string アカウントID（null：該当なし）
	 */
	function getUserId($accountId) {

		$obj =& $this->_getXmlObj();
		foreach($obj->AccountData as $record) {
			if(intval($record['id']) === intval($accountId)) {
				return (string)$record->UserId;
			}
		}
		return null;

	}

	/**
	 * ユーザー情報を取得する
	 * @param $accountId [in] アカウントID
	 * @return AccountInfo ユーザー情報(accountId=該当なし)
	 */
	function &getInfo($accountId) {

		$obj =& $this->_getXmlObj();
		foreach($obj->AccountData as $record) {
			if(intval($record['id']) === intval($accountId)) {

				require_once dirname(__FILE__).'/domain.php';
				$domain = new Domain($this->userName);
				$domainInfo = $domain->getInfo($record->DomainId);

				$info = new AccountInfo();
				$info->accountId = intval($record['id']);
				$info->userId = (string)$record->UserId;
				$info->password = ($record->Password===''?'':$this->_decode($record->Password));
				$info->dispName = (string)$record->DispName;
				$info->memo = (string)$record->Memo;
				$info->authorityLevel = intval($record->AuthorityLevel);
				$info->domainTitle = (string)$domainInfo->domainTitle;
				$info->domainId = intval($domainInfo->domainId);
				$info->registDateStr = (string)$record->RegistDate;
				$info->registUser = (string)$record->RegistUser;
				$info->updateDateStr = (string)$record->UpdateDate;
				$info->updateUser = (string)$record->UpdateUser;
				return $info;
			}
		}

		$info = new AccountInfo();
		return $info;

	}

	/**
	 * ユーザーID、パスワード、ドメインからユーザー情報を取得する
	 * @param $userId [in] ユーザーID
	 * @param $password [in] パスワード
	 * @param $domainDir [in] ドメインディレクトリ名
	 * @return AccountInfo ユーザー情報(accountId=該当なし)
	 */
	function &getFromInput($userId, $password, $domainDir) {

		require_once dirname(__FILE__).'/domain.php';

		if($domainDir === '') {
			$domainInfo = new DomainInfo();
		} else {
			$domain = new Domain($this->userName);
			$domainInfo = $domain->getInfoFromDomainDir($domainDir);
		}

		$obj =& $this->_getXmlObj();

		foreach($obj->AccountData as $record) {
			if(((string)$record->UserId) === $userId
			&& intval($record->DomainId) === $domainInfo->domainId) {
				if((((string)$record->Password) === '' && $password === '')
				|| ($this->_decode($record->Password) === $password)) {
					$info = new AccountInfo();
					$info->accountId = intval($record['id']);
					$info->userId = (string)$record->UserId;
					$info->password = ($record->Password===''?'':$this->_decode($record->Password));
					$info->dispName = (string)$record->DispName;
					$info->memo = (string)$record->Memo;
					$info->authorityLevel = intval($record->AuthorityLevel);
					$info->domainTitle = (string)$domainInfo->domainTitle;
					$info->domainId = intval($domainInfo->domainId);
					$info->registDateStr = (string)$record->RegistDate;
					$info->registUser = (string)$record->RegistUser;
					$info->updateDateStr = (string)$record->UpdateDate;
					$info->updateUser = (string)$record->UpdateUser;
					return $info;
				}
			}
		}

		$info = new AccountInfo();
		return $info;

	}

	/**
	 * 最終ログイン日時更新
	 * 現在の時刻に更新する
	 * @param $accountId [in] アカウントID
	 * @return bool 成功／失敗
	 */
	function updateLoginTime($accountId) {

		$obj =& $this->_getXmlObj();

		foreach($obj->AccountData as $record) {
			if(intval($record['id']) === intval($accountId)) {
				$record->LastLogin = date('Y/m/d H:i:s');
				self::$_isWrite = true;
				return true;
			}
		}

		return false;
	}

	/**
	 * 概要一覧取得
	 * @param $domainId [in] 0:全部/0以外:指定ドメインのID
	 * @return array AccountOutlineInfoリスト
	 */
	function &getOutlineList($domainId) {
		$list = array();

		require_once dirname(__FILE__).'/domain.php';
		$domain = new Domain($this->userName);

		$obj =& $this->_getXmlObj();
		foreach($obj->AccountData as $record) {
			if(intval($domainId) === 0
			|| intval($domainId) === intval($record->DomainId)) {
				$info = new AccountOutlineInfo();
				$info->accountId = intval($record['id']);
				$info->dispName = (string)$record->DispName;
				$info->authorityLevel = intval($record->AuthorityLevel);
				$info->domainTitle = $domain->getDomainTitle($record->DomainId);
				$list[$info->accountId] = $info;

			}

		}

		return $list;
	}

	/**
	 * 新規登録登録
	 * @param $info [in] AccountInfo
	 * @return intval 登録したID
	 */
	function regist($info) {

		$newId = 0;
		$obj =& $this->_getXmlObj();
		foreach($obj->AccountData as $record) {
			 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
		}
		$newId++;

		$nowTimeStr =  $this->dbStr(date('Y/m/d H:i:s'));

		$data = $obj->addChild('AccountData');
		$data->addAttribute('id', $newId);

		$data->addChild('DispName',       $this->dbStr($info->dispName));
		$data->addChild('UserId',         $this->dbStr($info->userId));
		$data->addChild('Password',       $this->dbStr($this->_encode($info->password)));
		$data->addChild('Memo',           $this->dbStr($info->memo));
		$data->addChild('DomainId',       intval($info->domainId));
		$data->addChild('AuthorityLevel', intval($info->authorityLevel));
		$data->addChild('RegistDate',     $nowTimeStr);
		$data->addChild('UpdateDate',     $nowTimeStr);
		$data->addChild('RegistUser',     $this->dbStr($this->userName));
		$data->addChild('UpdateUser',     $this->dbStr($this->userName));
		self::$_isWrite = true;

		return $newId;
	}

	/**
	 * 更新する
	 * @param $info [in] AccountInfo
	 * @return bool 成功／失敗
	 */
	function update($info) {

		$obj =& $this->_getXmlObj();
		foreach($obj->AccountData as $record) {
			if(intval($record['id']) === intval($info->accountId)) {

				$record->DispName = $this->dbStr($info->dispName);
				$record->UserId = $info->userId;
				$record->Password = $this->dbStr($this->_encode($info->password));
				$record->UpdateDate = date('Y/m/d H:i:s');
				$record->UpdateUser = $this->dbStr($this->userName);
				self::$_isWrite = true;

				return true;
			}

		}
		return false;
	}

	/**
	 * 削除する
	 * @param $accountId [in] アカウントID
	 * @return bool 成功／失敗
	 */
	function delete($accountId) {

		$obj =& $this->_getXmlObj();
		$max = count($obj->AccountData)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->AccountData[$cnt]['id']) === intval($accountId)) {
				unset($obj->AccountData[$cnt]);
				self::$_isWrite = true;
				return true;
			}
		}

		return true;
	}

	function _encode($str) {
		$seed = $this->_seed(strlen($str));
		return base64_encode($str^$seed);
	}

	function _decode($str) {
		$strTmp = base64_decode($str);
		$seed = $this->_seed(strlen($strTmp));
		return ($strTmp^$seed);
	}

	function _seed($length) {
		$keyWork = Account::SECURE_KEY;
		$seedLength = strlen(Account::SECURE_KEY);
		$seed = '';
		for($cnt = 0; $cnt < $length; $cnt++) {
			$seed .= $keyWork[$cnt%$seedLength];
		}
		return $seed;
	}

	////////////////////////////
	//以下非共通
	////////////////////////////
	/**
	 * 削除する
	 * @param $domainId [in] ドメインID
	 * @return bool 成功／失敗
	 */
	function deleteDomainAccount($domainId) {

		$obj =& $this->_getXmlObj();
		$max = count($obj->AccountData)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->AccountData[$cnt]->DomainId) === intval($domainId)) {
				unset($obj->AccountData[$cnt]);
				self::$_isWrite = true;
			}
		}

		return true;
	}

}
?>