<?

/**
 * データアクセス基底クラス(Text用)
 *
 */
class DataAccessBase {
	/**
	 * 操作ユーザー名
	 * @var string
	 */
	protected $userName = '';

	/**
	 * 利用可能かチェックする
	 * @param $settingList [in] 設定に必要なパラメータリスト
	 * @return bool 可否
	 */
	static function checkSetting($settingList) {
		if(is_dir($settingList['textDataPath'])) {
			$list = scandir($settingList['textDataPath']);
			if(count($list) > 2) {
				return false;
			}

			foreach($list as $dir) {
				if($dir !== '.' && $dir !== '..') {
					return false;
				}
			}
			return true;
		} else {
			return false;
		}
	}

	/**
	 * コンストラクタ
	 *
	 * @param unknown_type $dbConn [in] DBコネクション
	 * @param string $userName [in] 操作ユーザー名
	 * @return DataAccessBase
	 */
	function DataAccessBase($userName) {
		$this->userName = $userName;
	}

	/**
	 * 文字列をエスケープしてシングルクォートでくくる
	 *
	 * @param string $str [in] 文字列
	 * @return string 変換後文字列
	 */
	protected function dbStr($str) {
		return str_replace('&', '&amp;', $str);
	}

	/**
	 * 文字列をエスケープしてシングルクォートでくくる。文字がない場合は[NULL]を返す
	 *
	 * @param string $str [in] 文字列
	 * @return string 変換後文字列
	 */
	protected function dbStrNull($str) {
		if(strval($str) === ''){
			return 'NULL';
		} else{
			return $this->dbStr($str);
		}
	}

	/**
	 * XMLファイルをロックして、XMLオブジェクトを取得する
	 * @param $fileName [in] 対象ファイル名
	 * @param $fileHandle [in/out] ファイルハンドル格納場所(初期値=nullの変数)
	 * @param $xmlObj [in/out] XMLオブジェクト格納場所(初期値=nullの変数)
	 * @return unknown_type XMLオブジェクト
	 */
	static protected function &getXmlObj($fileName, &$fileHandle, &$xmlObj) {
		if(!is_null($fileHandle)) {
			return $xmlObj;
		}

		if(!is_file($fileName)) {
			return $xmlObj;
		}

		$fileHandle = fopen($fileName, 'r+');
		if($fileHandle === FALSE) {
			$xmlObj = null;
			return $xmlObj;
		}

		if(!flock($fileHandle, LOCK_EX)){
			//ロック失敗
			fclose($fileHandle);
			$fileHandle = null;
			return $fileHandle;
		}

		$str = '';
		while(!feof($fileHandle)){
		    $str .= fgets($fileHandle);
		}

		$xmlObj = simplexml_load_string($str);
		if($xmlObj === FALSE) {
			$xmlObj = null;
			flock($fileHandle, LOCK_UN);
			fclose($fileHandle);
			$fileHandle = null;
			return $fileHandle;
		}
		return $xmlObj;
	}

	/**
	 * XMLオブジェクトをファイルに書き出す
	 * @param $fileName [in] 対象ファイル名
	 * @param $fileHandle [in] ファイルハンドル格納場所(初期値=nullの変数)
	 * @param $xmlObj [in] XMLオブジェクト格納場所(初期値=nullの変数)
	 * @return bool 成功／失敗
	 */
	static protected function writeXmlObj($fileName, &$fileHandle, &$xmlObj) {
		$str = $xmlObj->asXML();
		$dom = new DOMDocument('1.0', 'UTF-8');
		$dom->preserveWhiteSpace = false;
		$dom->formatOutput = true;
		$dom->loadXML($str);
		$str = $dom->saveXML();

		if(ftruncate($fileHandle, 0) === FALSE) {	//中身削除
			return false;
		}

		fseek($fileHandle, 0);

		if(fwrite($fileHandle, $str) === FALSE) {
			return false;
		}

		return true;
	}

	/**
	 * ファイルを閉じる
	 * 全削除時などに利用。
	 * @param $fileHandle [in/out] ファイルハンドル
	 */
	static protected function closeFileHandle(&$fileHandle) {
		if(!is_null($fileHandle)) {
			flock($fileHandle, LOCK_UN);
			fclose($fileHandle);
			$fileHandle = null;
		}
	}
}
?>