<?php
require_once dirname(__FILE__).'/../domain.php';

class Domain extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_isWrite = false;

	function Domain($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(Config::TEXT_DATA_PATH.'domain.xml', self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
		}
	}

	private function &_getXmlObj() {
		return parent::getXmlObj(Config::TEXT_DATA_PATH.'domain.xml', self::$_fileHandle, self::$_xmlObj);
	}

	/**
	 * 概要一覧取得
	 * @return array DomainOutlineInfoリスト
	 */
	function &getOutlineList() {
		$list = array();

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(intval($record['id']) > 0) {
				$info = new DomainOutlineInfo();
				$info->domainId  = intval($record['id']);
				$info->domainTitle = (string)$record->Title;
				$list[$info->domainId] = $info;
			}
		}

		return $list;
	}

	/**
	 * 指定ドメイン名が利用中かどうかチェックする
	 * @param $domainName [in] ドメイン名
	 * @return bool 利用状況
	 */
	function isUseDomainName($domainName) {

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if($domainName === ((string)$record->Name)) {
				return true;
			}
		}

		return false;
	}

	/**
	 * 指定出力先が利用中かどうかチェックする
	 * @param $outputPath [in] 出力先
	 * @return bool 利用状況
	 */
	function isUseOutputPath($outputPath, $myDomainId) {

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if($outputPath === ((string)$record->OutputPath)
			&& intval($record['id']) !== intval($myDomainId)) {
				return true;
			}
		}
		return false;
	}

	/**
	 * ドメイン情報登録
	 * @param $info [in] DomainInfo
	 * @return 登録したID
	 */
	function regist($info) {

		$newId = 0;
		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
		}
		$newId++;

		$nowTimeStr =  $this->dbStr(date('Y/m/d H:i:s'));

		$data = $obj->addChild('DomaintData');
		$data->addAttribute('id', $newId);

		$data->addChild('Title',       $this->dbStr($info->domainTitle));
		$data->addChild('Name',        $this->dbStr($info->domainName));
		$data->addChild('OutputPath',  $this->dbStr($info->outputPath));
		$data->addChild('IsNotOutput', 1);
		$data->addChild('IframeSrcType', intval($info->iframeSrcType));
		$data->addChild('InputIframeSrc', $this->dbStr($info->inputIframeSrc));
		$data->addChild('RegistDate',  $nowTimeStr);
		$data->addChild('UpdateDate',  $nowTimeStr);
		$data->addChild('RegistUser',  $this->dbStr($this->userName));
		$data->addChild('UpdateUser',  $this->dbStr($this->userName));
		self::$_isWrite = true;

		mkdir(Config::TEXT_DATA_PATH.sprintf('%03d', $newId));

		return $newId;
	}

	/**
	 * ドメイン情報更新
	 * タイトル（名前）、横幅、高さを更新
	 * @param $info [in] ドメイン情報
	 * @return bool 成功／失敗
	 */
	function update($info) {

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(intval($record['id']) === intval($info->domainId)) {
				$record->Title  = $this->dbStr($info->domainTitle);
				$record->Name   = $this->dbStr($info->domainName);
				$record->OutputPath = $this->dbStr($info->outputPath);
				$record->IframeSrcType = intval($info->iframeSrcType);
				$record->InputIframeSrc = $this->dbStr($info->inputIframeSrc);
				$record->UpdateDate = $this->dbStr(date('Y/m/d H:i:s'));
				$record->UpdateUser = $this->dbStr($this->userName);
				self::$_isWrite = true;

				return true;
			}
		}
		return false;
	}

	/**
	 * ドメイン情報取得
	 * @param $domainId [in] ドメインID
	 * @return DomainInfo ドメイン情報
	 */
	function getInfo($domainId) {
		$info = new DomainInfo();

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(intval($record['id']) === intval($domainId)) {

				$info->domainId      = intval($record['id']);
				$info->domainTitle   = (string)$record->Title;
				$info->domainName    = (string)$record->Name;
				$info->outputPath    = (string)$record->OutputPath;
				$info->iframeSrcType = intval($record->IframeSrcType);
				$info->inputIframeSrc = (string)$record->InputIframeSrc;
				$info->registDateStr = (string)$record->RegistDate;
				$info->registUser    = (string)$record->RegistUser;
				$info->updateDateStr = (string)$record->UpdateDate;
				$info->updateUser    = (string)$record->UpdateUser;

				break;
			}
		}

		return $info;

	}

	/**
	 * ドメイン削除
	 * 関連テーブルのデータもすべて削除する
	 * @param $domainId [in] ドメインID
	 * @return bool 成功／失敗
	 */
	function delete($domainId) {
		// 関連テーブル全削除
		require_once dirname(__FILE__).'/../parts.php';
		$partsList =& PartsInfo::getList();

		foreach($partsList as $partsType => $partsInfoList) {
			$tmpStr = ucfirst($partsType);
			require_once SYSTEM_INCLUDE_DATA_PATH.$partsType.'/'.$partsType.'_xml.php';
			eval('$xmlDb = new '.$tmpStr.'Xml($_SESSION[\'UserName\']);');
			if(!$xmlDb->deleteAll(intval($domainId))) {
				return false;
			}
		}

		require_once 'flag_xml.php';
		$flagXml = new FlagXml($this->userName);
		if(!$flagXml->delete($domainId)) {
			return false;
		}

		require_once 'account.php';
		$account = new Account($this->userName);

		if(!$account->deleteDomainAccount($domainId)) {
			return false;
		}

		$domainDataPath = Config::TEXT_DATA_PATH.sprintf('%03d/', $domainId);
		if(!rmdir($domainDataPath)) {
			return false;
		}

		$obj =& $this->_getXmlObj();
		$max = count($obj->DomaintData)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->DomaintData[$cnt]['id']) === intval($domainId)) {
				unset($obj->DomaintData[$cnt]);
				self::$_isWrite = true;
				return true;
			}
		}
		return true;
	}

	/**
	 * ドメイン名取得
	 * @param $domainId [in] ドメインID
	 * @return string ドメイン名
	 */
	function getDomainTitle($domainId) {

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(intval($record['id']) === intval($domainId)) {
				return (string)$record->Title;
			}
		}

		return '';
	}


	/**
	 * ドメインの出力先パス取得
	 * @param $domainId [in] ドメインID
	 * @return string 出力先パス
	 */
	function getOutputPath($domainId) {

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(intval($record['id']) === intval($domainId)) {
				return (string)$record->OutputPath;
			}
		}

		return '';
	}

	/**
	 * 未出力に設定する。
	 * @param $domainId [in] ドメインID
	 * @return bool 成功／失敗
	 */
	function setNotOutput($domainId) {

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(intval($record['id']) === intval($domainId)) {
				$record->IsNotOutput = 1;
				self::$_isWrite = true;
			}
		}

		return true;
	}

	////////////////////////////
	//以下非共通
	////////////////////////////
	/**
	 * ドメインのディレクトリ名から情報を取得する
	 * @param $domainDir [in] ディレクトリ名
	 * @return DomainInfo
	 */
	function getInfoFromDomainDir($domainDir) {
		$info = new DomainInfo();

		$obj =& $this->_getXmlObj();
		foreach($obj->DomaintData as $record) {
			if(((string)$record->Name) === $domainDir) {

				$info->domainId      = intval($record['id']);
				$info->domainTitle   = (string)$record->Title;
				$info->domainName    = (string)$record->Name;
				$info->outputPath    = (string)$record->OutputPath;
				$info->registDateStr = (string)$record->RegistDate;
				$info->registUser    = (string)$record->RegistUser;
				$info->updateDateStr = (string)$record->UpdateDate;
				$info->updateUser    = (string)$record->UpdateUser;

				break;
			}
		}

		return $info;

	}
}
?>