<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class FlagXml extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function FlagXml($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/flag.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * 登録済みかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @return bool 登録状態
	 */
	function isCreated($domainId) {
		return is_file(self::_getFilePath($domainId));
	}

	/**
	 * xml_dataを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return FlagXmlInfo
	 */
	function &get($domainId, $isAll = false) {
		$info = new FlagXmlInfo();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return $info;
		}

		$info->logoPos       = intval($obj->Logo);
		$info->bgColor       = (string)$obj->BgColor;
		$info->bgImage       = (string)$obj->BgImage;
		$info->updateDateStr = (string)$obj->UpdateDate;
		$info->updateUser    = (string)$obj->UpdateUser;

		if($isAll) {
			require_once 'html_property_data.php';
			$childElement = new HtmlPropertyData($this->userName);
			$elementData = $childElement->get($domainId);
			if($elementData->domainId > 0) {
				$info->elementList[] = $elementData;
			}
			require_once 'player_data.php';
			$childElement = new PlayerData($this->userName);
			$elementData = $childElement->get($domainId, 0, 0);
			if($elementData->domainId > 0) {
				$info->elementList[] = $elementData;
			}
			require_once 'news_data.php';
			$childElement = new NewsData($this->userName);
			$elementData = $childElement->get($domainId, $isAll);
			if($elementData->domainId > 0) {
				$info->elementList[] = $elementData;
			}
			require_once 'link_data.php';
			$childElement = new LinkData($this->userName);
			$elementData = $childElement->get($domainId, $isAll);
			if($elementData->domainId > 0) {
				$info->elementList[] = $elementData;
			}
		}

		return $info;
	}

	/**
	 * xml_dataにデータを設定する
	 * すべて書き換える場合、先にdeleteする必要がある。
	 * @param $domainId [in] ドメインID
	 * @param $info [in] FlagXmlInfo
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<XmlData>
	<Logo>0</Logo>
	<BgColor />
	<BgImage />
	<UpdateDate />
	<UpdateUser />
</XmlData>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}


		$obj->Logo       = intval($info->logoPos);
		$obj->BgColor    = $this->dbStr($info->bgColor);
		$obj->BgImage    = $this->dbStr($info->bgImage);
		$obj->UpdateDate = $this->dbStr(date('Y/m/d H:i:s'));
		$obj->UpdateUser = $this->dbStr($this->userName);
		self::$_isWrite = true;

		if($isAll) {
			foreach($info->elementList as $element) {
				$className = get_class($element);
				switch($className) {
					case 'HtmlPropertyElement':
						require_once 'html_property_data.php';
						$childElement = new HtmlPropertyData($this->userName);
						if(!$childElement->set($domainId, $element)) {
							return false;
						}
						break;
					case 'PlayerElement':
						require_once 'player_data.php';
						$childElement = new PlayerData($this->userName);
						if(!$childElement->set($domainId, $element, $isAll)) {
							return false;
						}
						break;
					case 'NewsElement':
						require_once 'news_data.php';
						$childElement = new NewsData($this->userName);
						if(!$childElement->set($domainId, $element, $isAll)) {
							return false;
						}
						break;
					case 'LinkElement':
						require_once 'link_data.php';
						$childElement = new LinkData($this->userName);
						if(!$childElement->set($domainId, $element, $isAll)) {
							return false;
						}
						break;
				}
			}
		}

		return true;
	}

	/**
	 * 削除
	 * @param $domainId [in] ドメインID
	 * @return bool 成功/失敗
	 */
	function delete($domainId) {
		$fileList = array(
			 'flag.xml'
			,'item.xml'
			,'news.xml'
			,'player.xml'
			,'html_property.xml'
		);

		$domainDataPath = Config::TEXT_DATA_PATH.sprintf('%03d/', $domainId);
		foreach($fileList as $fileName) {
			if(is_file($domainDataPath.$fileName)) {
				unlink($domainDataPath.$fileName);
			}
		}

		return true;
	}
}