<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class HtmlPropertyData extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function HtmlPropertyData($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/html_property.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * html_property_dataを取得する
	 * @param $domainId [in] ドメインID
	 * @return HtmlPropertyElement
	 */
	function &get($domainId) {
		$info = new HtmlPropertyElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return $info;
		}

		$info->domainId = intval($domainId);

		$info->bodyMarginTop = intval($obj->Body->Margin->Top);
		$info->bodyMarginBottom = intval($obj->Body->Margin->Bottom);
		$info->bodyMarginLeft = intval($obj->Body->Margin->Left);
		$info->bodyMarginRight = intval($obj->Body->Margin->Right);
		$info->bodyMarginLeftIsAuto = (intval($obj->Body->Margin->LeftIsAuto)===1);
		$info->bodyMarginRightIsAuto = (intval($obj->Body->Margin->RightIsAuto)===1);
		$info->bodyPaddingTop = intval($obj->Body->Padding->Top);
		$info->bodyPaddingBottom = intval($obj->Body->Padding->Bottom);
		$info->bodyPaddingLeft = intval($obj->Body->Padding->Left);
		$info->bodyPaddingRight = intval($obj->Body->Padding->Right);
		$info->bodyPaddingLeftIsAuto = (intval($obj->Body->Padding->LefitIsAuto)===1);
		$info->bodyPaddingRightIsAuto = (intval($obj->Body->Padding->RightIsAuto)===1);
		$info->bodyLayoutType = intval($obj->Body->Background->Layout);
		$info->bodyBgColor = (string)$obj->Body->Background->Color;
		$info->bodyImageUrl = (string)$obj->Body->Background->Image->Url;
		$info->bodyImageRepeatType = intval($obj->Body->Background->Image->Repeat);
		$info->flashWidth = intval($obj->Flash->Width);
		$info->flashHeight = intval($obj->Flash->Height);
		$info->flashMarginTop = intval($obj->Flash->Margin->Top);
		$info->flashMarginBottom = intval($obj->Flash->Margin->Bottom);
		$info->flashMarginLeft = intval($obj->Flash->Margin->Left);
		$info->flashMarginRight = intval($obj->Flash->Margin->Right);
		$info->flashMarginLeftIsAuto = (intval($obj->Flash->Margin->LeftIsAuto)===1);
		$info->flashMarginRightIsAuto = (intval($obj->Flash->Margin->RightIsAuto)===1);
		$info->flashPaddingTop = intval($obj->Flash->Padding->Top);
		$info->flashPaddingBottom = intval($obj->Flash->Padding->Bottom);
		$info->flashPaddingLeft = intval($obj->Flash->Padding->Left);
		$info->flashPaddingRight = intval($obj->Flash->Padding->Right);
		$info->flashPaddingLeftIsAuto = (intval($obj->Flash->Padding->LeftIsAuto)===1);
		$info->flashPaddingRightIsAuto = (intval($obj->Flash->Padding->RightIsAuto)===1);


		return $info;
	}

	/**
	 * html_property_dataにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] HtmlPropertyElement
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<HtmlProperty>
	<Body>
		<Margin>
			<Top>0</Top>
			<Bottom>0</Bottom>
			<Left>0</Left>
			<LeftIsAuto>0</LeftIsAuto>
			<Right>0</Right>
			<RightIsAuto>0</RightIsAuto>
		</Margin>
		<Padding>
			<Top>0</Top>
			<Bottom>0</Bottom>
			<Left>0</Left>
			<LeftIsAuto>0</LeftIsAuto>
			<Right>0</Right>
			<RightIsAuto>0</RightIsAuto>
		</Padding>
		<Background>
			<Layout>0</Layout>
			<Color>FFFFFF</Color>
			<Image>
				<Url></Url>
				<Repeat>0</Repeat>
			</Image>
		</Background>
	</Body>
	<Flash>
		<Width>640</Width>
		<Height>940</Height>
		<Margin>
			<Top>0</Top>
			<Bottom>0</Bottom>
			<Left>0</Left>
			<LeftIsAuto>0</LeftIsAuto>
			<Right>0</Right>
			<RightIsAuto>0</RightIsAuto>
		</Margin>
		<Padding>
			<Top>0</Top>
			<Bottom>0</Bottom>
			<Left>0</Left>
			<LeftIsAuto>0</LeftIsAuto>
			<Right>0</Right>
			<RightIsAuto>0</RightIsAuto>
		</Padding>
	</Flash>
</HtmlProperty>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$obj->Body->Margin->Top = intval($info->bodyMarginTop);
		$obj->Body->Margin->Bottom = intval($info->bodyMarginBottom);
		$obj->Body->Margin->Left = intval($info->bodyMarginLeft);
		$obj->Body->Margin->Right = intval($info->bodyMarginRight);
		$obj->Body->Margin->LeftIsAuto = ($info->bodyMarginLeftIsAuto?1:0);
		$obj->Body->Margin->RightIsAuto = ($info->bodyMarginRightIsAuto?1:0);
		$obj->Body->Padding->Top = intval($info->bodyPaddingTop);
		$obj->Body->Padding->Bottom = intval($info->bodyPaddingBottom);
		$obj->Body->Padding->Left = intval($info->bodyPaddingLeft);
		$obj->Body->Padding->Right = intval($info->bodyPaddingRight);
		$obj->Body->Padding->LefitIsAuto = ($info->bodyPaddingLeftIsAuto?1:0);
		$obj->Body->Padding->RightIsAuto = ($info->bodyPaddingRightIsAuto?1:0);
		$obj->Body->Background->Layout = intval($info->bodyLayoutType);
		$obj->Body->Background->Color = $this->dbStr($info->bodyBgColor);
		$obj->Body->Background->Image->Url = $this->dbStr($info->bodyImageUrl);
		$obj->Body->Background->Image->Repeat = intval($info->bodyImageRepeatType);
		$obj->Flash->Width = intval($info->flashWidth);
		$obj->Flash->Height = intval($info->flashHeight);
		$obj->Flash->Margin->Top = intval($info->flashMarginTop);
		$obj->Flash->Margin->Bottom = intval($info->flashMarginBottom);
		$obj->Flash->Margin->Left = intval($info->flashMarginLeft);
		$obj->Flash->Margin->Right = intval($info->flashMarginRight);
		$obj->Flash->Margin->LeftIsAuto = ($info->flashMarginLeftIsAuto?1:0);
		$obj->Flash->Margin->RightIsAuto = ($info->flashMarginRightIsAuto?1:0);
		$obj->Flash->Padding->Top = intval($info->flashPaddingTop);
		$obj->Flash->Padding->Bottom = intval($info->flashPaddingBottom);
		$obj->Flash->Padding->Left = intval($info->flashPaddingLeft);
		$obj->Flash->Padding->Right = intval($info->flashPaddingRight);
		$obj->Flash->Padding->LeftIsAuto = ($info->flashPaddingLeftIsAuto?1:0);
		$obj->Flash->Padding->RightIsAuto = ($info->flashPaddingRightIsAuto?1:0);

		self::$_isWrite = true;

		return true;
	}
}