<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class ItemData extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function ItemData($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/item.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * 親に所属するアイテムの最大表示順(件数から割り出したもの)を取得する
	 * @param $domainId [in] ドメインID
	 * @return intval 最大の表示順
	 */
	function getMaxDispNo($domainId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return 0;
		}

		$cnt = 0;
		foreach($obj->Item as $record) {
			 if(intval($record->ParentItemId) === 0) {
			 	$cnt++;
			 }
		}

		return $cnt;
	}

	/**
	 * 概要一覧取得（ツリー用）
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @return array 概要一覧
	 */
	function &getOutlineList($domainId, $parentItemId, $parentType = 0) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $list;
		}

		$obj =& $this->_getXmlObj($domainId);
		foreach($obj->Item as $record) {
			if(intval($record->ParentItemId) === intval($parentItemId) && intval($record->ParentType) === intval($parentType)) {
				$itemId = intval($record['id']);
				$dispNo = intval($record->DispNo);
				$list[$dispNo]['itemId'] = $itemId;
				$list[$dispNo]['name'] =  (string)$record->Name;
				$list[$dispNo]['dispNo'] = $dispNo;
				$list[$dispNo]['isUseButton'] = (!empty($record->Button));
				$list[$dispNo]['child'] = $this->getOutlineList($domainId, $itemId);
			}
		}

		ksort($list);

		return $list;
	}

	/**
	 * item_element一覧を取得する(item_buttom,wipe_settingまで含む)
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return ItemElement
	 */
	function &getList($domainId, $parentItemId, $parentType, $isAll = false) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || !isset($obj->Item)) {
			return $list;
		}

		foreach($obj->Item as $record) {

			if(intval($record->ParentItemId) === intval($parentItemId) && intval($record->ParentType) === intval($parentType)) {
				$info = new ItemElement();
				$info->itemId = intval($record['id']);
				$info->parentItemId = intval($record->ParentItemId);

				$info->name = (string)$record->Name;
				$info->dispNo = intval($record->DispNo);
				$info->isDisplay = (intval($record->IsDisplay)===1);
				$info->layer = intval($record->Layer);
				$info->xAxis = intval($record->XAxis);
				$info->yAxis = intval($record->YAxis);
				$info->image = (string)$record->Image;
				$info->imageFadeinEffect = intval($record->ImageFadeinEffect);
				$info->imageSlideinAngle = intval($record->ImageSlideinAngle);
				$info->imageSlideinMoveSize = intval($record->ImageSlideinMoveSize);
				$info->imageSlideinMoveSpeed = intval($record->ImageSlideinMoveSpeed);

				$info->delayTime = intval($record->DelayTime);
				$info->imageType = intval($record->ImageType);
				$info->playlistPlayType = intval($record->PlaylistPlayType);
				$info->playlistPlayWait = intval($record->PlaylistPlayWait);

				if(!empty($record->Button)) {
					$info->itemButtonElement = new ItemButtonElement();
					$info->itemButtonElement->itemId        = intval($info->itemId);
					$info->itemButtonElement->width         = intval($record->Button->Width);
					$info->itemButtonElement->height        = intval($record->Button->Height);
					$info->itemButtonElement->rolloverImage = (string)$record->Button->RolloverImage;
					$info->itemButtonElement->rolloverColor = (string)$record->Button->RolloverColor;
					$info->itemButtonElement->rolloverAlpha = intval($record->Button->RolloverAlpha);
					$info->itemButtonElement->rolloutColor  = (string)$record->Button->RolloutColor;
					$info->itemButtonElement->rolloutAlpha  = intval($record->Button->RolloutAlpha);
					$info->itemButtonElement->bgImage       = (string)$record->Button->BgImage;
					$info->itemButtonElement->linkUrl       = (string)$record->Button->LinkUrl;
					$info->itemButtonElement->linkUrlTarget = intval($record->Button->LinkUrlTarget);

					if($isAll) {
						require_once 'player_data.php';
						$childElement = new PlayerData($this->userName);
						$playerElement = $childElement->get($domainId, $info->itemId, 0);
						if($playerElement->domainId > 0) {
							$info->itemButtonElement->playerElement = $playerElement;
						}
						$info->itemButtonElement->itemElementList = $this->getList($domainId, $info->itemId, 0, $isAll);
					}
				}


				if(!empty($record->Wipe)) {
					$info->itemWipeElement = new ItemWipeElement();
					$info->itemWipeElement->itemId             = intval($info->itemId);
					$info->itemWipeElement->type               = intval($record->Wipe->Type);
					$info->itemWipeElement->widthDivideNumber  = intval($record->Wipe->WidthDivideNumber);
					$info->itemWipeElement->heightDivideNumber = intval($record->Wipe->HeightDivideNumber);
					$info->itemWipeElement->widthIsMagnified   = (intval($record->Wipe->WidthIsMagnified)===1);
					$info->itemWipeElement->heightIsMagnified  = (intval($record->Wipe->HeightIsMagnified)===1);
					$info->itemWipeElement->displayDirection   = intval($record->Wipe->DisplayDirection);
					$info->itemWipeElement->speed              = intval($record->Wipe->Speed);
					$info->itemWipeElement->diagonalType       = intval($record->Wipe->DiagonalType);
				}

				if($isAll) {
					$info->playlistItemList = $this->_getItemListFromObj($record['id'], $record->PlayList);
				}

				$list[] = $info;
			}
		}

		return $list;
	}

	/**
	 * item_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ItemID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return NewsElement
	 */
	function &get($domainId, $itemId, $isAll = false) {
		$info = new ItemElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $info;
		}

		foreach($obj->Item as $record) {

			if(intval($record['id']) === intval($itemId)) {
				$info->itemId = intval($itemId);
				$info->parentType = intval($record->ParentType);
				$info->parentItemId = intval($record->ParentItemId);

				$info->name = (string)$record->Name;
				$info->dispNo = intval($record->DispNo);
				$info->isDisplay = (intval($record->IsDisplay)===1);
				$info->layer = intval($record->Layer);
				$info->xAxis = intval($record->XAxis);
				$info->yAxis = intval($record->YAxis);
				$info->image = (string)$record->Image;
				$info->imageFadeinEffect = intval($record->ImageFadeinEffect);
				$info->imageSlideinAngle = intval($record->ImageSlideinAngle);
				$info->imageSlideinMoveSize = intval($record->ImageSlideinMoveSize);
				$info->imageSlideinMoveSpeed = intval($record->ImageSlideinMoveSpeed);

				$info->delayTime = intval($record->DelayTime);
				$info->imageType = intval($record->ImageType);
				$info->playlistPlayType = intval($record->PlaylistPlayType);
				$info->playlistPlayWait = intval($record->PlaylistPlayWait);

				if($isAll) {
					if(!empty($record->Button)) {
						$info->itemButtonElement = new ItemButtonElement();
						$info->itemButtonElement->itemId        = intval($itemId);
						$info->itemButtonElement->width         = intval($record->Button->Width);
						$info->itemButtonElement->height        = intval($record->Button->Height);
						$info->itemButtonElement->rolloverImage = (string)$record->Button->RolloverImage;
						$info->itemButtonElement->rolloverColor = (string)$record->Button->RolloverColor;
						$info->itemButtonElement->rolloverAlpha = intval($record->Button->RolloverAlpha);
						$info->itemButtonElement->rolloutColor  = (string)$record->Button->RolloutColor;
						$info->itemButtonElement->rolloutAlpha  = intval($record->Button->RolloutAlpha);
						$info->itemButtonElement->bgImage       = (string)$record->Button->BgImage;
						$info->itemButtonElement->linkUrl       = (string)$record->Button->LinkUrl;
						$info->itemButtonElement->linkUrlTarget = intval($record->Button->LinkUrlTarget);

						if($isAll) {
							require_once 'player_data.php';
							$childElement = new PlayerData($this->userName);
							$playerElement = $childElement->get($domainId, $info->itemId);
							if($playerElement->domainId > 0) {
								$info->itemButtonElement->playerElement = $playerElement;
							}
							$info->itemButtonElement->itemElementList = $this->getList($domainId, $info->itemId, 0, $isAll);
						}
					}

					if(!empty($record->Wipe)) {
						$info->itemWipeElement = new ItemWipeElement();
						$info->itemWipeElement->itemId             = intval($info->itemId);
						$info->itemWipeElement->type               = intval($record->Wipe->Type);
						$info->itemWipeElement->widthDivideNumber  = intval($record->Wipe->WidthDivideNumber);
						$info->itemWipeElement->heightDivideNumber = intval($record->Wipe->HeightDivideNumber);
						$info->itemWipeElement->widthIsMagnified   = (intval($record->Wipe->WidthIsMagnified)===1);
						$info->itemWipeElement->heightIsMagnified  = (intval($record->Wipe->HeightIsMagnified)===1);
						$info->itemWipeElement->displayDirection   = intval($record->Wipe->DisplayDirection);
						$info->itemWipeElement->speed              = intval($record->Wipe->Speed);
						$info->itemWipeElement->diagonalType       = intval($record->Wipe->DiagonalType);
					}

					$info->playlistItemList = $this->_getItemListFromObj($record['id'], $record->PlayList);
				}

				break;
			}
		}
		return $info;
	}

	/**
	 * item_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Items>
</Items>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		if(intval($info->itemId) > 0) {
			if(!$this->_updateElement($domainId, $info)) {
				return false;
			}
			$itemId = intval($info->itemId);
		} else {
			$itemId = $this->_insertElement($domainId, $info);
			if($itemId === 0) {
				return false;
			}
		}

		if($isAll) {
			if(isset($info->itemButtonElement)) {
				if(!$this->setButton($domainId, $itemId, $info->itemButtonElement, $isAll)) {
					return false;
				}
			}

			if(isset($info->itemWipeElement)) {
				$info->itemWipeElement->itemId = $itemId;
				if(!$this->setWipe($domainId, $info->itemWipeElement)) {
					return false;
				}
			}

			foreach($info->playlistItemList as $itemElement) {
				$itemElement->itemId = $itemId;
				if(!$this->setPlaylistItem($domainId, $itemElement)) {
					return false;
				}
			}
		}

		return true;
	}

	private function _insertElement($domainId, $info) {
		$newId = 0;
		$obj =& $this->_getXmlObj($domainId);
		if(!empty($obj->Item)) {
			foreach($obj->Item as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Item');
		$data->addAttribute('id', $newId);

		$data->addChild('ParentType',   intval($info->parentType));
		$data->addChild('ParentItemId', intval($info->parentItemId));
		$data->addChild('Name',         $this->dbStr($info->name));
		$data->addChild('DispNo',       intval($info->dispNo));
		$data->addChild('IsDisplay',    ($info->isDisplay?1:0));
		$data->addChild('Layer',        intval($info->layer));
		$data->addChild('XAxis',        intval($info->xAxis));
		$data->addChild('YAxis',        intval($info->yAxis));
		$data->addChild('Image',        $this->dbStr($info->image));
		$data->addChild('ImageFadeinEffect',     intval($info->imageFadeinEffect));
		$data->addChild('ImageSlideinAngle',     intval($info->imageSlideinAngle));
		$data->addChild('ImageSlideinMoveSize',  intval($info->imageSlideinMoveSize));
		$data->addChild('ImageSlideinMoveSpeed', intval($info->imageSlideinMoveSpeed));
		$data->addChild('DelayTime',        intval($info->delayTime));
		$data->addChild('ImageType',        intval($info->imageType));
		$data->addChild('PlaylistPlayType', intval($info->playlistPlayType));
		$data->addChild('PlaylistPlayWait', intval($info->playlistPlayWait));

		self::$_isWrite = true;

		return $newId;
	}

	private function _updateElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		foreach($obj->Item as $record) {
			if(intval($info->itemId) === intval($record['id'])) {
				$record->ParentItemId = intval($info->parentItemId);
				$record->Name      = $this->dbStr($info->name);
				$record->DispNo    = intval($info->dispNo);
				$record->IsDisplay = ($info->isDisplay?1:0);
				$record->Layer     = intval($info->layer);
				$record->XAxis     = intval($info->xAxis);
				$record->YAxis     = intval($info->yAxis);
				$record->Image     = $this->dbStr($info->image);
				$record->ImageFadeinEffect     = intval($info->imageFadeinEffect);
				$record->ImageSlideinAngle     = intval($info->imageSlideinAngle);
				$record->ImageSlideinMoveSize  = intval($info->imageSlideinMoveSize);
				$record->ImageSlideinMoveSpeed = intval($info->imageSlideinMoveSpeed);
				$record->DelayTime        = intval($info->delayTime);
				$record->ImageType        = intval($info->imageType);
				$record->PlaylistPlayType = intval($info->playlistPlayType);
				$record->PlaylistPlayWait = intval($info->playlistPlayWait);

				self::$_isWrite = true;
				return true;
			}
		}

		return false;
	}

	/**
	 * 親アイテム表示位置変更
	 * 子階層が参照している表示位置もすべて変更する。
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeTopItemDispNo($domainId, $itemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$oldDispNo = 0;

		$obj =& $this->_getXmlObj($domainId);
		foreach($obj->Item as $record) {
			if(intval($itemId) === intval($record['id'])) {
				$oldDispNo = intval($record->DispNo);
				break;
			}
		}

		if($oldDispNo === 0) {
			return false;
		}
		if($oldDispNo === $newDispNo) {
			return true;
		}

		reset($obj->Item);
		$start = min(array($newDispNo, $oldDispNo));
		$end   = max(array($newDispNo, $oldDispNo));
		$addVal = ($oldDispNo<$newDispNo?-1:+1);
		foreach($obj->Item as $record) {
			if($start <= intval($record->DispNo) && intval($record->DispNo) <= $end) {
				if(intval($record->DispNo) === $oldDispNo) {
					$record->DispNo = $newDispNo;
				} else {
					$record->DispNo = intval($record->DispNo) + $addVal;
				}
				self::$_isWrite = true;
			}
		}

		return true;
	}

	/**
	 * 削除可能かチェックする
	 * 親階層の場合、子階層が無いかつ操作対象に指定されていないことが条件。
	 * 子階層の場合、子階層が無いことが条件。
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 可否
	 */
	function isCanDelete($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		$dispNo = 0;
		foreach($obj->Item as $record) {
			//子階層チェック
			if(intval($record->ParentItemId) === intval($itemId)
			&& intval($record->ParentType) === 0) {
				return false;
			}

			//親の場合の操作対象として選択されているかチェック
			if(intval($record['id']) === intval($itemId)
			&& intval($record->ParentItemId) === 0) {
				$dispNo = intval($record->DispNo);
			}
		}

		//親の場合の操作対象として選択されているかチェック
		if($dispNo > 0) {
			foreach($obj->Item as $record) {
				if(intval($record->ParentItemId) > 0) {
					if($dispNo === intval($record->DispNo)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	/**
	 * アイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $itemId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		$dispNo = 0;
		$parentItemId = 0;
		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$dispNo = intval($record->DispNo);
				$parentItemId = intval($record->ParentItemId);
				break;
			}
		}

		if($dispNo === 0) {
			return false;
		}

		require_once 'player_data.php';
		$childElement = new PlayerData($this->userName);
		if(!$childElement->delete($domainId, $itemId, 0)) {
			return false;
		}

		$max = count($obj->Item)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Item[$cnt]['id']) === intval($itemId)) {
				unset($obj->Item[$cnt]);
				self::$_isWrite = true;
			} else if($parentItemId === 0 && $dispNo < $obj->Item[$cnt]->DispNo) {
				$obj->Item[$cnt]->DispNo = intval($obj->Item[$cnt]->DispNo)-1;
				self::$_isWrite = true;
			}
		}

		return true;
	}

	/**
	 * 指定した表示順が利用中かどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @param $dispNo [in] チェック対象表示位置
	 * @return unknown_type
	 */
	function isUseDispNo($domainId, $parentItemId, $parentType, $dispNo) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return true;
		}

		$dispNo = intval($dispNo);
		foreach($obj->Item as $record) {
			//子階層チェック
			if(intval($record->ParentItemId) === intval($parentItemId)
			&& intval($record->ParentType) === intval($parentType)) {
				if($dispNo === intval($record->DispNo)) {
					return true;
				}
			}
		}

		return false;
	}

	//////////////////////////
	// ボタン

	/**
	 * ボタンを利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 利用状況
	 */
	function isUseButton($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(empty($record->Button)) {
					return false;
				} else {
					return true;
				}
			}
		}

		return false;
	}

	/**
	 * プレイヤーを利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $parentType [in] 親アイテム種別
	 * @return bool 利用状況
	 */
	function isUsePlayer($domainId, $itemId, $parentType = 0) {
		require_once 'player_data.php';
		$player = new PlayerData($this->userName);
		return $player->isUsePlayer($domainId, $itemId, $parentType);
	}
	/**
	 * item_button_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function setButton($domainId, $itemId, $info, $isAll = false) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$record->Button->Width         = intval($info->width);
				$record->Button->Height        = intval($info->height);
				$record->Button->RolloverImage = $this->dbStr($info->rolloverImage);
				$record->Button->RolloverColor = $this->dbStr($info->rolloverColor);
				$record->Button->RolloverAlpha = intval($info->rolloverAlpha);
				$record->Button->RolloutColor  = $this->dbStr($info->rolloutColor);
				$record->Button->RolloutAlpha  = intval($info->rolloutAlpha);
				$record->Button->BgImage       = $this->dbStr($info->bgImage);
				$record->Button->LinkUrl       = $this->dbStr($info->linkUrl);
				$record->Button->LinkUrlTarget = intval($info->linkUrlTarget);
				self::$_isWrite = true;

				if($isAll) {
					if(isset($info->playerElement)) {
						require_once 'player_data.php';
						$childElement = new PlayerData($this->userName);
						$info->playerElement->itemId = $itemId;
						if(!$childElement->set($domainId, $info->playerElement, $isAll)) {
							return false;
						}
					}
					if(count($info->itemElementList) > 0) {
						foreach($info->itemElementList as $itemElement) {
							$itemElement->parentItemId = $itemId;
							if(!$this->set($domainId, $itemElement, $isAll)) {
								return false;
							}
						}
					}
				}

				return true;
			}
		}

		return false;
	}

	/**
	 * item_button_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ItemID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return NewsElement
	 */
	function &getButton($domainId, $itemId, $isAll = false) {
		$info = new ItemButtonElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $info;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(empty($record->Button)) {
					return $info;
				} else {
					$info->itemId        = intval($itemId);
					$info->width         = intval($record->Button->Width);
					$info->height        = intval($record->Button->Height);
					$info->rolloverImage = (string)$record->Button->RolloverImage;
					$info->rolloverColor = (string)$record->Button->RolloverColor;
					$info->rolloverAlpha = intval($record->Button->RolloverAlpha);
					$info->rolloutColor  = (string)$record->Button->RolloutColor;
					$info->rolloutAlpha  = intval($record->Button->RolloutAlpha);
					$info->bgImage       = (string)$record->Button->BgImage;
					$info->linkUrl       = (string)$record->Button->LinkUrl;
					$info->linkUrlTarget = intval($record->Button->LinkUrlTarget);

					break;
				}
			}
		}

		if($info->itemId === 0) {
			return $info;
		}

		if($isAll) {
			require_once 'player_data.php';
			$childElement = new PlayerData($this->userName);
			$playerElement = $childElement->get($domainId, $info->itemId);
			if($playerElement->domainId > 0) {
				$info->playerElement = $playerElement;
			}
			$info->itemElementList = $this->getList($domainId, $info->itemId, 0, $isAll);
		}

		return $info;
	}

	/**
	 * ボタンアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 成功/失敗
	 */
	function deleteButton($domainId, $itemId) {
		require_once 'player_data.php';
		$childElement = new PlayerData($this->userName);
		if(!$childElement->delete($domainId, $itemId)) {
			return false;
		}

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return true;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(!empty($record->Button)) {
					unset($record->Button);
					self::$_isWrite = true;
				}
				return true;
			}
		}

		return true;
	}

	/**
	 * 操作対象表示番号一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 所属アイテムID
	 * @param $parentType [in] 親アイテム種別
	 * @return array キー：表示順／値：名前
	 */
	function &getTargetDispNoList($domainId, $parentItemId, $parentType = 0) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $list;
		}

		$deleteDispNoList = array();
		foreach($obj->Item as $record) {
			if(intval($record->ParentItemId) === intval($parentItemId) && intval($record->ParentType) === intval($parentType)) {
				$deleteDispNoList[intval($record->DispNo)] = 1;
			} else if(intval($record->ParentItemId) === 0) {
				$list[intval($record->DispNo)] = $record->Name;
			}
		}

		if(count($deleteDispNoList) > 0) {
			foreach($deleteDispNoList as $key => $value) {
				unset($list[$key]);
			}
		}

		return $list;
	}

	/**
	 * 削除可能かチェックする
	 * 子階層が無いことが条件。
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 可否
	 */
	function isCanDeleteButton($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		$dispNo = 0;
		foreach($obj->Item as $record) {
			//子階層チェック
			if(intval($record->ParentItemId) === intval($itemId)
			&& intval($record->ParentType) === 0) {
				return false;
			}
		}
		return true;
	}

	//////////////////////////
	// 表示効果設定

	/**
	 * 表示効果を利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 利用状況
	 */
	function isUseWipe($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(empty($record->Wipe)) {
					return false;
				} else {
					return true;
				}
			}
		}

		return false;
	}

	/**
	 * 表示効果取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return ItemWipeElement
	 */
	function &getWipe($domainId, $itemId) {
		$info = new ItemWipeElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $info;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(empty($record->Wipe)) {
					return $info;
				} else {
					$info->type               = intval($record->Wipe->Type);
					$info->widthDivideNumber  = intval($record->Wipe->WidthDivideNumber);
					$info->heightDivideNumber = intval($record->Wipe->HeightDivideNumber);
					$info->widthIsMagnified   = (intval($record->Wipe->WidthIsMagnified)===1);
					$info->heightIsMagnified  = (intval($record->Wipe->HeightIsMagnified)===1);
					$info->displayDirection   = intval($record->Wipe->DisplayDirection);
					$info->speed              = intval($record->Wipe->Speed);
					$info->diagonalType       = intval($record->Wipe->DiagonalType);

					$info->itemId        = intval($itemId);

					break;
				}
			}
		}
		return $info;
	}

	/**
	 * wipe_settingにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemElement
	 * @return bool 成功/失敗
	 */
	function setWipe($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($info->itemId)) {
				$record->Wipe->Type               = intval($info->type);
				$record->Wipe->WidthDivideNumber  = intval($info->widthDivideNumber);
				$record->Wipe->HeightDivideNumber = intval($info->heightDivideNumber);
				$record->Wipe->WidthIsMagnified   = ($info->widthIsMagnified?1:0);
				$record->Wipe->HeightIsMagnified  = ($info->heightIsMagnified?1:0);
				$record->Wipe->DisplayDirection   = intval($info->displayDirection);
				$record->Wipe->Speed              = intval($info->speed);
				$record->Wipe->DiagonalType       = intval($info->diagonalType);
				self::$_isWrite = true;

				return true;
			}
		}

		return false;
	}

	/**
	 * 表示効果削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return bool 成功/失敗
	 */
	function deleteWipe($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return true;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(!empty($record->Wipe)) {
					unset($record->Wipe);
					self::$_isWrite = true;
				}
				return true;
			}
		}

		return true;
	}

	//////////////////////////
	// プレイリストアイテム

	/**
	 * プレイリストのアイテム一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @return array ItemPlayListItem一覧
	 */
	function &getItemList($domainId, $itemId) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $list;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$list = $this->_getItemListFromObj($itemId, $record->PlayList);
				break;
			}
		}
		return $list;

	}

	private function &_getItemListFromObj($itemId, $obj) {
		$list = array();

		if(isset($obj->ListItem)) {
			foreach($obj->ListItem as $record) {
				$itemInfo = new ItemPlayListItem();
				$itemInfo->dispNo         = intval($record->DispNo);
				$itemInfo->name           = (string)$record->Name;
				$itemInfo->image          = (string)$record->Image;
				$itemInfo->linkUrl        = (string)$record->LinkUrl;
				$itemInfo->linkUrlTarget  = intval($record->LinkUrlTarget);
				$itemInfo->itemId         = intval($itemId);
				$itemInfo->playlistItemId = intval($record['id']);

				$list[$itemInfo->dispNo] = $itemInfo;
			}
		}

		ksort($list);

		return $list;
	}

	/**
	 * プレイリストアイテム取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @return ItemPlayListItem
	 */
	function &getPlayListItem($domainId, $itemId, $playlistItemId) {

		$itemInfo = new ItemPlayListItem();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $itemInfo;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(isset($record->PlayList->ListItem)) {
					foreach($record->PlayList->ListItem as $itemRecord) {
						if(intval($itemRecord['id']) === intval($playlistItemId)) {
							$itemInfo->dispNo         = intval($itemRecord->DispNo);
							$itemInfo->name           = (string)$itemRecord->Name;
							$itemInfo->image          = (string)$itemRecord->Image;
							$itemInfo->linkUrl        = (string)$itemRecord->LinkUrl;
							$itemInfo->linkUrlTarget  = intval($itemRecord->LinkUrlTarget);
							$itemInfo->itemId         = intval($itemRecord);
							$itemInfo->playlistItemId = intval($itemRecord['id']);
							return $itemInfo;
						}
					}

				} else {
					return $itemInfo;
				}
			}
		}
		return $itemInfo;
	}

	/**
	 * itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function setPlaylistItem($domainId, $info) {
		if($info->playlistItemId > 0) {
			if(!$this->updatePlaylistItemElement($domainId, $info)) {
				return false;
			}
		} else {
			if($this->insertPlaylistItemElement($domainId, $info) === 0) {
				return false;
			}
		}

		return true;
	}

	/**
	 * アイテムを挿入する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemPlayListItem
	 * @return intval アイテムID
	 */
	function insertPlaylistItemElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return 0;
		}

		$itemObj = null;
		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($info->itemId)) {
				$itemObj = $record;
				break;
			}
		}

		$newId = 0;
		if(isset($itemObj)) {

			if(!isset($itemObj->PlayList)) {
				$itemObj->addChild('PlayList');
			}

			if(isset($itemObj->PlayList->ListItem)) {
				foreach($itemObj->PlayList->ListItem as $record) {
					$newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
				}
			}
			$newId++;

			$data = $itemObj->PlayList->addChild('ListItem');
			$data->addAttribute('id', $newId);
			$data->addChild('DispNo',        intval($info->dispNo));
			$data->addChild('Name',          $this->dbStr($info->name));
			$data->addChild('Image',         $this->dbStr($info->image));
			$data->addChild('LinkUrl',       $this->dbStr($info->linkUrl));
			$data->addChild('LinkUrlTarget', intval($info->linkUrlTarget));

			self::$_isWrite = true;

		}
		return $newId;
	}

	/**
	 * アイテムを更新する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] ItemPlayListItem
	 * @return bool 成功/失敗
	 */
	function updatePlaylistItemElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return 0;
		}

		$itemObj = null;
		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($info->itemId)) {
				$itemObj = $record;
				break;
			}
		}

		if(isset($itemObj->PlayList->ListItem)) {

			foreach($itemObj->PlayList->ListItem as $record) {
				if(intval($record['id']) === $info->playlistItemId) {
					$record->DispNo        = intval($info->dispNo);
					$record->Name          = $this->dbStr($info->name);
					$record->Image         = $this->dbStr($info->image);
					$record->LinkUrl       = $this->dbStr($info->linkUrl);
					$record->LinkUrlTarget = intval($info->linkUrlTarget);
					self::$_isWrite = true;

					return true;
				}
			}
		}

		return false;
	}

	/**
	 * 表示順の最大値取得
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] プレイヤーID
	 * @return intval 表示順の最大値
	 */
	function getPlaylistItemMaxDispNo($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return 0;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				if(isset($record->PlayList->ListItem)) {
					return count($record->PlayList->ListItem);
				} else {
					return 0;
				}
			}
		}
		return 0;
	}
	/**
	 * 表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changePlaylistItemDispNo($domainId, $itemId, $playlistItemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$oldDispNo = 0;

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		$itemObj = null;
		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$itemObj = $record;
				break;
			}
		}

		if(isset($itemObj)) {

			$cnt = 0;
			foreach($itemObj->PlayList->ListItem as $record) {
				if(intval($playlistItemId) === intval($record['id'])) {
					$oldDispNo = intval($record->DispNo);
				}
				$list[(intval($record->DispNo)-1)] = $cnt;
				$cnt++;
			}

			if($oldDispNo === 0) {
				return false;
			}
			if($oldDispNo === $newDispNo) {
				return true;
			}

			ksort($list);

			$start = min(array(($newDispNo-1), ($oldDispNo - 1)));
			$end   = max(array(($newDispNo-1), ($oldDispNo - 1)));
			$addVal = ($oldDispNo<$newDispNo?-1:+1);
			for($cnt = $start; $cnt <= $end; $cnt++) {
				if($cnt === ($oldDispNo-1)) {
					$itemObj->PlayList->ListItem[$list[$cnt]]->DispNo = $newDispNo;
				} else {
					$itemObj->PlayList->ListItem[$list[$cnt]]->DispNo = intval($itemObj->PlayList->ListItem[$list[$cnt]]->DispNo) + $addVal;
				}
				self::$_isWrite = true;
			}
		}

		return true;
	}

	/**
	 * プレイリストアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @return bool 成功/失敗
	 */
	function deletePlaylistItem($domainId, $itemId, $playlistItemId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return false;
		}

		$itemObj = null;
		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$itemObj = $record;
				break;
			}
		}

		if(isset($itemObj)) {
			$dispNo = 0;
			foreach($itemObj->PlayList->Item as $record) {
				if(intval($record['id']) === intval($playlistItemId)) {
					$dispNo = intval($record->DispNo);
					break;
				}
			}

			if($dispNo === 0) {
				return false;
			}

			$max = count($itemObj->PlayList->ListItem)-1;
			for($cnt = $max; $cnt >= 0; $cnt--) {
				if(intval($itemObj->PlayList->ListItem[$cnt]['id']) === intval($playlistItemId)) {
					unset($itemObj->PlayList->ListItem[$cnt]);
					self::$_isWrite = true;
				} else if($dispNo < $itemObj->PlayList->ListItem[$cnt]->DispNo) {
					$itemObj->PlayList->ListItem[$cnt]->DispNo = intval($itemObj->PlayList->ListItem[$cnt]->DispNo)-1;
					self::$_isWrite = true;
				}
			}

		}
	}

	////////////////////////////
	//以下非共通
	////////////////////////////

	/**
	 * 子ID一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ID（0:最上位）
	 * @param $parentType [in] 親アイテム種別
	 * @return array 子ID一覧(キー:ID/値:表示順)
	 */
	function &getChildList($domainId, $parentItemId, $parentType = 0) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $list;
		}

		$obj =& $this->_getXmlObj($domainId);
		foreach($obj->Item as $record) {
			if(intval($record->ParentItemId) === intval($parentItemId) && intval($record->ParentType) === intval($parentType)) {
				$list[intval($record['id'])] = intval($record->DispNo);
			}
		}

		return $list;
	}

	/**
	 * アイテムを利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] 親アイテムID
	 * @param $parentType [in] 親アイテム種別
	 * @return bool 利用状況
	 */
	function isUseItem($domainId, $parentItemId, $parentType) {
		$obj =& $this->_getXmlObj($domainId);
		if(empty($obj->Item)) {
			return false;
		} else {
			foreach($obj->Item as $record) {
				if(intval($record->ParentItemId) === intval($parentItemId)
				&& intval($record->ParentType) === intval($parentType)) {
					return true;
				}
			}
			return false;
		}
	}
}

?>