<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class NewsData extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function NewsData($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/news.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}
	/**
	 * news_element登録状況確認
	 * @param $domainId [in] ドメインID
	 * @return bool 登録状況
	 */
	function isRegist($domainId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * news_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return NewsElement
	 */
	function &get($domainId, $isAll = false) {
		$info = new NewsElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return $info;
		}

		$info->isDisplay = (intval($obj->IsDisplay)===1);
		$info->displayType = intval($obj->DisplayType);
		$info->textDisplaytType = intval($obj->TextDisplayType);
		$info->slideWaitTime = intval($obj->SlideWaitTime);
		$info->scrollMovePixel = floatval($obj->ScrollMovePixel);
		$info->xAxis = intval($obj->XAxis);
		$info->yAxis = intval($obj->YAxis);
		$info->width = intval($obj->Width);
		$info->height = intval($obj->Height);
		$info->padding = intval($obj->Padding );
		$info->textColor = (string)$obj->TextColor;
		$info->textShadowColor = (string)$obj->TextShadowColor;
		$info->domainId = intval($domainId);

		if($isAll) {
			$info->skinElement = $this->getSkin($domainId);

			$info->itemElementList = $this->getItemList($domainId);
		}

		return $info;
	}

	/**
	 * news_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<News>
	<IsDisplay>0</IsDisplay>
	<DisplayType>0</DisplayType>
	<TextDisplayType>0</TextDisplayType>
	<SlideWaitTime>0</SlideWaitTime>
	<ScrollMovePixel>0</ScrollMovePixel>
	<XAxis>0</XAxis>
	<YAxis>0</YAxis>
	<Width>0</Width>
	<Height>0</Height>
	<Padding>0</Padding>
	<TextColor />
	<TextShadowColor />
</News>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$obj->IsDisplay       = ($info->isDisplay?1:0);
		$obj->DisplayType     = intval($info->displayType);
		$obj->TextDisplayType = intval($info->textDisplaytType);
		$obj->SlideWaitTime   = intval($info->slideWaitTime);
		$obj->ScrollMovePixel = floatval($info->scrollMovePixel);
		$obj->XAxis           = intval($info->xAxis);
		$obj->YAxis           = intval($info->yAxis);
		$obj->Width           = intval($info->width);
		$obj->Height          = intval($info->height);
		$obj->Padding         = intval($info->padding);
		$obj->TextColor       = $this->dbStr($info->textColor);
		$obj->TextShadowColor = $this->dbStr($info->textShadowColor);
		self::$_isWrite = true;

		if($isAll) {
			if(isset($info->skinElement)) {
				if(!$this->setSkin($domainId, $info->skinElement)) {
					return false;
				}
			}

			if(count($info->itemElementList) > 0) {
				foreach($info->itemElementList as $itemElement) {
					if(!$this->setItem($domainId, $itemElement)) {
						return false;
					}
				}
			}
		}

		return true;
	}


	/////////////
	/**
	 * news_skinを取得する
	 * @param $domainId [in] ドメインID
	 * @return NewsSkinElement
	 */
	function &getSkin($domainId) {
		$info = new NewsSkinElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Skin)) {
			return $info;
		}

		$info->mainIsDisplayGradation = (intval($obj->Skin->Main->IsDisplayGradation)===1);
		$info->mainGradationAlpha = intval($obj->Skin->Main->GradationAlpha);
		$info->mainBgColor = (string)$obj->Skin->Main->BgColor;
		$info->mainBgAlpha = intval($obj->Skin->Main->BgAlpha );
		$info->innerIsDisplayGradation = (intval($obj->Skin->Inner->IsDisplayGradation)===1);
		$info->innerGradationAlpha = intval($obj->Skin->Inner->GradationAlpha);
		$info->innerBgColor = (string)$obj->Skin->Inner->BgColor;
		$info->innerBgAlpha = intval($obj->Skin->Inner->BgAlpha );

		return $info;
	}

	/**
	 * news_skinにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsSkinElement
	 * @return bool 成功/失敗
	 */
	function setSkin($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return false;
		}

		if(isset($obj->Skin)) {
			if(!$this->_updateNewsSkinElement($domainId, $info)) {
				return false;
			}
		} else {
			if(!$this->_insertNewsSkinElement($domainId, $info)) {
				return false;
			}
		}

		return true;
	}

	private function _insertNewsSkinElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return false;
		}

		$data = $obj->addChild('Skin');

		$subData = $data->addChild('Main');
		$subData->addChild('IsDisplayGradation', ($info->mainIsDisplayGradation?1:0));
		$subData->addChild('GradationAlpha',     intval($info->mainGradationAlpha));
		$subData->addChild('BgColor',            $this->dbStr($info->mainBgColor));
		$subData->addChild('BgAlpha',            intval($info->mainBgAlpha));

		$subData = $data->addChild('Inner');
		$subData->addChild('IsDisplayGradation', ($info->innerIsDisplayGradation?1:0));
		$subData->addChild('GradationAlpha',     intval($info->innerGradationAlpha));
		$subData->addChild('BgColor',            $this->dbStr($info->innerBgColor));
		$subData->addChild('BgAlpha',            intval($info->innerBgAlpha));
		self::$_isWrite = true;

		return true;
	}

	private function _updateNewsSkinElement($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Skin)) {
			return false;
		}

		$obj->Skin->Main->IsDisplayGradation = ($info->mainIsDisplayGradation?1:0);
		$obj->Skin->Main->GradationAlpha     = intval($info->mainGradationAlpha);
		$obj->Skin->Main->BgColor            = $this->dbStr($info->mainBgColor);
		$obj->Skin->Main->BgAlpha            = intval($info->mainBgAlpha);

		$obj->Skin->Inner->IsDisplayGradation = ($info->innerIsDisplayGradation?1:0);
		$obj->Skin->Inner->GradationAlpha     = intval($info->innerGradationAlpha);
		$obj->Skin->Inner->BgColor            = $this->dbStr($info->innerBgColor);
		$obj->Skin->Inner->BgAlpha            = intval($info->innerBgAlpha);
		self::$_isWrite = true;

		return true;
	}

	/////////////
	/**
	 * news_item一覧を取得する
	 * @param $domainId [in] ドメインID
	 * @return NewsItemElement
	 */
	function &getItemList($domainId) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $list;
		}

		$obj =& $this->_getXmlObj($domainId);
		foreach($obj->Item as $record) {

			$info = new NewsItemElement();
			$info->itemId = intval($record['id']);

			$info->dispNo    = intval($record->DispNo);
			$info->title     = (string)$record->Title;
			$info->url       = (string)$record->Url;
			$info->urlTarget = intval($record->Url_target);

			$list[($info->dispNo-1)] = $info;
		}

		ksort($list);

		return $list;
	}

	/**
	 * news_itemを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ニュース記事ID
	 * @return NewsItemElement
	 */
	function &getItem($domainId, $itemId) {
		$info = new NewsItemElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $info;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$info->itemId = intval($itemId);
				$info->dispNo    = intval($record->DispNo);
				$info->title     = (string)$record->Title;
				$info->url       = (string)$record->Url;
				$info->urlTarget = intval($record->UrlTarget);
				break;
			}
		}
		return $info;
	}

	/**
	 * news_itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function setItem($domainId, $info) {
		if($info->itemId > 0) {
			if(!$this->updateNewsItemElement($domainId, $info)) {
				return false;
			}
		} else {
			if($this->insertNewsItemElement($domainId, $info) === 0) {
				return false;
			}
		}

		return true;
	}

	/**
	 * アイテムを挿入する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return intval アイテムID
	 */
	function insertNewsItemElement($domainId, $info) {

		$newId = 0;
		$obj =& $this->_getXmlObj($domainId);
		if(!empty($obj->Item)) {
			foreach($obj->Item as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Item');
		$data->addAttribute('id', $newId);

		$data->addChild('DispNo',    intval($info->dispNo));
		$data->addChild('Title',     $this->dbStr($info->title));
		$data->addChild('Url',       $this->dbStr($info->url));
		$data->addChild('UrlTarget', intval($info->urlTarget));
		self::$_isWrite = true;

		return $newId;
	}

	/**
	 * アイテムを更新する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function updateNewsItemElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return $list;
		}

		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($info->itemId)) {
				$record->DispNo    = intval($info->dispNo);
				$record->Title     = $this->dbStr($info->title);
				$record->Url       = $this->dbStr($info->url);
				$record->UrlTarget = intval($info->urlTarget);
				self::$_isWrite = true;
				return true;
			}
		}

		return false;
	}

	/**
	 * 表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ニュースアイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeDispNo($domainId, $itemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$oldDispNo = 0;

		$list = array();
		$obj =& $this->_getXmlObj($domainId);
		$cnt = 0;
		foreach($obj->Item as $record) {
			if(intval($itemId) === intval($record['id'])) {
				$oldDispNo = intval($record->DispNo);
			}
			$list[(intval($record->DispNo)-1)] = $cnt;
			$cnt++;
		}

		if($oldDispNo === 0) {
			return false;
		}
		if($oldDispNo === $newDispNo) {
			return true;
		}

		ksort($list);

		$start = min(array(($newDispNo-1), ($oldDispNo - 1)));
		$end   = max(array(($newDispNo-1), ($oldDispNo - 1)));
		$addVal = ($oldDispNo<$newDispNo?-1:+1);
		for($cnt = $start; $cnt <= $end; $cnt++) {
			if($cnt === ($oldDispNo-1)) {
				$obj->Item[$list[$cnt]]->DispNo = $newDispNo;
			} else {
				$obj->Item[$list[$cnt]]->DispNo = intval($obj->Item[$list[$cnt]]->DispNo) + $addVal;
			}
			self::$_isWrite = true;
		}

		return true;
	}

	/**
	 * ニュースアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] ニュースアイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $itemId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Item)) {
			return false;
		}

		$dispNo = 0;
		foreach($obj->Item as $record) {
			if(intval($record['id']) === intval($itemId)) {
				$dispNo = intval($record->DispNo);
				break;
			}
		}

		if($dispNo === 0) {
			return false;
		}

		$max = count($obj->Item)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Item[$cnt]['id']) === intval($itemId)) {
				unset($obj->Item[$cnt]);
				self::$_isWrite = true;
			} else if($dispNo < $obj->Item[$cnt]->DispNo) {
				$obj->Item[$cnt]->DispNo = intval($obj->Item[$cnt]->DispNo)-1;
				self::$_isWrite = true;
			}
		}

		return true;
	}

	/**
	 * 表示順の最大値取得
	 * @param $domainId [in] ドメインID
	 * @return intval 表示順の最大値
	 */
	function getMaxDispNo($domainId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {
			return 0;
		}

		return count($obj->Item);
	}
}