<?php
require_once dirname(__FILE__).'/../../photo_xml.php';

class PhotoImageItem extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function PhotoImageItem($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/photo_image.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * アイテムの最大表示順(件数から割り出したもの)を取得する
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @return intval 最大の表示順
	 */
	function getMaxDispNo($domainId, $photoId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return 0;
		}

		$cnt = 0;
		foreach($obj->Image as $record) {
			 if(intval($record->PhotoId) === intval($photoId)) {
			 	$cnt++;
			 }
		}
		return $cnt;
	}

	/**
	 * photo_image_item一覧を取得する
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return PhotoImageItemElemet
	 */
	function &getList($domainId, $photoId, $isAll = false) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return $list;
		}

		foreach($obj->Image as $record) {
			if(intval($photoId) === intval($record->PhotoId)) {

				$info = new PhotoImageItemElemet();
				$info->imageId  = intval($record['id']);
				$info->photoId = intval($record->PhotoId);
				$info->dispNo   = intval($record->DispNo);
				$info->name     = (string)$record->Name;
				$info->imageUrl = (string)$record->ImageUrl;

				$list[$info->dispNo] = $info;
			}
		}

		ksort($list);

		return $list;
	}

	/**
	 * photo_image_itemを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return PhotoImageItemElemet
	 */
	function &get($domainId, $photoId, $imageId, $isAll = false) {
		$info = new PhotoImageItemElemet();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return $info;
		}

		foreach($obj->Image as $record) {
			if(intval($imageId) === intval($record['id'])
			&& intval($photoId) === intval($record->PhotoId)) {

				$info = new PhotoImageItemElemet();
				$info->imageId  = intval($record['id']);
				$info->photoId = intval($record->PhotoId);
				$info->dispNo   = intval($record->DispNo);
				$info->name     = (string)$record->Name;
				$info->imageUrl = (string)$record->ImageUrl;

				break;
			}
		}

		return  $info;

	}

	/**
	 * photo_image_itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] PhotoImageItemElemet
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if(intval($info->imageId > 0)) {
			if(!$this->_updateElement($domainId, $info)) {
				return false;
			}
			$imageId = intval($info->imageId);
		} else {
			$imageId = $this->_insertElement($domainId, $info);
			if($imageId === 0) {
				return false;
			}
		}

		return true;
	}

	private function _insertElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Images>
</Images>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$newId = 0;
		if(!empty($obj->Image)) {
			foreach($obj->Image as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Image');
		$data->addAttribute('id', $newId);

		$data->addChild('PhotoId', intval($info->photoId));
		$data->addChild('Name',     $this->dbStr($info->name));
		$data->addChild('DispNo',   intval($info->dispNo));
		$data->addChild('ImageUrl', $this->dbStr($info->imageUrl));

		self::$_isWrite = true;

		return $newId;
	}

	private function _updateElement($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		foreach($obj->Image as $record) {
			if(intval($info->imageId) === intval($record['id'])) {
				$record->Name     = $this->dbStr($info->name);
				$record->DispNo   = intval($info->dispNo);
				$record->ImageUrl = $this->dbStr($info->imageUrl);
				self::$_isWrite = true;
				return true;
			}
		}

		return false;
	}

	/**
	 * イメージアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @param $imageId [in] イメージアイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $photoId, $imageId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return true;
		}

		$dispNo = 0;
		foreach($obj->Image as $record) {
			if(intval($record['id']) === intval($imageId)
			&& intval($record->PhotoId) === intval($photoId)) {
				$dispNo = intval($record->DispNo);
				break;
			}
		}
		if($dispNo === 0) {
			return false;
		}

		$max = count($obj->Image)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Image[$cnt]->PhotoId) === intval($photoId)) {
				if(intval($obj->Image[$cnt]['id']) === intval($imageId)) {
					unset($obj->Image[$cnt]);
					self::$_isWrite = true;
				} else if($dispNo < intval($obj->Image[$cnt]->DispNo)) {
					$obj->Image[$cnt]->DispNo = intval($obj->Image[$cnt]->DispNo) - 1;
					self::$_isWrite = true;
				}
			}
		}

		return true;
	}

	/**
	 * アイテム表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeDispNo($domainId, $photoId, $imageId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$oldDispNo = 0;

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		foreach($obj->Image as $record) {
			if(intval($imageId) === intval($record['id'])
			&& intval($photoId) === intval($record->PhotoId)) {
				$oldDispNo = intval($record->DispNo);
				break;
			}
		}

		if($oldDispNo === 0) {
			return false;
		}
		if($oldDispNo === $newDispNo) {
			return true;
		}

		reset($obj->Image);
		$start = min(array($newDispNo, $oldDispNo));
		$end   = max(array($newDispNo, $oldDispNo));
		$addVal = ($oldDispNo<$newDispNo?-1:+1);
		foreach($obj->Image as $record) {
			if($start <= intval($record->DispNo)
			&& intval($record->DispNo) <= $end
			&& intval($photoId) === intval($record->PhotoId)) {
				if(intval($record->DispNo) === $oldDispNo) {
					$record->DispNo = $newDispNo;
				} else {
					$record->DispNo = intval($record->DispNo) + $addVal;
				}
				self::$_isWrite = true;
			}
		}

		return true;
	}


	////////////////////////////
	//以下非共通
	////////////////////////////
	/**
	 * フォトギャラリーが画像アイテムを利用しているかをチェックする
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @return bool 利用状況
	 */
	function isUse($domainId, $photoId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		foreach($obj->Image as $record) {
			if(intval($photoId) === intval($record->PhotoId)) {
				return true;
			}
		}

		return false;
	}
}

?>
