<?php
require_once dirname(__FILE__).'/../../photo_xml.php';

class PhotoXml extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function PhotoXml($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/photo_xml.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * フォトギャラリー一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $isAll  [in] 子ノードも処理するかどうか
	 * @return array PhotoXmlInfo配列
	 */
	function &getList($domainId, $isAll = false) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Photo)) {
			return $list;
		}

		foreach($obj->Photo as $record) {
			$info = new PhotoXmlInfo();
			$info->photoId       = intval($record['id']);
			$info->number         = intval($record->Number);
			$info->name           = (string)$record->Name;
			$info->bgColor        = (string)$record->BgColor;
			$info->bgAlpha        = intval($record->BgAlpha);
			$info->width          = intval($record->Width);
			$info->height         = intval($record->Height);
			$info->isSequentialMode = (intval($record->IsSequentialMode)===1);
			$info->figureNumber   = intval($record->FigureNumber);
			$info->startValue     = intval($record->StartValue);
			$info->endValue       = intval($record->EndValue);
			$info->fileExtension  = (string)$record->FileExtension;
			$info->filePath       = (string)$record->FilePath;
			$info->imageSize      = intval($record->ImageSize);
			$info->isDisplayFrame = (intval($record->IsDisplayFrame)===1);
			$info->frameOuterColor = (string)$record->FrameOuterColor;
			$info->frameInnerColor = (string)$record->FrameInnerColor;

			if($isAll) {
				require_once 'image_item.php';
				$childElement = new PhotoImageItem($this->userName);
				$info->imageItemList = $childElement->getList($domainId, $info->photoId, $isAll);
			}

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * photo_dataを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return FlagXmlInfo
	 */
	function &get($domainId, $photoId, $isAll = false) {
		$info = new PhotoXmlInfo();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Photo)) {
			return $info;
		}
		foreach($obj->Photo as $record) {
			if(intval($photoId) === intval($record['id'])) {
				$info->photoId       = intval($record['id']);
				$info->number         = intval($record->Number);
				$info->name           = (string)$record->Name;
				$info->bgColor        = (string)$record->BgColor;
				$info->bgAlpha        = intval($record->BgAlpha);
				$info->width          = intval($record->Width);
				$info->height         = intval($record->Height);
				$info->isSequentialMode = (intval($record->IsSequentialMode)===1);
				$info->figureNumber   = intval($record->FigureNumber);
				$info->startValue     = intval($record->StartValue);
				$info->endValue       = intval($record->EndValue);
				$info->fileExtension  = (string)$record->FileExtension;
				$info->filePath       = (string)$record->FilePath;
				$info->imageSize      = intval($record->ImageSize);
				$info->isDisplayFrame = (intval($record->IsDisplayFrame)===1);
				$info->frameOuterColor = (string)$record->FrameOuterColor;
				$info->frameInnerColor = (string)$record->FrameInnerColor;

				if($isAll) {
					require_once 'image_item.php';
					$childElement = new PhotoImageItem($this->userName);
					$info->imageItemList = $childElement->getList($domainId, $info->photoId, $isAll);
				}

				break;
			}
		}

		return $info;
	}

	/**
	 * photo_dataにデータを設定する
	 * すべて書き換える場合、先にdeleteする必要がある。
	 * @param $domainId [in] ドメインID
	 * @param $info [in] FlagXmlInfo
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if($info->photoId > 0) {
			if(!$this->_update($domainId, $info)) {
				return false;
			}
			$photoId = $info->photoId;
		} else {
			$photoId = $this->_insert($domainId, $info);
			if($photoId === 0) {
				return false;
			}
		}

		if($isAll) {
			if(isset($info->imageItemList)) {
				require_once 'image_item.php';
				$childElement = new PhotoImageItem($this->userName);
				foreach($info->imageItemList as $imageItem) {
					$imageItem->photoId = $photoId;
					if(!$childElement->set($domainId, $imageItem, $isAll)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	private function _insert($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Photos>
</Photos>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$newId = 0;
		if(!empty($obj->Photo)) {
			foreach($obj->Photo as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Photo');
		$data->addAttribute('id', $newId);

		$data->addChild('Number',           intval($info->number));
		$data->addChild('Name',             $this->dbStr($info->name));
		$data->addChild('BgColor',          $this->dbStr($info->bgColor));
		$data->addChild('BgAlpha',          intval($info->bgAlpha));
		$data->addChild('Width',            intval($info->width));
		$data->addChild('Height',           intval($info->height));
		$data->addChild('IsSequentialMode', ($info->isSequentialMode?1:0));
		$data->addChild('FigureNumber',     intval($info->figureNumber));
		$data->addChild('StartValue',       intval($info->startValue));
		$data->addChild('EndValue',         intval($info->endValue));
		$data->addChild('FileExtension',    $this->dbStr($info->fileExtension));
		$data->addChild('FilePath',         $this->dbStr($info->filePath));
		$data->addChild('ImageSize',        intval($info->imageSize));
		$data->addChild('IsDisplayFrame',   ($info->isDisplayFrame?1:0));
		$data->addChild('FrameOuterColor',  $this->dbStr($info->frameOuterColor));
		$data->addChild('FrameInnerColor',  $this->dbStr($info->frameInnerColor));

		self::$_isWrite = true;

		return $newId;
	}

	private function _update($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Photo)) {
			return false;
		}
		foreach($obj->Photo as $record) {
			if(intval($info->photoId) === intval($record['id'])) {
				$record->Name =             $this->dbStr($info->name);
				$record->BgColor =          $this->dbStr($info->bgColor);
				$record->BgAlpha =          intval($info->bgAlpha);
				$record->Width =            intval($info->width);
				$record->Height =           intval($info->height);
				$record->IsSequentialMode = ($info->isSequentialMode?1:0);
				$record->FigureNumber =     intval($info->figureNumber);
				$record->StartValue =       intval($info->startValue);
				$record->EndValue =         intval($info->endValue);
				$record->FileExtension =    $this->dbStr($info->fileExtension);
				$record->FilePath =         $this->dbStr($info->filePath);
				$record->ImageSize =        intval($info->imageSize);
				$record->IsDisplayFrame =   ($info->isDisplayFrame?1:0);
				$record->FrameOuterColor =  $this->dbStr($info->frameOuterColor);
				$record->FrameInnerColor =  $this->dbStr($info->frameInnerColor);

				self::$_isWrite = true;

				return true;
			}
		}

		return false;
	}


	/**
	 * 全削除
	 * @param $domainId [in] ドメインID
	 * @return bool 成功/失敗
	 */
	function deleteAll($domainId) {
		self::closeFileHandle(self::$_fileHandle);
		self::$_xmlObj = null;

		$fileList = array(
			 'photo_image.xml'
			,'photo_xml.xml'
		);

		$domainDataPath = Config::TEXT_DATA_PATH.sprintf('%03d/', $domainId);
		foreach($fileList as $fileName) {
			if(is_file($domainDataPath.$fileName)) {
				unlink($domainDataPath.$fileName);
			}
		}

		return true;
	}

	/**
	 * フォトギャラリー番号の最大値取得
	 * @param $domainId [in] ドメイン番号
	 * @return intval フォトギャラリー番号最大値
	 */
	function getMaxNumber($domainId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Photo)) {
			return 0;
		}

		$number = 0;
		foreach($obj->Photo as $record) {
			$number = max($number, intval($record->Number));
		}

		return $number;
	}

	/**
	 * 削除可能かチェックする
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @return bool 削除可否
	 */
	function isCanDelete($domainId, $photoId) {
		require_once dirname(__FILE__).'/image_item.php';
		$childElement = new PhotoImageItem($this->userName);

		return (!$childElement->isUse($domainId, $photoId));

	}

	/**
	 * 削除
	 * @param $domainId [in] ドメインID
	 * @param $photoId [in] フォトギャラリーID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $photoId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Photo)) {
			return true;
		}

		$max = count($obj->Photo)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Photo[$cnt]['id']) === intval($photoId)) {
				unset($obj->Photo[$cnt]);
				self::$_isWrite = true;
				return true;
			}
		}

		return true;
	}
}