<?php
require_once dirname(__FILE__).'/../flag_xml.php';

class PlayerData extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function PlayerData($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/player.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * player_elementを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] itemに所属する場合、itemId。0でXML所属playerが対象
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @return PlayerElement
	 */
	function &get($domainId, $itemId, $parentType = 0) {
		$info = new PlayerElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return $info;
		}

		foreach($obj->Player as $record) {
			if(intval($record->ItemId) === intval($itemId) && intval($record->ParentType) === intval($parentType)) {
				$info->itemId             = intval($itemId);
				$info->playerType         = intval($record->PlayerType);
				$info->xAxis              = (isset($record->XAxis)?intval($record->XAxis):null);
				$info->yAxis              = (isset($record->YAxis)?intval($record->YAxis):null);
				$info->width              = (isset($record->Width)?intval($record->Width):null);
				$info->height             = (isset($record->Height)?intval($record->Height):null);
				$info->fileUrl            = (isset($record->FileUrl)?((string)$record->FileUrl):'');
				$info->fileTitle          = (isset($record->FileTitle)?((string)$record->FileTitle):'');
				$info->fileThumbUrl       = (isset($record->FileThumbUrl)?((string)$record->FileThumbUrl):'');
				$info->isAutoPlay         = (isset($record->IsAutoPlay)?(intval($record->IsAutoPlay)===1):null);
				$info->isAutoReplay       = (isset($record->IsAutoReplay)?(intval($record->IsAutoReplay)===1):null);
				$info->isDisplayMenu      = (isset($record->IsDisplayMenu)?(intval($record->IsDisplayMenu)===1):null);
				$info->menuPosition       = (isset($record->MenuPosition)?intval($record->MenuPosition):null);
				$info->menuBgColor        = (isset($record->MenuBgColor)?((string)$record->MenuBgColor):'');
				$info->isDisplayEqualizer = (isset($record->IsDisplayEqualizer)?(intval($record->IsDisplayEqualizer)===1):null);
				$info->equalizerBear      = (isset($record->EqualizerBear)?intval($record->EqualizerBear):null);
				$info->equalizerFall      = (isset($record->EqualizerFall)?intval($record->EqualizerFall):null);
				$info->outsideUrl         = (isset($record->OutsideUrl)?((string)$record->OutsideUrl):'');
				$info->domainId = intval($domainId);
				$info->parentType = intval($parentType);

				$info->fileType = (isset($record->FileType)?intval($record->FileType):1);
				$info->playlistPlayType = (isset($record->PlayList->PlayType)?intval($record->PlayList->PlayType):2);
				$info->playlistStartNumber = (isset($record->PlayList->StartNumber)?intval($record->PlayList->StartNumber):null);
				$info->isDisplayPlayAndStopMenu = (isset($record->MenuItem->IsDisplayPlayAndStop)?(intval($record->MenuItem->IsDisplayPlayAndStop)===1):null);
				$info->isDisplaySeekBarMenu     = (isset($record->MenuItem->IsDisplaySeekBar)?(intval($record->MenuItem->IsDisplaySeekBar)===1):null);
				$info->isDisplayPlayTimeMenu    = (isset($record->MenuItem->IsDisplayPlayTime)?(intval($record->MenuItem->IsDisplayPlayTime)===1):null);
				$info->isDisplayResizeMenu      = (isset($record->MenuItem->IsDisplayResize)?(intval($record->MenuItem->IsDisplayResize)===1):null);
				$info->isDisplaySoundMenu       = (isset($record->MenuItem->IsDisplaySound)?(intval($record->MenuItem->IsDisplaySound)===1):null);

				$info->playlistItemList = $this->_getItemListFromObj($record['id'], $record->PlayList);

				break;
			}
		}

		return $info;
	}

	/**
	 * player_elementにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] PlayerElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Players>
</Players>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		if(empty($obj->Player)) {
			$playerId = $this->_insertPlayerElement($domainId, $info);
			if($playerId === 0) {
				return false;
			}
		} else {

			$playerId = 0;
			foreach($obj->Player as $record) {
				if(intval($record->ItemId) === $info->itemId && intval($record->ParentType) === intval($info->parentType)) {
					if($this->_updatePlayerElement($record, $info)) {
						$playerId = intval($record['id']);
						break;
					} else {
						return false;
					}
				}
			}

			if($playerId === 0) {
				$playerId = $this->_insertPlayerElement($domainId, $info);
				if($playerId === 0) {
					return false;
				}
			}
		}


		if($isAll) {
			if(count($info->playlistItemList) > 0) {
				foreach($info->playlistItemList as $itemElement) {
					$itemElement->playerId = $playerId;
					if(!$this->setPlaylistItem($domainId, $itemElement)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	private function _insertPlayerElement($domainId, $info) {

		$newId = 0;
		$obj =& $this->_getXmlObj($domainId);
		if(!empty($obj->Player)) {
			foreach($obj->Player as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;


		$data = $obj->addChild('Player');
		$data->addAttribute('id', $newId);

		$data->addChild('ParentType', intval($info->parentType));
		if(intval($info->itemId) > 0) {
			$data->addChild('ItemId', intval($info->itemId));
		}
		$data->addChild('PlayerType', intval($info->playerType));

		if(isset($info->xAxis)) {
			$data->addChild('XAxis', intval($info->xAxis));
		}
		if(isset($info->yAxis)) {
			$data->addChild('YAxis', intval($info->yAxis));
		}
		if(isset($info->width)) {
			$data->addChild('Width', intval($info->width));
		}
		if(isset($info->height)) {
			$data->addChild('Height', intval($info->height));
		}
		$data->addChild('FileUrl',      $this->dbStr($info->fileUrl));
		$data->addChild('FileTitle',    $this->dbStr($info->fileTitle));
		$data->addChild('FileThumbUrl', $this->dbStr($info->fileThumbUrl));
		if(isset($info->isAutoPlay)) {
			$data->addChild('IsAutoPlay', ($info->isAutoPlay?1:0));
		}
		if(isset($info->isAutoReplay)) {
			$data->addChild('IsAutoReplay', ($info->isAutoReplay?1:0));
		}
		if(isset($info->isDisplayMenu)) {
			$data->addChild('IsDisplayMenu', ($info->isDisplayMenu?1:0));
		}
		if(isset($info->menuPosition)) {
			$data->addChild('MenuPosition', intval($info->menuPosition));
		}
		$data->addChild('MenuBgColor', $this->dbStr($info->menuBgColor));
		if(isset($info->isDisplayEqualizer)) {
			$data->addChild('IsDisplayEqualizer', ($info->isDisplayEqualizer?1:0));
		}
		if(isset($info->equalizerBear)) {
			$data->addChild('EqualizerBear', intval($info->equalizerBear));
		}
		if(isset($info->equalizerFall)) {
			$data->addChild('EqualizerFall', intval($info->equalizerFall));
		}
		$data->addChild('OutsideUrl', $this->dbStr($info->outsideUrl));

		$data->addChild('FileType', intval($info->fileType));
		$playListData = $data->addChild('PlayList');
		$playListData->addChild('PlayType', intval($info->playlistPlayType));
		if(isset($info->playlistStartNumber)) {
			$playListData->addChild('StartNumber', intval($info->playlistStartNumber));
		}

		$menuItem = $data->addChild('MenuItem');
		if(isset($info->isDisplayPlayAndStopMenu)) {
			$menuItem->addChild('IsDisplayPlayAndStop', ($info->isDisplayPlayAndStopMenu?1:0));
		}
		if(isset($info->isDisplaySeekBarMenu)) {
			$menuItem->addChild('IsDisplaySeekBar', ($info->isDisplaySeekBarMenu?1:0));
		}
		if(isset($info->isDisplayPlayTimeMenu)) {
			$menuItem->addChild('IsDisplayPlayTime', ($info->isDisplayPlayTimeMenu?1:0));
		}
		if(isset($info->isDisplayResizeMenu)) {
			$menuItem->addChild('IsDisplayResize', ($info->isDisplayResizeMenu?1:0));
		}
		if(isset($info->isDisplaySoundMenu)) {
			$menuItem->addChild('IsDisplaySound', ($info->isDisplaySoundMenu?1:0));
		}

		self::$_isWrite = true;

		return $newId;
	}

	private function _updatePlayerElement(&$record, $info) {
		$record->PlayerType = intval($info->playerType);
		if(isset($info->xAxis)) {
			$record->XAxis = intval($info->xAxis);
		} else {
			unset($record->XAxis);
		}
		if(isset($info->yAxis)) {
			$record->YAxis = intval($info->yAxis);
		} else {
			unset($record->YAxis);
		}
		if(isset($info->width)) {
			$record->Width = intval($info->width);
		} else {
			unset($record->Width);
		}
		if(isset($info->height)) {
			$record->Height = intval($info->height);
		} else {
			unset($record->Height);
		}
		$record->FileUrl = $this->dbStr($info->fileUrl);
		$record->FileTitle = $this->dbStr($info->fileTitle);
		$record->FileThumbUrl = $this->dbStr($info->fileThumbUrl);
		if(isset($info->isAutoPlay)) {
			$record->IsAutoPlay = ($info->isAutoPlay?1:0);
		} else {
			unset($record->IsAutoPlay);
		}
		if(isset($info->isAutoReplay)) {
			$record->IsAutoReplay = ($info->isAutoReplay?1:0);
		} else {
			unset($record->IsAutoReplay);
		}
		if(isset($info->isDisplayMenu)) {
			$record->IsDisplayMenu = ($info->isDisplayMenu?1:0);
		} else {
			unset($record->IsDisplayMenu);
		}
		if(isset($info->menuPosition)) {
			$record->MenuPosition = intval($info->menuPosition);
		} else {
			unset($record->MenuPosition);
		}
		$record->MenuBgColor = $this->dbStr($info->menuBgColor);
		if(isset($info->isDisplayEqualizer)) {
			$record->IsDisplayEqualizer = ($info->isDisplayEqualizer?1:0);
		} else {
			unset($record->IsDisplayEqualizer);
		}
		if(isset($info->equalizerBear)) {
			$record->EqualizerBear = intval($info->equalizerBear);
		} else {
			unset($record->EqualizerBear);
		}
		if(isset($info->equalizerFall)) {
			$record->EqualizerFall = intval($info->equalizerFall);
		} else {
			unset($record->EqualizerFall);
		}
		$record->OutsideUrl = $this->dbStr($info->outsideUrl);

		$record->FileType = intval($info->fileType);
		$record->PlayList->PlayType = intval($info->playlistPlayType);
		if(isset($info->playlistStartNumber)) {
			$record->PlayList->StartNumber = intval($info->playlistStartNumber);
		} else {
			unset($record->PlayList->StartNumber);
		}

		if(isset($info->isDisplayPlayAndStopMenu)) {
			$record->MenuItem->IsDisplayPlayAndStop = ($info->isDisplayPlayAndStopMenu?1:0);
		} else {
			unset($record->MenuItem->IsDisplayPlayAndStop);
		}
		if(isset($info->isDisplaySeekBarMenu)) {
			$record->MenuItem->IsDisplaySeekBar = ($info->isDisplaySeekBarMenu?1:0);
		} else {
			unset($record->MenuItem->IsDisplaySeekBar);
		}
		if(isset($info->isDisplayPlayTimeMenu)) {
			$record->MenuItem->IsDisplayPlayTime = ($info->isDisplayPlayTimeMenu?1:0);
		} else {
			unset($record->MenuItem->IsDisplayPlayTime);
		}
		if(isset($info->isDisplayResizeMenu)) {
			$record->MenuItem->IsDisplayResize = ($info->isDisplayResizeMenu?1:0);
		} else {
			unset($record->MenuItem->IsDisplayResize);
		}
		if(isset($info->isDisplaySoundMenu)) {
			$record->MenuItem->IsDisplaySound = ($info->isDisplaySoundMenu?1:0);
		} else {
			unset($record->MenuItem->IsDisplaySound);
		}

		self::$_isWrite = true;

		return true;
	}

	/**
	 * 指定したItemIDの子のPlayer一覧を取得する(簡易設定用)
	 * ボタンがないところは無し。
	 * @param $domainId [in] ドメインID
	 * @param $parentItemId [in] 親ItemID
	 * @return array PlayerElementリスト(キー：表示順)
	 */
	function &getChildPlayerList($domainId, $parentItemId) {
		$list = array();

		require_once 'item_data.php';
		$itemData = new ItemData($this->userName);
		$itemIdList = &$itemData->getChildList($domainId, $parentItemId);

		if(count($itemIdList) === 0) {
			return $list;
		}


		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return $list;
		}

		foreach($obj->Player as $record) {
			if(intval($record->ParentType) === 0) {
				if(array_key_exists(intval($record->ItemId), $itemIdList)) {
					$info = new PlayerElement();
					$info->itemId             = intval($record->ItemId);
					$info->playerType         = intval($record->PlayerType);
					$info->xAxis              = (isset($record->XAxis)?intval($record->XAxis):null);
					$info->yAxis              = (isset($record->YAxis)?intval($record->YAxis):null);
					$info->width              = (isset($record->Width)?intval($record->Width):null);
					$info->height             = (isset($record->Height)?intval($record->Height):null);
					$info->fileUrl            = (isset($record->FileUrl)?((string)$record->FileUrl):'');
					$info->fileTitle          = (isset($record->FileTitle)?((string)$record->FileTitle):'');
					$info->fileThumbUrl       = (isset($record->FileThumbUrl)?((string)$record->FileThumbUrl):'');
					$info->isAutoPlay         = (isset($record->IsAutoPlay)?(intval($record->IsAutoPlay)===1):null);
					$info->isAutoReplay       = (isset($record->IsAutoReplay)?(intval($record->IsAutoReplay)===1):null);
					$info->isDisplayMenu      = (isset($record->IsDisplayMenu)?(intval($record->IsDisplayMenu)===1):null);
					$info->menuPosition       = (isset($record->MenuPosition)?intval($record->MenuPosition):null);
					$info->menuBgColor        = (isset($record->MenuBgColor)?((string)$record->MenuBgColor):'');
					$info->isDisplayEqualizer = (isset($record->IsDisplayEqualizer)?(intval($record->IsDisplayEqualizer)===1):null);
					$info->equalizerBear      = (isset($record->EqualizerBear)?intval($record->EqualizerBear):null);
					$info->equalizerFall      = (isset($record->EqualizerFall)?intval($record->EqualizerFall):null);
					$info->outsideUrl         = (isset($record->OutsideUrl)?((string)$record->OutsideUrl):'');
					$info->domainId = intval($domainId);
					$info->fileType            = (isset($record->FileType)?intval($record->FileType):1);
					$info->playlistPlayType    = (isset($record->PlayList->PlayType)?intval($record->PlayList->PlayType):2);
					$info->playlistStartNumber = (isset($record->PlayList->StartNumber)?intval($record->PlayList->StartNumber):null);
					$info->isDisplayPlayAndStopMenu = (isset($record->MenuItem->IsDisplayPlayAndStop)?(intval($record->MenuItem->IsDisplayPlayAndStop)===1):null);
					$info->isDisplaySeekBarMenu     = (isset($record->MenuItem->IsDisplaySeekBar)?(intval($record->MenuItem->IsDisplaySeekBar)===1):null);
					$info->isDisplayPlayTimeMenu    = (isset($record->MenuItem->IsDisplayPlayTime)?(intval($record->MenuItem->IsDisplayPlayTime)===1):null);
					$info->isDisplayResizeMenu      = (isset($record->MenuItem->IsDisplayResize)?(intval($record->MenuItem->IsDisplayResize)===1):null);
					$info->isDisplaySoundMenu       = (isset($record->MenuItem->IsDisplaySound)?(intval($record->MenuItem->IsDisplaySound)===1):null);

					$list[$itemIdList[$info->itemId]] = $info;
				}
			}
		}

		return $list;


	}

	/**
	 * プレイヤー削除
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $itemId, $parentType = 0) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return true;
		}
		$max = count($obj->Player)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Player[$cnt]->ItemId) === intval($itemId)
			&& intval($obj->Player[$cnt]->ParentType) === intval($parentType)) {
				unset($obj->Player[$cnt]);
				self::$_isWrite = true;
				return true;
			}
		}
		return true;
	}

	////////////////////////////

	/**
	 * PlayerIDを取得する
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] itemに所属する場合、itemId。0でXML所属playerが対象
	 * @param $parentType [in] 親種別（0:初期値,子階層/1:スライダー画像アイテム）
	 * @return integer PlayerID
	 */
	function getPlayerId($domainId, $itemId, $parentType) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return 0;
		}

		foreach($obj->Player as $record) {
			if(intval($record->ItemId) === intval($itemId) && intval($record->ParentType) === intval($parentType)) {
				return intval($record['id']);
			}
		}

		return 0;
	}

	/**
	 * プレイリストのアイテム一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $playerId [in] プレイヤーID
	 * @return array PlayerPlayListItem一覧
	 */
	function &getItemList($domainId, $playerId) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return $list;
		}

		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($playerId)) {
				$list = $this->_getItemListFromObj($playerId, $record->PlayList);
				break;
			}
		}
		return $list;
	}

	private function &_getItemListFromObj($playerId, $obj) {
		$list = array();

		if(isset($obj->Item)) {
			foreach($obj->Item as $record) {
				$itemInfo = new PlayerPlayListItem();
				$itemInfo->dispNo = intval($record->DispNo);
				$itemInfo->fileUrl = (string)$record->Url;
				$itemInfo->fileTitle = (string)$record->Title;
				$itemInfo->fileThumbUrl = (string)$record->ThumbUrl;
				$itemInfo->playerId = intval($playerId);
				$itemInfo->playlistItemId = intval($record['id']);

				$list[$itemInfo->dispNo] = $itemInfo;
			}
		}

		ksort($list);

		return $list;
	}

	/**
	 * プレイリストアイテム取得
	 * @param $domainId [in] ドメインID
	 * @param $playerId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @return PlayerPlayListItem
	 */
	function &getPlaylistItem($domainId, $playerId, $playlistItemId) {
		$itemInfo = new PlayerPlayListItem();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return $itemInfo;
		}

		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($playerId)) {
				if(isset($record->PlayList->Item)) {
					foreach($record->PlayList->Item as $itemRecord) {
						if(intval($itemRecord['id']) === intval($playlistItemId)) {
							$itemInfo->dispNo = intval($itemRecord->DispNo);
							$itemInfo->fileUrl = (string)$itemRecord->Url;
							$itemInfo->fileTitle = (string)$itemRecord->Title;
							$itemInfo->fileThumbUrl = (string)$itemRecord->ThumbUrl;
							$itemInfo->playerId = intval($playerId);
							$itemInfo->playlistItemId = intval($itemRecord['id']);
							return $itemInfo;
						}
					}

				} else {
					return $itemInfo;
				}
			}
		}
		return $itemInfo;

	}

	/**
	 * 表示順の最大値取得
	 * @param $domainId [in] ドメインID
	 * @param $playerId [in] プレイヤーID
	 * @return intval 表示順の最大値
	 */
	function getPlaylistItemMaxDispNo($domainId, $playerId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return 0;
		}

		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($playerId)) {
				if(isset($record->PlayList->Item)) {
					return count($record->PlayList->Item);
				} else {
					return 0;
				}
			}
		}
		return 0;
	}

	/**
	 * itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] NewsItemElement
	 * @return bool 成功/失敗
	 */
	function setPlaylistItem($domainId, $info) {
		if($info->playlistItemId > 0) {
			if(!$this->updatePlaylistItemElement($domainId, $info)) {
				return false;
			}
		} else {
			if($this->insertPlaylistItemElement($domainId, $info) === 0) {
				return false;
			}
		}

		return true;
	}

	/**
	 * アイテムを挿入する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] PlayerPlayListItem
	 * @return intval アイテムID
	 */
	function insertPlaylistItemElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return 0;
		}

		$playerObj = null;
		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($info->playerId)) {
				$playerObj = $record;
				break;
			}
		}

		$newId = 0;
		if(isset($playerObj)) {

			if(!isset($playerObj->PlayList)) {
				$playerObj->addChild('PlayList');
			}

			if(isset($playerObj->PlayList->Item)) {
				foreach($playerObj->PlayList->Item as $record) {
					$newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
				}
			}
			$newId++;

			$data = $playerObj->PlayList->addChild('Item');
			$data->addAttribute('id', $newId);
			$data->addChild('DispNo',   intval($info->dispNo));
			$data->addChild('Url',      $this->dbStr($info->fileUrl));
			$data->addChild('Title',    $this->dbStr($info->fileTitle));
			$data->addChild('ThumbUrl', $this->dbStr($info->fileThumbUrl));

			self::$_isWrite = true;

		}
		return $newId;
	}

	/**
	 * アイテムを更新する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] PlayerPlayListItem
	 * @return bool 成功/失敗
	 */
	function updatePlaylistItemElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return false;
		}

		$playerObj = null;
		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($info->playerId)) {
				$playerObj = $record;
				break;
			}
		}

		if(isset($playerObj->PlayList->Item)) {

			foreach($playerObj->PlayList->Item as $record) {
				if(intval($record['id']) === $info->playlistItemId) {
					$record->DispNo = intval($info->dispNo);
					$record->Url = $this->dbStr($info->fileUrl);
					$record->Title = $this->dbStr($info->fileTitle);
					$record->ThumbUrl = $this->dbStr($info->fileThumbUrl);
					self::$_isWrite = true;

					return true;
				}
			}
		}

		return false;
	}

	/**
	 * 表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $playerId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changePlaylistItemDispNo($domainId, $playerId, $playlistItemId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$oldDispNo = 0;

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return false;
		}

		$playerObj = null;
		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($playerId)) {
				$playerObj = $record;
				break;
			}
		}

		if(isset($playerObj)) {

			$cnt = 0;
			foreach($playerObj->PlayList->Item as $record) {
				if(intval($playlistItemId) === intval($record['id'])) {
					$oldDispNo = intval($record->DispNo);
				}
				$list[(intval($record->DispNo)-1)] = $cnt;
				$cnt++;
			}

			if($oldDispNo === 0) {
				return false;
			}
			if($oldDispNo === $newDispNo) {
				return true;
			}

			ksort($list);

			$start = min(array(($newDispNo-1), ($oldDispNo - 1)));
			$end   = max(array(($newDispNo-1), ($oldDispNo - 1)));
			$addVal = ($oldDispNo<$newDispNo?-1:+1);
			for($cnt = $start; $cnt <= $end; $cnt++) {
				if($cnt === ($oldDispNo-1)) {
					$playerObj->PlayList->Item[$list[$cnt]]->DispNo = $newDispNo;
				} else {
					$playerObj->PlayList->Item[$list[$cnt]]->DispNo = intval($playerObj->PlayList->Item[$list[$cnt]]->DispNo) + $addVal;
				}
				self::$_isWrite = true;
			}
		}

		return true;
	}

	/**
	 * プレイリストアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $playerId [in] プレイヤーID
	 * @param $playlistItemId [in] プレイリストアイテムID
	 * @return bool 成功/失敗
	 */
	function deletePlaylistItem($domainId, $playerId, $playlistItemId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Player)) {
			return false;
		}

		$playerObj = null;
		foreach($obj->Player as $record) {
			if(intval($record['id']) === intval($playerId)) {
				$playerObj = $record;
				break;
			}
		}

		if(isset($playerObj)) {
			$dispNo = 0;
			foreach($playerObj->PlayList->Item as $record) {
				if(intval($record['id']) === intval($playlistItemId)) {
					$dispNo = intval($record->DispNo);
					break;
				}
			}

			if($dispNo === 0) {
				return false;
			}

			$max = count($playerObj->PlayList->Item)-1;
			for($cnt = $max; $cnt >= 0; $cnt--) {
				if(intval($playerObj->PlayList->Item[$cnt]['id']) === intval($playlistItemId)) {
					unset($playerObj->PlayList->Item[$cnt]);
					self::$_isWrite = true;
				} else if($dispNo < $playerObj->PlayList->Item[$cnt]->DispNo) {
					$playerObj->PlayList->Item[$cnt]->DispNo = intval($playerObj->PlayList->Item[$cnt]->DispNo)-1;
					self::$_isWrite = true;
				}
			}

		}
	}


	////////////////////////////
	//以下非共通
	////////////////////////////
	/**
	 * プレイヤーを利用しているかどうかチェックする
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $parentType [in] 親アイテム種別
	 * @return bool 利用状況
	 */
	function isUsePlayer($domainId, $itemId, $parentType) {
		$obj =& $this->_getXmlObj($domainId);
		if(empty($obj->Player)) {
			return false;
		} else {
			foreach($obj->Player as $record) {
				if(intval($record->ItemId) === intval($itemId)
				&& intval($record->ParentType) === intval($parentType)) {
					return true;
				}
			}
			return false;
		}
	}
}
?>