<?php
require_once dirname(__FILE__).'/../../slider_xml.php';

class SliderImageItem extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function SliderImageItem($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/slider_image.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * アイテムの最大表示順(件数から割り出したもの)を取得する
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @return intval 最大の表示順
	 */
	function getMaxDispNo($domainId, $sliderId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return 0;
		}

		$cnt = 0;
		foreach($obj->Image as $record) {
			 if(intval($record->SliderId) === intval($sliderId)) {
			 	$cnt++;
			 }
		}
		return $cnt;
	}

	/**
	 * slider_image_item一覧を取得する
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return SliderImageItemElemet
	 */
	function &getList($domainId, $sliderId, $isAll = false) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return $list;
		}

		foreach($obj->Image as $record) {
			if(intval($sliderId) === intval($record->SliderId)) {

				$info = new SliderImageItemElemet();
				$info->imageId  = intval($record['id']);
				$info->sliderId = intval($record->SliderId);
				$info->dispNo   = intval($record->DispNo);
				$info->name     = (string)$record->Name;
				$info->imageUrl = (string)$record->ImageUrl;

				if($isAll) {
					if(!empty($record->Action)) {
						$info->actionElement = new SliderActionElement();

						$info->actionElement->linkUrl       = (string)$record->Action->LinkUrl;
						$info->actionElement->linkUrlTarget = intval($record->Action->LinkUrlTarget);
						$info->actionElement->bgImage       = (string)$record->Action->BgImage;
					}

					require_once dirname(__FILE__).'/../player_data.php';
					$childElement = new PlayerData($this->userName);
					$playerElement = $childElement->get($domainId, $info->imageId, 1);
					if($playerElement->domainId > 0) {
						if($info->actionElement === null) {
							$info->actionElement = new SliderActionElement();
						}
						$info->actionElement->playerElement = $playerElement;
					}

					require_once dirname(__FILE__).'/../item_data.php';
					$childElement = new ItemData($this->userName);
					$childItemList =& $childElement->getList($domainId, $info->imageId, 1, $isAll);
					if(count($childItemList) > 0) {
						if($info->actionElement === null) {
							$info->actionElement = new SliderActionElement();
						}
						$info->actionElement->itemElementList = $childItemList;
					}
				}

				$list[$info->dispNo] = $info;
			}
		}

		ksort($list);

		return $list;
	}

	/**
	 * slider_image_itemを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return SliderImageItemElemet
	 */
	function &get($domainId, $sliderId, $imageId, $isAll = false) {
		$info = new SliderImageItemElemet();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return $info;
		}

		foreach($obj->Image as $record) {
			if(intval($imageId) === intval($record['id'])
			&& intval($sliderId) === intval($record->SliderId)) {

				$info = new SliderImageItemElemet();
				$info->imageId  = intval($record['id']);
				$info->sliderId = intval($record->SliderId);
				$info->dispNo   = intval($record->DispNo);
				$info->name     = (string)$record->Name;
				$info->imageUrl = (string)$record->ImageUrl;

				if($isAll) {
					if(!empty($record->Action)) {
						$info->actionElement = new SliderActionElement();

						$info->actionElement->linkUrl       = (string)$record->Action->LinkUrl;
						$info->actionElement->linkUrlTarget = intval($record->Action->LinkUrlTarget);
						$info->actionElement->bgImage       = (string)$record->Action->BgImage;
					}

					require_once dirname(__FILE__).'/../player_data.php';
					$childElement = new PlayerData($this->userName);
					$playerElement = $childElement->get($domainId, $info->imageId, 1);
					if($playerElement->domainId > 0) {
						if($info->actionElement === null) {
							$info->actionElement = new SliderActionElement();
						}
						$info->actionElement->playerElement = $playerElement;
					}

					require_once dirname(__FILE__).'/../item_data.php';
					$childElement = new ItemData($this->userName);
					$childItemList =& $childElement->getList($domainId, $info->imageId, 1, $isAll);
					if(count($childItemList) > 0) {
						if($info->actionElement === null) {
							$info->actionElement = new SliderActionElement();
						}
						$info->actionElement->itemElementList = $childItemList;
					}
				}

				break;
			}
		}

		return  $info;

	}

	/**
	 * slider_image_itemにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $info [in] SliderImageItemElemet
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if(intval($info->imageId > 0)) {
			if(!$this->_updateElement($domainId, $info)) {
				return false;
			}
			$imageId = intval($info->imageId);
		} else {
			$imageId = $this->_insertElement($domainId, $info);
			if($imageId === 0) {
				return false;
			}
		}

		if($isAll) {
			if(isset($info->actionElement)) {
				return $this->setAction($domainId, $imageId, $info->actionElement, $isAll);
			}
		}

		return true;
	}

	private function _insertElement($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Images>
</Images>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$newId = 0;
		if(!empty($obj->Image)) {
			foreach($obj->Image as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Image');
		$data->addAttribute('id', $newId);

		$data->addChild('SliderId', intval($info->sliderId));
		$data->addChild('Name',     $this->dbStr($info->name));
		$data->addChild('DispNo',   intval($info->dispNo));
		$data->addChild('ImageUrl', $this->dbStr($info->imageUrl));

		self::$_isWrite = true;

		return $newId;
	}

	private function _updateElement($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		foreach($obj->Image as $record) {
			if(intval($info->imageId) === intval($record['id'])) {
				$record->Name     = $this->dbStr($info->name);
				$record->DispNo   = intval($info->dispNo);
				$record->ImageUrl = $this->dbStr($info->imageUrl);
				self::$_isWrite = true;
				return true;
			}
		}

		return false;
	}

	/**
	 * 削除可能かチェックする
	 * 子階層が無いことが条件。
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @param $imageId [in] イメージアイテムID
	 * @return bool 可否
	 */
	function isCanDelete($domainId, $sliderId, $imageId) {

		require_once dirname(__FILE__).'/../player_data.php';
		$childElement = new PlayerData($this->userName);
		if($childElement->isUsePlayer($domainId, $imageId, 1)) {
			return false;
		}

		require_once dirname(__FILE__).'/../item_data.php';
		$childElement = new ItemData($this->userName);
		if($childElement->isUseItem($domainId, $imageId, 1)) {
			return false;
		}

		return true;
	}

	/**
	 * イメージアイテム削除
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @param $imageId [in] イメージアイテムID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $sliderId, $imageId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return true;
		}

		$dispNo = 0;
		foreach($obj->Image as $record) {
			if(intval($record['id']) === intval($imageId)
			&& intval($record->SliderId) === intval($sliderId)) {
				$dispNo = intval($record->DispNo);
				break;
			}
		}
		if($dispNo === 0) {
			return false;
		}

		$max = count($obj->Image)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Image[$cnt]->SliderId) === intval($sliderId)) {
				if(intval($obj->Image[$cnt]['id']) === intval($imageId)) {
					unset($obj->Image[$cnt]);
					self::$_isWrite = true;
				} else if($dispNo < intval($obj->Image[$cnt]->DispNo)) {
					$obj->Image[$cnt]->DispNo = intval($obj->Image[$cnt]->DispNo) - 1;
					self::$_isWrite = true;
				}
			}
		}

		return true;
	}

	/**
	 * アイテム表示位置変更
	 * @param $domainId [in] ドメインID
	 * @param $itemId [in] アイテムID
	 * @param $newDispNo [in] 新しい表示位置
	 * @return bool 成功/失敗
	 */
	function changeDispNo($domainId, $sliderId, $imageId, $newDispNo) {
		$newDispNo = intval($newDispNo);
		$oldDispNo = 0;

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		foreach($obj->Image as $record) {
			if(intval($imageId) === intval($record['id'])
			&& intval($sliderId) === intval($record->SliderId)) {
				$oldDispNo = intval($record->DispNo);
				break;
			}
		}

		if($oldDispNo === 0) {
			return false;
		}
		if($oldDispNo === $newDispNo) {
			return true;
		}

		reset($obj->Image);
		$start = min(array($newDispNo, $oldDispNo));
		$end   = max(array($newDispNo, $oldDispNo));
		$addVal = ($oldDispNo<$newDispNo?-1:+1);
		foreach($obj->Image as $record) {
			if($start <= intval($record->DispNo)
			&& intval($record->DispNo) <= $end
			&& intval($sliderId) === intval($record->SliderId)) {
				if(intval($record->DispNo) === $oldDispNo) {
					$record->DispNo = $newDispNo;
				} else {
					$record->DispNo = intval($record->DispNo) + $addVal;
				}
				self::$_isWrite = true;
			}
		}

		return true;
	}

	/////////

	/**
	 * slider_item_actionにデータを設定する
	 * @param $domainId [in] ドメインID
	 * @param $imageId [in] スライダー画像アイテムID
	 * @param $info [in] SliderActionElement
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function setAction($domainId, $imageId, $info, $isAll = false) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		$isSuccess = false;
		foreach($obj->Image as $record) {
			if(intval($imageId) === intval($record['id'])) {

				$record->Action->LinkUrl       = $this->dbStr($info->linkUrl);
				$record->Action->LinkUrlTarget = intval($info->linkUrlTarget);
				$record->Action->BgImage       = $this->dbStr($info->bgImage);
				self::$_isWrite = true;
				$isSuccess = true;
				break;
			}
		}

		if(!$isSuccess) {
			return false;
		}

		if($isAll) {
			if(isset($info->playerElement)) {
				require_once dirname(__FILE__).'/../player_data.php';
				$childElement = new PlayerData($this->userName);
				$info->playerElement->parentType = 1;
				$info->playerElement->itemId = $imageId;
				if(!$childElement->set($domainId, $info->playerElement, $isAll)) {
					return false;
				}
			}
			if(count($info->itemElementList) > 0) {
				require_once dirname(__FILE__).'/../item_data.php';
				$childElement = new ItemData($this->userName);
				foreach($info->itemElementList as $itemElement) {
					$itemElement->parentType = 1;
					$itemElement->parentItemId = $imageId;
					if(!$childElement->set($domainId, $itemElement, $isAll)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	/**
	 * slider_image_itemを取得する
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @param $imageId [in] スライダー画像アイテムID
	 * @return SliderImageItemElemet
	 */
	function &getAction($domainId, $sliderId, $imageId) {

		$info = new SliderActionElement();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return $info;
		}

		foreach($obj->Image as $record) {
			if(intval($imageId) === intval($record['id'])
			&& intval($sliderId) === intval($record->SliderId)) {

				if(empty($obj->Image->Action)) {
					break;
				}

				$info->linkUrl       = (string)$record->Action->LinkUrl;
				$info->linkUrlTarget = intval($record->Action->LinkUrlTarget);
				$info->bgImage       = (string)$record->Action->BgImage;

				break;
			}
		}

		return  $info;

	}

	////////////////////////////
	//以下非共通
	////////////////////////////
	/**
	 * スライダーが画像アイテムを利用しているかをチェックする
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @return bool 利用状況
	 */
	function isUse($domainId, $sliderId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Image)) {
			return false;
		}

		foreach($obj->Image as $record) {
			if(intval($sliderId) === intval($record->SliderId)) {
				return true;
			}
		}

		return false;
	}
}

?>
