<?php
require_once dirname(__FILE__).'/../../slider_xml.php';

class SliderXml extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function SliderXml($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/slider_xml.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * スライダー一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $isAll  [in] 子ノードも処理するかどうか
	 * @return array SliderXmlInfo配列
	 */
	function &getList($domainId, $isAll = false) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Slider)) {
			return $list;
		}

		foreach($obj->Slider as $record) {
			$info = new SliderXmlInfo();
			$info->sliderId       = intval($record['id']);
			$info->number         = intval($record->Number);
			$info->name           = (string)$record->Name;
			$info->directionType  = intval($record->DirectionType);
			$info->isMirrorEffect = (intval($record->IsMirrorEffect)===1);
			$info->isBlurEffect   = (intval($record->IsBlurEffect)===1);
			$info->bgColor        = (string)$record->BgColor;
			$info->bgAlpha        = intval($record->BgAlpha);
			$info->width          = intval($record->Width);
			$info->height         = intval($record->Height);
			$info->thumbWidth     = intval($record->ThumbWidth);
			$info->thumbHeight    = intval($record->ThumbHeight);
			$info->sortType       = intval($record->SortType);

			if($isAll) {
				require_once 'image_item.php';
				$childElement = new SliderImageItem($this->userName);
				$info->imageItemList = $childElement->getList($domainId, $info->sliderId, $isAll);
			}

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * slider_dataを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return FlagXmlInfo
	 */
	function &get($domainId, $sliderId, $isAll = false) {
		$info = new SliderXmlInfo();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Slider)) {
			return $info;
		}
		foreach($obj->Slider as $record) {
			if(intval($sliderId) === intval($record['id'])) {
				$info->sliderId       = intval($record['id']);
				$info->number         = intval($record->Number);
				$info->name           = (string)$record->Name;
				$info->directionType  = intval($record->DirectionType);
				$info->isMirrorEffect = (intval($record->IsMirrorEffect)===1);
				$info->isBlurEffect   = (intval($record->IsBlurEffect)===1);
				$info->bgColor        = (string)$record->BgColor;
				$info->bgAlpha        = intval($record->BgAlpha);
				$info->width          = intval($record->Width);
				$info->height         = intval($record->Height);
				$info->thumbWidth     = intval($record->ThumbWidth);
				$info->thumbHeight    = intval($record->ThumbHeight);
				$info->sortType       = intval($record->SortType);

				if($isAll) {
					require_once 'image_item.php';
					$childElement = new SliderImageItem($this->userName);
					$info->imageItemList = $childElement->getList($domainId, $info->sliderId, $isAll);
				}

				break;
			}
		}

		return $info;
	}

	/**
	 * slider_dataにデータを設定する
	 * すべて書き換える場合、先にdeleteする必要がある。
	 * @param $domainId [in] ドメインID
	 * @param $info [in] FlagXmlInfo
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if($info->sliderId > 0) {
			if(!$this->_update($domainId, $info)) {
				return false;
			}
			$sliderId = $info->sliderId;
		} else {
			$sliderId = $this->_insert($domainId, $info);
			if($sliderId === 0) {
				return false;
			}
		}

		if($isAll) {
			if(isset($info->imageItemList)) {
				require_once 'image_item.php';
				$childElement = new SliderImageItem($this->userName);
				foreach($info->imageItemList as $imageItem) {
					$imageItem->sliderId = $sliderId;
					if(!$childElement->set($domainId, $imageItem, $isAll)) {
						return false;
					}
				}
			}
		}

		return true;
	}

	private function _insert($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Sliders>
</Sliders>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$newId = 0;
		if(!empty($obj->Slider)) {
			foreach($obj->Slider as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Slider');
		$data->addAttribute('id', $newId);

		$data->addChild('Number',         intval($info->number));
		$data->addChild('Name',           $this->dbStr($info->name));
		$data->addChild('DirectionType',  intval($info->directionType));
		$data->addChild('IsMirrorEffect', ($info->isMirrorEffect?1:0));
		$data->addChild('IsBlurEffect',   ($info->isBlurEffect?1:0));
		$data->addChild('BgColor',        $this->dbStr($info->bgColor));
		$data->addChild('BgAlpha',        intval($info->bgAlpha));
		$data->addChild('Width',          intval($info->width));
		$data->addChild('Height',         intval($info->height));
		$data->addChild('ThumbWidth',     intval($info->thumbWidth));
		$data->addChild('ThumbHeight',    intval($info->thumbHeight));
		$data->addChild('SortType',       intval($info->sortType));
		self::$_isWrite = true;

		return $newId;
	}

	private function _update($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Slider)) {
			return false;
		}
		foreach($obj->Slider as $record) {
			if(intval($info->sliderId) === intval($record['id'])) {
				$record->Name =           $this->dbStr($info->name);
				$record->DirectionType =  intval($info->directionType);
				$record->IsMirrorEffect = ($info->isMirrorEffect?1:0);
				$record->IsBlurEffect =   ($info->isBlurEffect?1:0);
				$record->BgColor =        $this->dbStr($info->bgColor);
				$record->BgAlpha =        intval($info->bgAlpha);
				$record->Width =          intval($info->width);
				$record->Height =         intval($info->height);
				$record->ThumbWidth =     intval($info->thumbWidth);
				$record->ThumbHeight =    intval($info->thumbHeight);
				$record->SortType =       intval($info->sortType);

				self::$_isWrite = true;

				return true;
			}
		}

		return false;
	}


	/**
	 * 全削除
	 * @param $domainId [in] ドメインID
	 * @return bool 成功/失敗
	 */
	function deleteAll($domainId) {

		self::closeFileHandle(self::$_fileHandle);
		self::$_xmlObj = null;

		$fileList = array(
			 'slider_image.xml'
			,'slider_xml.xml'
		);

		$domainDataPath = Config::TEXT_DATA_PATH.sprintf('%03d/', $domainId);
		foreach($fileList as $fileName) {
			if(is_file($domainDataPath.$fileName)) {
				unlink($domainDataPath.$fileName);
			}
		}

		return true;
	}

	/**
	 * スライダー番号の最大値取得
	 * @param $domainId [in] ドメイン番号
	 * @return intval スライダー番号最大値
	 */
	function getMaxNumber($domainId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Slider)) {
			return 0;
		}

		$number = 0;
		foreach($obj->Slider as $record) {
			$number = max($number, intval($record->Number));
		}

		return $number;
	}

	/**
	 * 削除可能かチェックする
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @return bool 削除可否
	 */
	function isCanDelete($domainId, $sliderId) {
		require_once dirname(__FILE__).'/image_item.php';
		$childElement = new SliderImageItem($this->userName);

		return (!$childElement->isUse($domainId, $sliderId));

	}

	/**
	 * 削除
	 * @param $domainId [in] ドメインID
	 * @param $sliderId [in] スライダーID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $sliderId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Slider)) {
			return true;
		}

		$max = count($obj->Slider)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Slider[$cnt]['id']) === intval($sliderId)) {
				unset($obj->Slider[$cnt]);
				self::$_isWrite = true;
				return true;
			}
		}

		return true;
	}
}