<?php
require_once dirname(__FILE__).'/../../text_xml.php';

class TextXml extends DataAccessBase {

	private static $_fileHandle = null;
	private static $_xmlObj = null;
	private static $_referenceCnt = 0;
	private static $_domainId = 0;
	private static $_isWrite = false;

	function TextXml($userName) {
		self::$_referenceCnt++;
		parent::DataAccessBase($userName);
	}

	static function _getFilePath($domainId) {
		return Config::TEXT_DATA_PATH.sprintf('%03d/text_xml.xml', intval($domainId));
	}

	function __destruct() {
		self::$_referenceCnt--;
		if(self::$_referenceCnt <= 0 && self::$_fileHandle !== null) {
			if(self::$_isWrite) {
				parent::writeXmlObj(self::_getFilePath(self::$_domainId), self::$_fileHandle, self::$_xmlObj);
				self::$_isWrite = false;
			}
			flock(self::$_fileHandle, LOCK_UN);
			fclose(self::$_fileHandle);
			self::$_fileHandle = null;
			self::$_domainId = 0;
		}
	}

	private function &_getXmlObj($domainId) {
		if(self::$_domainId === intval($domainId) || self::$_domainId === 0) {
			self::$_domainId = intval($domainId);
			return parent::getXmlObj(self::_getFilePath($domainId), self::$_fileHandle, self::$_xmlObj);
		} else {
			return null;
		}
	}

	/**
	 * テキスト一覧取得
	 * @param $domainId [in] ドメインID
	 * @param $isAll  [in] 子ノードも処理するかどうか
	 * @return array TextXmlInfo配列
	 */
	function &getList($domainId, $isAll = false) {
		$list = array();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Text)) {
			return $list;
		}

		foreach($obj->Text as $record) {
			$info = new TextXmlInfo();
			$info->textId       = intval($record['id']);
			$info->number         = intval($record->Number);
			$info->name           = (string)$record->Name;

			$info->width          = intval($record->Width);
			$info->height         = intval($record->Height);
			$info->bgColor        = (string)$record->BgColor;
			$info->bgAlpha        = intval($record->BgAlpha);
			$info->fileType = intval($record->FileType);
			$info->fileUrl = (string)$record->FileUrl;
			$info->isWordWrap = (intval($record->IsWordWrap)===1);
			$info->fontType = intval($record->Font->Type);
			$info->textFontSize = intval($record->Font->Size);
			$info->textColor = (string)$record->Font->Color;
			$info->textIsDisplayShadow = (intval($record->Font->IsDisplayShadow)===1);
			$info->textShadowColor = (string)$record->Font->ShadowColor;
			$info->verticalSchlollIsDisplay = (intval($record->Scroll->Vertical->IsDisplay)===1);
			$info->verticalSchlollFaceColor = (string)$record->Scroll->Vertical->FaceColor;
			$info->verticalSchlollArrowColor = (string)$record->Scroll->Vertical->ArrowColor;
			$info->verticalSchlollTrackColor = (string)$record->Scroll->Vertical->TrackColor;
			$info->verticalSchlollInsideHighlightColor = (string)$record->Scroll->Vertical->Inside->HighlightColor;
			$info->verticalSchlollInsideShadowColor = (string)$record->Scroll->Vertical->Inside->ShadowColor;
			$info->verticalSchlollOutsideHighlightColor = (string)$record->Scroll->Vertical->Outside->HighlightColor;
			$info->verticalSchlollOutsideShadowColor = (string)$record->Scroll->Vertical->Outside->ShadowColor;
			$info->horizonSchlollIsDisplay = (intval($record->Scroll->Horizon->IsDisplay)===1);
			$info->horizonSchlollFaceColor = (string)$record->Scroll->Horizon->FaceColor;
			$info->horizonSchlollArrowColor = (string)$record->Scroll->Horizon->ArrowColor;
			$info->horizonSchlollTrackColor = (string)$record->Scroll->Horizon->TrackColor;
			$info->horizonSchlollInsideHighlightColor = (string)$record->Scroll->Horizon->Inside->HighlightColor;
			$info->horizonSchlollInsideShadowColor = (string)$record->Scroll->Horizon->Inside->ShadowColor;
			$info->horizonSchlollOutsideHighlightColor = (string)$record->Scroll->Horizon->Outside->HighlightColor;
			$info->horizonSchlollOutsideShadowColor = (string)$record->Scroll->Horizon->Outside->ShadowColor;
			$info->textData = (string)$record->TextData;

			$list[] = $info;
		}

		return $list;
	}

	/**
	 * text_dataを取得する
	 * @param $domainId [in] ドメインID
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return FlagXmlInfo
	 */
	function &get($domainId, $textId, $isAll = false) {
		$info = new TextXmlInfo();

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Text)) {
			return $info;
		}
		foreach($obj->Text as $record) {
			if(intval($textId) === intval($record['id'])) {
				$info->textId       = intval($record['id']);
				$info->number         = intval($record->Number);
				$info->name           = (string)$record->Name;

				$info->width          = intval($record->Width);
				$info->height         = intval($record->Height);
				$info->bgColor        = (string)$record->BgColor;
				$info->bgAlpha        = intval($record->BgAlpha);
				$info->fileType = intval($record->FileType);
				$info->fileUrl = (string)$record->FileUrl;
				$info->isWordWrap = (intval($record->IsWordWrap)===1);
				$info->fontType = intval($record->Font->Type);
				$info->textFontSize = intval($record->Font->Size);
				$info->textColor = (string)$record->Font->Color;
				$info->textIsDisplayShadow = (intval($record->Font->IsDisplayShadow)===1);
				$info->textShadowColor = (string)$record->Font->ShadowColor;
				$info->verticalSchlollIsDisplay = (intval($record->Scroll->Vertical->IsDisplay)===1);
				$info->verticalSchlollFaceColor = (string)$record->Scroll->Vertical->FaceColor;
				$info->verticalSchlollArrowColor = (string)$record->Scroll->Vertical->ArrowColor;
				$info->verticalSchlollTrackColor = (string)$record->Scroll->Vertical->TrackColor;
				$info->verticalSchlollInsideHighlightColor = (string)$record->Scroll->Vertical->Inside->HighlightColor;
				$info->verticalSchlollInsideShadowColor = (string)$record->Scroll->Vertical->Inside->ShadowColor;
				$info->verticalSchlollOutsideHighlightColor = (string)$record->Scroll->Vertical->Outside->HighlightColor;
				$info->verticalSchlollOutsideShadowColor = (string)$record->Scroll->Vertical->Outside->ShadowColor;
				$info->horizonSchlollIsDisplay = (intval($record->Scroll->Horizon->IsDisplay)===1);
				$info->horizonSchlollFaceColor = (string)$record->Scroll->Horizon->FaceColor;
				$info->horizonSchlollArrowColor = (string)$record->Scroll->Horizon->ArrowColor;
				$info->horizonSchlollTrackColor = (string)$record->Scroll->Horizon->TrackColor;
				$info->horizonSchlollInsideHighlightColor = (string)$record->Scroll->Horizon->Inside->HighlightColor;
				$info->horizonSchlollInsideShadowColor = (string)$record->Scroll->Horizon->Inside->ShadowColor;
				$info->horizonSchlollOutsideHighlightColor = (string)$record->Scroll->Horizon->Outside->HighlightColor;
				$info->horizonSchlollOutsideShadowColor = (string)$record->Scroll->Horizon->Outside->ShadowColor;
				$info->textData = (string)$record->TextData;

				break;
			}
		}

		return $info;
	}

	/**
	 * text_dataにデータを設定する
	 * すべて書き換える場合、先にdeleteする必要がある。
	 * @param $domainId [in] ドメインID
	 * @param $info [in] FlagXmlInfo
	 * @param $isAll [in] 子ノードも処理するかどうか
	 * @return bool 成功/失敗
	 */
	function set($domainId, $info, $isAll = false) {
		if($info->textId > 0) {
			if(!$this->_update($domainId, $info)) {
				return false;
			}
			$textId = $info->textId;
		} else {
			$textId = $this->_insert($domainId, $info);
			if($textId === 0) {
				return false;
			}
		}

		return true;
	}

	private function _insert($domainId, $info) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj)) {

			$outputStr = <<<_END_OF_STR_
<?xml version="1.0" encoding="UTF-8"?>
<Texts>
</Texts>
_END_OF_STR_;
			require_once dirname(__FILE__).'/../../../util/file.php';
			if(FileUtil::writeFileStr(self::_getFilePath($domainId), $outputStr) !== 0) {
				return false;
			}

			$obj =& $this->_getXmlObj($domainId);
			if(is_null($obj)) {
				return false;
			}
		}

		$newId = 0;
		if(!empty($obj->Text)) {
			foreach($obj->Text as $record) {
				 $newId = ($newId>intval($record['id'])?$newId:intval($record['id']));
			}
		}
		$newId++;

		$data = $obj->addChild('Text');
		$data->addAttribute('id', $newId);

		$data->addChild('Number',           intval($info->number));
		$data->addChild('Name',             $this->dbStr($info->name));
		$data->addChild('Width',            intval($info->width));
		$data->addChild('Height',           intval($info->height));
		$data->addChild('BgColor',          $this->dbStr($info->bgColor));
		$data->addChild('BgAlpha',          intval($info->bgAlpha));

		$data->addChild('FileType',         intval($info->fileType));
		$data->addChild('FileUrl',          $this->dbStr($info->fileUrl));
		$data->addChild('IsWordWrap',       ($info->isWordWrap?1:0));

		$fontData = $data->addChild('Font');
		$fontData->addChild('Type',             intval($info->fontType));
		$fontData->addChild('Size',             intval($info->textFontSize));
		$fontData->addChild('Color',            $this->dbStr($info->textColor));
		$fontData->addChild('IsDisplayShadow',  ($info->textIsDisplayShadow?1:0));
		$fontData->addChild('ShadowColor',      $this->dbStr($info->textShadowColor));

		$scrollData = $data->addChild('Scroll');
		$verticalData = $scrollData->addChild('Vertical');
		$verticalData->addChild('IsDisplay',    ($info->verticalSchlollIsDisplay?1:0));
		$verticalData->addChild('FaceColor',    $this->dbStr($info->verticalSchlollFaceColor));
		$verticalData->addChild('ArrowColor',   $this->dbStr($info->verticalSchlollArrowColor));
		$verticalData->addChild('TrackColor',   $this->dbStr($info->verticalSchlollTrackColor));
		$insideData = $verticalData->addChild('Inside');
		$insideData->addChild('HighlightColor', $this->dbStr($info->verticalSchlollInsideHighlightColor));
		$insideData->addChild('ShadowColor',    $this->dbStr($info->verticalSchlollInsideHighlightColor));
		$outsideData = $verticalData->addChild('Outside');
		$outsideData->addChild('HighlightColor',$this->dbStr($info->verticalSchlollOutsideHighlightColor));
		$outsideData->addChild('ShadowColor',   $this->dbStr($info->verticalSchlollOutsideHighlightColor));

		$horizonData = $scrollData->addChild('Horizon');
		$horizonData->addChild('IsDisplay',     ($info->horizonSchlollIsDisplay?1:0));
		$horizonData->addChild('FaceColor',     $this->dbStr($info->horizonSchlollFaceColor));
		$horizonData->addChild('ArrowColor',    $this->dbStr($info->horizonSchlollArrowColor));
		$horizonData->addChild('TrackColor',    $this->dbStr($info->horizonSchlollTrackColor));
		$insideData = $horizonData->addChild('Inside');
		$insideData->addChild('HighlightColor', $this->dbStr($info->horizonSchlollInsideHighlightColor));
		$insideData->addChild('ShadowColor',    $this->dbStr($info->horizonSchlollInsideHighlightColor));
		$outsideData = $horizonData->addChild('Outside');
		$outsideData->addChild('HighlightColor',$this->dbStr($info->horizonSchlollOutsideHighlightColor));
		$outsideData->addChild('ShadowColor',   $this->dbStr($info->horizonSchlollOutsideHighlightColor));

		$data->addChild('TextData',   $this->dbStr($info->textData));

		self::$_isWrite = true;

		return $newId;
	}

	private function _update($domainId, $info) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Text)) {
			return false;
		}
		foreach($obj->Text as $record) {
			if(intval($info->textId) === intval($record['id'])) {
				$record->Name =             $this->dbStr($info->name);
				$record->Width =            intval($info->width);
				$record->Height =           intval($info->height);
				$record->BgColor =          $this->dbStr($info->bgColor);
				$record->BgAlpha =          intval($info->bgAlpha);
				$record->FileType =         intval($info->fileType);
				$record->FileUrl =          $this->dbStr($info->fileUrl);
				$record->IsWordWrap =       ($info->isWordWrap?1:0);

				$record->Font->Type =            intval($info->fontType);
				$record->Font->Size =            intval($info->textFontSize);
				$record->Font->Color =           $this->dbStr($info->textColor);
				$record->Font->IsDisplayShadow = ($info->textIsDisplayShadow?1:0);
				$record->Font->ShadowColor =     $this->dbStr($info->textShadowColor);

				$record->Scroll->Vertical->IsDisplay =               ($info->verticalSchlollIsDisplay?1:0);
				$record->Scroll->Vertical->FaceColor =               $this->dbStr($info->verticalSchlollFaceColor);
				$record->Scroll->Vertical->ArrowColor =              $this->dbStr($info->verticalSchlollArrowColor);
				$record->Scroll->Vertical->TrackColor =              $this->dbStr($info->verticalSchlollTrackColor);
				$record->Scroll->Vertical->Inside->HighlightColor =  $this->dbStr($info->verticalSchlollInsideHighlightColor);
				$record->Scroll->Vertical->Inside->ShadowColor =     $this->dbStr($info->verticalSchlollInsideHighlightColor);
				$record->Scroll->Vertical->Outside->HighlightColor = $this->dbStr($info->verticalSchlollOutsideHighlightColor);
				$record->Scroll->Vertical->Outside->ShadowColor =    $this->dbStr($info->verticalSchlollOutsideHighlightColor);

				$record->Scroll->Horizon->IsDisplay =               ($info->horizonSchlollIsDisplay?1:0);
				$record->Scroll->Horizon->FaceColor =               $this->dbStr($info->horizonSchlollFaceColor);
				$record->Scroll->Horizon->ArrowColor =              $this->dbStr($info->horizonSchlollArrowColor);
				$record->Scroll->Horizon->TrackColor =              $this->dbStr($info->horizonSchlollTrackColor);
				$record->Scroll->Horizon->Inside->HighlightColor =  $this->dbStr($info->horizonSchlollInsideHighlightColor);
				$record->Scroll->Horizon->Inside->ShadowColor =     $this->dbStr($info->horizonSchlollInsideHighlightColor);
				$record->Scroll->Horizon->Outside->HighlightColor = $this->dbStr($info->horizonSchlollOutsideHighlightColor);
				$record->Scroll->Horizon->Outside->ShadowColor =    $this->dbStr($info->horizonSchlollOutsideHighlightColor);

				$record->TextData = $this->dbStr($info->textData);

				self::$_isWrite = true;

				return true;
			}
		}

		return false;
	}


	/**
	 * 全削除
	 * @param $domainId [in] ドメインID
	 * @return bool 成功/失敗
	 */
	function deleteAll($domainId) {
		self::closeFileHandle(self::$_fileHandle);
		self::$_xmlObj = null;

		$fileList = array(
			'text_xml.xml'
		);

		$domainDataPath = Config::TEXT_DATA_PATH.sprintf('%03d/', $domainId);
		foreach($fileList as $fileName) {
			if(is_file($domainDataPath.$fileName)) {
				unlink($domainDataPath.$fileName);
			}
		}

		return true;
	}

	/**
	 * テキスト番号の最大値取得
	 * @param $domainId [in] ドメイン番号
	 * @return intval テキスト番号最大値
	 */
	function getMaxNumber($domainId) {
		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Text)) {
			return 0;
		}

		$number = 0;
		foreach($obj->Text as $record) {
			$number = max($number, intval($record->Number));
		}

		return $number;
	}

	/**
	 * 削除
	 * @param $domainId [in] ドメインID
	 * @param $textId [in] テキストID
	 * @return bool 成功/失敗
	 */
	function delete($domainId, $textId) {

		$obj =& $this->_getXmlObj($domainId);
		if(is_null($obj) || empty($obj->Text)) {
			return true;
		}

		$max = count($obj->Text)-1;
		for($cnt = $max; $cnt >= 0; $cnt--) {
			if(intval($obj->Text[$cnt]['id']) === intval($textId)) {
				unset($obj->Text[$cnt]);
				self::$_isWrite = true;
				return true;
			}
		}

		return true;
	}
}