<?php
abstract class Element {
	/**
	 * xmlノードを作成する
	 * @param $dom [in] 作成するためのDOM
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return object ノードオブジェクト
	 */
	abstract function &getNode($dom, $isDemo);

	/**
	 * XMLオブジェクトからデータを取り込み
	 * @param $obj [in] XMLオブジェクト
	 * @return bool 成功/失敗
	 * @see simplexml
	 */
	abstract function setDataFromXmlObj($obj);

	/**
	 * オブジェクトに設定されているID関連情報のみ初期化する（コピー等で利用するため）
	 */
	abstract function resetId();

	/**
	 * 文字列取得
	 * @param $id [in] ID
	 * @return string 文字列
	 */
	static function getStrFromList($list, $key) {
		if(array_key_exists($key, $list)) {
			return $list[$key];
		} else {
			return '';
		}
	}

	/**
	 * 文字列に対応するID取得
	 * @param $keyStr [in] 文字列
	 * @return intval ID(不一致時は0)
	 */
	static function getIdFromList($list, $keyStr) {
		$list = array_flip($list);
		if(array_key_exists($keyStr, $list)) {
			return intval($list[$keyStr]);
		} else {
			return 0;
		}
	}

	/**
	 * boolに対応する文字取得
	 * @param $bool [in] bool値
	 * @return string 文字列
	 */
	static function getBoolStr($bool) {
		if($bool) {
			return 'yes';
		} else {
			return 'no';
		}
	}

	/**
	 * 文字に対応するbool値取得
	 * @param $str [in] yes/no
	 * @return bool yes:true/yes以外:false
	 */
	static function getBoolFromStr($str) {
		return ($str === 'yes');
	}

	/**
	 * 色文字列フォーマットチェック
	 * @param $value [in] 色文字列
	 * @return bool OK/NG
	 */
	static function checkColorFormat($value) {
		return (preg_match('/^[0-9A-Fa-f]{6}$/', $value) === 1);
	}

	/**
	 * @param $value [in] アルファ値文字列
	 * アルファ値フォーマットチェック
	 * @return bool OK/NG
	 */
	static function checkAlphaFormat($value) {
		if(is_numeric($value)) {
			if(intval($value) >= 0 && intval($value) <= 100) {
				return true;
			}
		}
		return false;
	}

	/**
	 * @param $value [in] パーセント値文字列
	 * パーセント値フォーマットチェック
	 * @return bool OK/NG
	 */
	static function checkPercentageFormat($value) {
		if(is_numeric($value)) {
			if(intval($value) >= 0 && intval($value) <= 100) {
				return true;
			}
		}
		return false;
	}

	/**
	 * デモサイト用の場合、時間パラメータ文字列を付けたURLに変換する
	 * @param $urlStr [in] URL
	 * @param $isDemo [in] デモサイト用かどうか
	 * @return 時間パラメータ付きURL
	 */
	static function addTimeStrToUrl($urlStr, $isDemo) {
		if($isDemo) {
			if(strpos($urlStr, '?') === FALSE) {
				return $urlStr.'?'.date('U');
			} else {
				return $urlStr.'&'.date('U');
			}
		} else {
			return $urlStr;
		}
	}
}
?>