<?
class FileUtil {
	/**
	 * ファイルに文字列を追加する
	 * @param string $filePath [in] 対象ファイル
	 * @param string $addStr [in] 追加する文字列
	 * @return intval 0:成功／1:ファイル指定エラー／2:ファイルオープン失敗／3:ロック失敗
	 */
	static function addStrToFile($filePath, $addStr) {
		$ret = 0;
		if(is_file($filePath)) {
			$fh = fopen($filePath, "a+");
			if($fh != FALSE){
				if(flock($fh, LOCK_EX)){
					fputs($fh, $addStr);
					flock($fh, LOCK_UN);
				} else {
					$ret = 3;
				}
				fclose($fh);
			} else {
				$ret = 2;
			}
		} else {
			$ret = 1;
		}
		return $ret;
	}

	/**
	 * ファイル読み込み
	 *
	 * @param string $filePath [in] 読込先ファイルパス
	 * @param string $fileStr [out] ファイルから読み込んだテキスト
	 * @return intval 0:成功／1:ロック解除失敗／2:ロック失敗／3:ファイルオープン失敗／4:ファイルでない
	 */
	static function readFileStr($filePath, &$fileStr) {
		if(!is_file($filePath)) {
			return 4;
		}

		$ret = 0;
		$fh=fopen($filePath,"r");
		if($fh != FALSE){
			if(flock($fh, LOCK_EX)){
				while (!feof($fh)) {
					$fileStr .= fgets($fh);
				}
				if(flock($fh, LOCK_UN) == FALSE){
					// ロック解除失敗
					$ret = 1;
				}
				fclose($fh);
			}else{
				//ロック失敗
				$ret = 2;
			}
		}else{
			//オープン失敗
			$ret = 3;
		}
		return $ret;
	}

	/**
	 * ファイル出力
	 *
	 * @param string $outFilePath [in] 出力先ファイルパス
	 * @param string $outputStr [in] 出力内容
	 * @return intval 0:成功／1:書き込み失敗／2:ロック解除失敗／3:ファイルロック失敗／4:ファイルオープン失敗
	 */
	static function writeFileStr($outFilePath, $outputStr) {
		$ret = 0;
		$fh = fopen($outFilePath, "wb");
		if($fh !== FALSE){
			if(flock($fh, LOCK_EX)){
				if(fwrite($fh, $outputStr) === FALSE){
					// ファイルの書き込みに失敗
					$ret = 1;
				}
				if(flock($fh, LOCK_UN) === FALSE){
					// ファイルロック解除失敗
					$ret = 2;
				}
				fclose($fh);
			}else{
				// ファイルロック失敗
				$ret = 3;
			}
		}else{
			// ファイルオープンに失敗
			$ret = 4;
		}
		return $ret;
	}

	/**
	 * 指定したファイル／パスまでのパスを生成する
	 *
	 * @param string $path [in] 操作開始パスに作っていくパス(ディレクトリの場合/で終わる)
	 * @return bool 成功／失敗
	 */
	static function createDir($path) {
		$nameList = explode('/', $path);
		$nameCnt = count($nameList);
		if(substr($path, strlen($path) - 1) === '/') {
			$lastIsFile = false;
		} else {
			$lastIsFile = true;
		}

		$outPath = $nameList[0];
		for($cnt = 0; $cnt < $nameCnt; $cnt++) {
			if($cnt === ($nameCnt - 1) && $lastIsFile) {
				break;
			}
			$outPath .= $nameList[$cnt].'/';
			if(!is_dir($outPath)) {
				if(!mkdir($outPath, 0755)) return false;
			}
		}
		return true;
	}
}
?>