<?php
class FormUtil {

	/**
	 * POSTから該当キーの内容を取得する。
	 * @param $key [in] POSTのキー
	 * @return unknown_type POSTの値
	 */
	private static function _getPostStr($key) {
		if(isset($_POST[$key])) {
			if(get_magic_quotes_gpc()) {
				$str = stripslashes($_POST[$key]);
			} else {
				$str = $_POST[$key];
			}
		} else {
			$str = null;
		}
		return $str;
	}

	/**
	 * テキストボックスタグの文字列を生成する。
	 * @param $name [in] Inputタグの名称
	 * @param $defaultValue [in] 初期表示内容
	 * @param $fieldSize [in] 横幅
	 * @param $maxLen [in] 入力可能文字数
	 * @param $class [in] スタイル(null:なし)
	 * @return string タグ文字列
	 */
	static function textbox($name, $defaultValue, $fieldSize, $maxLen, $class=null){

		$str = FormUtil::_getPostStr($name);
		if(is_null($str)) {
			$str = $defaultValue;
		}
		if($maxLen> 0){
			$optionStr = ' maxlength="'.intval($maxLen).'"';
		} else {
			$optionStr = '';
		}

		if(is_null($class)) {
			$classStr = '';
		} else {
			$classStr = 'class="'.$class.'" ';
		}

		$str = '<input type="text" name="'.$name.'" size="'.$fieldSize.'" value="'.htmlspecialchars($str).'"'.$optionStr.' '.$classStr.'onfocus="focusColor(this)" onblur="blurColor(this)" />';


		return $str;
	}

	/**
	 * テキストエリアタグの文字列を生成する。
	 * @param $name [in] testareaタグの名称
	 * @param $defaultVal [in] 初期表示内容
	 * @param $colSize [in] 横文字数
	 * @param $rowSize [in] 高さ文字数
	 * @param $class [in] スタイル(null:なし)
	 * @param $options [in] オプション
	 * @return string タグ文字列
	 */
	static function textArea($name, $defaultVal, $colSize, $rowSize, $class=null, $options=''){
		$str = FormUtil::_getPostStr($name);

		if(is_null($str)) {
			$str = $defaultVal;
		}

		if(is_null($class)) {
			$classStr = '';
		} else {
			$classStr = 'class="'.$class.'" ';
		}
		$str = '<textarea name="'.$name.'" cols="'.$colSize.'" rows="'.$rowSize.'" '.$classStr.$options.' onfocus="focusColor(this)" onblur="blurColor(this)">'.htmlspecialchars($str).'</textarea>';

		return $str;
	}

	/**
	 * ラジオボタンタグの文字列を生成する。
	 * @param $name [in] inputタグの名称
	 * @param $value [in] ラジオボタンの値
	 * @param $checkedValue [in] 選択されているラジオボタンの値
	 * @param $options [in] オプション文字列(null:なし)
	 * @return string タグ文字列
	 */
	static function radio($name, $value, $checkedValue, $options=null) {
		$valueStr = FormUtil::_getPostStr($name);

		if(($valueStr != '' && $valueStr == $value)
		|| $checkedValue == $value) {
			$checkedStr = ' checked="checked"';
		} else {
			$checkedStr = '';
		}

		if(!is_null($options)) {
			$options = ' '.$options;
		}

		$str = '<input type="radio" name="'.$name.'" value="'.htmlspecialchars($value).'"'.$checkedStr.$options.' />';

		return $str;
	}

	/**
	 * チェックボックスタグを生成する。
	 * @param $name [in] inputタグの名称
	 * @param $value [in] チェックボックスの値
	 * @param $isChecked [in] 初期選択状態
	 * @param $checkedValue [in] 選択されているチェックボックスの値
	 * @return string タグ文字列
	 */
	static function checkBox($name, $value, $isChecked, $checkedValue) {

		$valueStr = FormUtil::_getPostStr($name);
		if(is_null($valueStr)) {
			$valueStr = $checkedValue;
		}
		if(($valueStr != '' && $valueStr == $value)
		|| $isChecked){
			$checkedStr = ' checked="checked"';
		} else {
			$checkedStr = '';
		}

		$str = '<input type="checkbox" name="'.$name.'" value="'.htmlspecialchars($value).'"'.$checkedStr.' />';

		return $str;
	}

	/**
	 * オプションタグを生成する。
	 * @param $name [in] optionタグの名称
	 * @param $value $value [in] optionの値
	 * @param $defaultValue [in] 初期選択状態
	 * @param $textStr [in] オプションで表示する文字列
	 * @return string タグ文字列
	 */
	static function option($name, $value, $defaultValue, $textStr) {

		$str = FormUtil::_getPostStr($name);
		if(is_null($str)) {
			$str = $defaultValue;
		}
		if($str == $value){
			$checkedStr = ' selected="selected"';
		} else {
			$checkedStr = '';
		}

		$str = '<option value="'.htmlspecialchars($value).'"'.$checkedStr.'>'.htmlspecialchars($textStr).'</option>';

		return $str;
	}

	/**
	 * エラーリストから該当キーのエラー用タグを取得する
	 * @param $errorList [in] エラーリスト
	 * @param $key [in] エラーの検索キー
	 * @return string エラー文字列タグ
	 */
	static function getErrorStr($errorList, $key) {
		if(array_key_exists($key, $errorList)) {
			return '<p style="color: #FF0000;">'.htmlspecialchars($errorList[$key]).'</p>';
		} else {
			return '';
		}
	}

	/**
	 * 入力フォームに初期表示するパスに変換する
	 * @param $basePath [in] 変換用基本パス部分
	 * @param $path [in] 変換対象パス
	 * @return string 変換後文字列（変換不可の場合空文字）
	 */
	static function filePathToSettingFormPath($basePath, $path) {
		$pos = strpos($path, $basePath);
		if($pos === FALSE) {
			return '';
		} else {
			return substr($path, strlen($basePath));
		}
	}

	/**
	 * 入力フォームのファイルパスを保存できるパスに変換する。
	 * @param $basePath [in] 変換用基本パス部分
	 * @param $path [in] 入力されたパス
	 * @return string 変換後文字列（または空文字）
	 */
	static function formPathToFilePath($basePath, $path) {
		if(trim($path) === '') {
			return '';
		} else {
			return $basePath.$path;
		}
	}

	/**
	 * ページのnext/back表示
	 * @param $pageMax
	 * @param $pageNo
	 * @return unknown_type
	 */
	static function pageNextBack($pageMax, $pageNo) {
		$pageDispNum = 5;
		$pageLinkStr = '<input type="hidden" name="page" value="'.$pageNo.'" />'."\n";
		$pageDispNum--;
		$pageMax = intval($pageMax);
		$pageNo = intval($pageNo);
		if($pageNo === 0){
			$pageLinkStr .= '<span class="n_n">前のページ｜</span>';
		}else{
			$pageLinkStr .= '<span class="n_n"><a href="javascript:void(0);" onclick="document.getElementById(\'act\').page.value=\''.($pageNo - 1).'\';document.getElementById(\'act\').submit();return false;">前のページ</a>｜</span>';
		}
		$pageLinkStr .= "\n";
		for($i = 0; $i<= $pageMax; $i++){
			if(($pageMax - $pageDispNum) <= $pageNo){
				if($i >= ($pageMax - $pageDispNum) && $i <= $pageMax){
					if($pageNo ==$i){
						$pageLinkStr .= '<span class="n_b_red">'.($i+1).'</span><span class="n_n">｜</span>';
					}else{
						$pageLinkStr .= '<span class="n_n"><a href="javascript:void(0);" onclick="document.getElementById(\'act\').page.value=\''.$i.'\';document.getElementById(\'act\').submit();return false;">'.($i+1).'</a>｜</span>';
					}
					$pageLinkStr .= "\n";
				}
			}else{
				if($i >= $pageNo && $i <= ($pageNo + $pageDispNum)){
					if($pageNo ==$i){
						$pageLinkStr .= '<span class="n_b_red">'.($i+1).'</span><span class="n_n">｜</span>';
					}else{
						$pageLinkStr .= '<span class="n_n"><a href="javascript:void(0);" onclick="document.getElementById(\'act\').page.value=\''.$i.'\';document.getElementById(\'act\').submit();return false;">'.($i+1).'</a>｜</span>';
					}
					$pageLinkStr .= "\n";
				}
			}
		}
		if($pageNo == $pageMax){
			$pageLinkStr .= '<span class="n_n">次のページ</span>';
		}else{
			$pageLinkStr .= '<span class="n_n"><a href="javascript:void(0);" onclick="document.getElementById(\'act\').page.value=\''.($pageNo+1).'\';document.getElementById(\'act\').submit();return false;">次のページ</a></span>';
		}
		$pageLinkStr .= "\n";
		return $pageLinkStr;
	}

}
?>