<?php
class HtmlUtil {

	/**
	 * 文字が空の場合、'-'に置き換える。
	 * @param $str [in] 文字列
	 * @return string $str
	 */
	static function emptyStr($str) {
		if(is_null($str) || trim($str) === '') {
			return '-';
		} else {
			return htmlspecialchars($str);
		}
	}

	/**
	 * 日時文字が空の場合、'----/--/-- --:--:--'に置き換える。
	 * @param $datetimeStr [in] 日時文字列
	 * @return string 日時文字列
	 */
	static function emptyDatetimeStr($dateStr) {
		if(empty($dateStr)) {
			return '----/--/-- --:--:--';
		} else {
			return htmlspecialchars($dateStr);
		}
	}

	/**
	 * 共通Javascriptタグ
	 * @return string 文字列
	 */
	static function tagCommonJs() {
		$str  = '<script type="text/javascript" src="'.SYSTEM_URL.'apl/js/window.js"></script>'."\n";
		$str .= '<script type="text/javascript" src="'.SYSTEM_URL.'apl/js/popup_frame.js"></script>'."\n";
		return $str;
	}

	/**
	 * 共通ヘッダーメニュータグ
	 * @param $now [in] 現在表示中のメニュー
	 * @param $authLevel [in] 現在ログインしているユーザーの権限レベル
	 * @param $siteName [in] サイト名
	 * @return string 文字列
	 */
	static function tagHeader($now, $authLevel, $siteName, $editMode=null) {

		if(isset($editMode)) {
			if($editMode === 'detail'){
				$designPath = 'detail/base.php';
			} else {
				$designPath = 'mode1_base.php';
			}
		} else {
			$cookieKey = 'maverica_coreblo_flag_light_cms_edit_mode_'.intval($_SESSION['AccountID']);
			if(isset($_COOKIE[$cookieKey]) && $_COOKIE[$cookieKey] === 'detail'){
				$designPath = 'detail/base.php';
			} else {
				$designPath = 'mode1_base.php';
			}
		}

		$now = intval($now);
		$str = '';
		$str .= '<div id="header">'."\n";
		$str .= '	<div id="head_sub_area">'."\n";
		$str .= '		<div id="head_sub_navi_area">'."\n";
		$str .= '			<div class="head_sub_sitename"><p>'.htmlspecialchars(Language::SITE_NAME).':'.htmlspecialchars($siteName).'</p></div>'."\n";
		$str .= '			<div class="head_sub_navi">'."\n";
		$str .= '				<ul>'."\n";
		if(Config::IS_ARCIVE) {
			$str .= '					<li title="'.htmlspecialchars(Language::FILE_DOWNLOAD).'"><a href="'.SYSTEM_URL.'apl/download/index.php" class="head_sub_navi1'.($now===1?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::FILE_DOWNLOAD).'</span></a></li>'."\n";
		}
		$str .= '					<li title="'.htmlspecialchars(Language::ADMIN_SETTING).'"><a href="'.SYSTEM_URL.'apl/setting/index.php" class="head_sub_navi2'.($now===2?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::ADMIN_SETTING).'</span></a></li>'."\n";
		$str .= '					<li title="'.htmlspecialchars(Language::LOGOUT).'"><a href="'.SYSTEM_URL.'apl/system/logout.php" class="head_sub_navi3'.($now===3?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::LOGOUT).'</span></a></li>'."\n";
		$str .= '				</ul>'."\n";
		$str .= '			</div>'."\n";
		$str .= '		</div>'."\n";
		$str .= '		<div id="head_logo_area">'.DesignConfig::getTagAplLogo().'</div>'."\n";
		$str .= '	</div>'."\n";
		$str .= '	<div id="head_gl_area">'."\n";
		$str .= '		<div class="head_gl_navi">'."\n";
		$str .= '			<ul>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::MANAGEMENT_USE_IMAGE).'"><a href="'.SYSTEM_URL.'apl/upload/uploader.php" class="head_gl_navi1'.($now===4?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::MANAGEMENT_USE_IMAGE).'</span></a></li>'."\n";
		$str .= '				<li class="head_gl_yaji_no"><span class="dis_none">'.htmlspecialchars(Language::ALLOW).'</span></li>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::CREATE_FREE_DESIGN).'"><a href="'.SYSTEM_URL.'apl/design/'.$designPath.'" class="head_gl_navi2'.($now===5?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::CREATE_FREE_DESIGN).'</span></a></li>'."\n";
		$str .= '				<li class="head_gl_yaji_on"><span class="dis_none">'.htmlspecialchars(Language::ALLOW).'</span></li>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::MANAGEMENT_INFO).'"><a href="'.SYSTEM_URL.'apl/news/index.php" class="head_gl_navi3'.($now===6?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::MANAGEMENT_INFO).'</span></a></li>'."\n";
		$str .= '			</ul>'."\n";
		$str .= '		</div>'."\n";
		$str .= '		<div class="head_gl_sub_navi">'."\n";
		$str .= '			<ul>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::CREATE_FROM_TEMPLATE).'"><a href="'.SYSTEM_URL.'apl/template/index.php" class="head_gl_sub_navi1'.($now===7?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::CREATE_FROM_TEMPLATE).'</span></a></li>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::PREVIEW_DEMOSITE).'"><a href="'.SYSTEM_URL.'apl/preview/index.php" class="head_gl_sub_navi2'.($now===8?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::PREVIEW_DEMOSITE).'</span></a></li>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::OPEN_SETTING).'"><a href="'.SYSTEM_URL.'apl/outpath/index.php" class="head_gl_sub_navi3'.($now===9?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::OPEN_SETTING).'</span></a></li>'."\n";
		$str .= '			</ul>'."\n";
		$str .= '		</div>'."\n";
		$str .= '	</div>'."\n";
		$str .= '</div>'."\n";

		return $str;
	}

	/**
	 * アイテムツリー文字列取得
	 * @param $itemOutlineInfo [in] アイテム概要一覧
	 * @param $selectItemId [in] 選択中アイテムID
	 * @return string タグ文字列
	 */
	static function &tagItemTree($itemOutlineInfo, $selectItemId, $isTop = true, $isSelect = false, $selectParentId = 0) {
		$str = '';
		$listCnt = count($itemOutlineInfo);
		$cnt = 1;
		foreach($itemOutlineInfo as $itemInfoList) {
			$itemId = $itemInfoList['itemId'];

			if(count($itemInfoList['child']) > 0) {
				$subStr= '<div id="Branch'.$_SESSION['AccountID'].'-'.$itemId.'">'.HtmlUtil::tagItemTree($itemInfoList['child'], $selectItemId, false, $isSelect, $selectParentId).'</div>';
				$openCloseStr = '<a href="javascript:void(0);" id="BranchCtrl'.$_SESSION['AccountID'].'-'.$itemId.'" class="opcl_ico" onclick="onToggle(\'Branch'.$_SESSION['AccountID'].'-'.$itemId.'\', this, \''.SYSTEM_URL.'\');"><img src="'.SYSTEM_URL.'apl/image/common/bt/sp_bt.gif" alt="OpenClose" /></a>';
			} else {
				$subStr='';
				$openCloseStr = '<span class="opcl_ico"><img src="'.SYSTEM_URL.'apl/image/common/bt/sp_bt.gif" alt="OpenClose" /></span>';
			}
			if($isSelect) {
				if($itemInfoList['isUseButton']) {
					$optionStr = ' onclick="getTargetItemList(\'0_'.$itemId.'\', \''.htmlspecialchars(Language::NOT_TARGET_ITEMS).'\');"';
				} else {
					$optionStr = ' disabled="disabled"';
				}
				$openCloseStr .= FormUtil::radio('SelectParentId', $itemId, $selectParentId, $optionStr);
			}

			if($listCnt<=$cnt) {
				$class = 'tree_mse';
			} else {
				$class = 'tree_mst';
			}
			if(!$isTop) {
				$class .= '2';
			}
			$str .= '<div class="'.$class.'"><div class="tree_msy"><p class="tree_txt">'.$openCloseStr.'<span class="tree_nb">'.$itemInfoList['dispNo']."</span>\n";
			$nameStr = '';
			if($itemInfoList['name'] === '') {
				$nameStr .= 'no name';
			} else {
				$nameStr .= $itemInfoList['name'];
			}
			if($selectItemId === $itemId) {
				$str .= htmlspecialchars($nameStr)."\n";
			} else {
				$str .= '<a href="link.php?id='.$itemId.'">'.htmlspecialchars($nameStr).'</a>'."\n";
			}
			$str .= '</p></div>';

			if($subStr !== '') {
				$str .= $subStr;
			}

			$str .= '</div>'."\n";
			$cnt++;
		}

		if($isTop) {
			$str .= '<script type="text/javascript">'."\n";
			$str .= '<!--'."\n";
			$str .= 'loadToggle(\'Branch'.$_SESSION['AccountID'].'-\', \'BranchCtrl'.$_SESSION['AccountID'].'-\', \''.SYSTEM_URL.'\');'."\n";
			$str .= '-->'."\n";
			$str .= '</script>'."\n";
		}
		return $str;
	}

	/**
	 * アイテム用メニュー
	 * @param $isUseButton [in] ボタン使用状況
	 * @param $nowType [in] 選択中メニュー番号
	 * @return tring タグ文字列
	 */
		static function &tagItemMenu($isUseButton, $nowType) {
		$str = '<div class="tab_menu"><ul>';
		$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'link.php\');return false;"'.($nowType === 1?' class="crt"':'').'>'.htmlspecialchars(Language::ITEM_CONFIG).'</a></li>';
		if($isUseButton) {
			$buttonName = Language::BUTTON_ACTION_SETTING;
		} else {
			$buttonName =  Language::BUTTON_ACTION_REGIST;
		}

		$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_button.php\');return false;"'.($nowType === 2?' class="crt"':'').'>'.htmlspecialchars($buttonName).'</a></li>';

		$str .= '</ul></div>';

		return $str;

	}

	/**
	 * アイテム設定用メニュー
	 * @param $fileType [in] ファイル種別
	 * @param $isUseWipe [in] 表示効果設定しよう状況
	 * @param $nowType [in] 選択中メニュー番号
	 * @return string タグ文字列
	 */
	static function &tagItemSettingMenu($fileType, $isUseWipe, $nowType) {
		$str = '<div class="tab_menu2"><ul>';
		$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'link.php\');return false;"'.($nowType === 1?' class="crt"':'').'>'.htmlspecialchars(Language::BASE_SETTING).'</a></li>';
		if($fileType === 1) {
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_file.php\');return false;"'.($nowType === 2?' class="crt"':'').'>'.htmlspecialchars(Language::CONTENTS).'</a></li>';
		} else if($fileType === 2) {
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_playlist.php\');return false;"'.($nowType === 2?' class="crt"':'').'>'.htmlspecialchars(Language::ITEM_DISPLAY_TYPE_PLAY_LIST).'</a></li>';
		}
		$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_wipe.php\');return false;"'.($nowType === 3?' class="crt"':'').'>';
		if($isUseWipe) {
			$str .= htmlspecialchars(Language::WIPE_EFFECT_CHANGE);
		} else {
			$str .= htmlspecialchars(Language::WIPE_EFFECT_REGIST);
		}
		$str .= '</a></li>';
		$str .= '</ul></div>';

		return $str;
	}

	/**
	 * アイテムボタン用メニュー
	 * @param $isUseButton [in] ボタン使用状況
	 * @param $isUsePlayer [in] プレイヤー使用状況
	 * @param $nowType [in] 選択中メニュー番号
	 * @return string タグ文字列
	 */
	static function &tagItemButtonMenu($isUseButton, $isUsePlayer, $nowType) {
		$str = '<div class="tab_menu2"><ul>';
		$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_button.php\');return false;"'.($nowType === 1?' class="crt"':'').'>'.htmlspecialchars(Language::BASE_SETTING).'</a></li>';

		if($isUseButton) {
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_bg.php\');return false;"'.($nowType === 2?' class="crt"':'').'>'.htmlspecialchars(Language::CHANGE_BACKGROUND).'</a></li>';
			if($isUsePlayer) {
				$buttonName = Language::PLAYER_CHANGE;
			} else {
				$buttonName = Language::PLAYRE_REGIST;
			}
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player.php\');return false;"'.($nowType === 3?' class="crt"':'').'>'.htmlspecialchars($buttonName).'</a></li>';
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_link.php\');return false;"'.($nowType === 4?' class="crt"':'').'>'.htmlspecialchars(Language::OUTSIDE_LINK).'</a></li>';
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_change.php\');return false;"'.($nowType === 5?' class="crt"':'').'>'.htmlspecialchars(Language::CHANGE_ITEM).'</a></li>';
		}
		$str .= '</ul></div>';

		return $str;
	}

	/**
	 * アイテムプレイヤー用メニュー
	 * @param $playerType [in] プレイヤー種別
	 * @param $nowType [in] 選択中メニュー番号
	 * @param $fileType [in] 再生ファイル種別
	 * @return string タグ文字列
	 */
	static function tagItemPlayerMenu($playerType, $nowType, $fileType) {
		$str = '<div class="tab_menu3"><ul>';
		$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player.php\');return false;"'.($nowType === 1?' class="crt"':'').'>'.htmlspecialchars(Language::PLAYER_SETTING).'</a></li>';
		if($playerType === 1) {
			if($fileType === 1) {
				$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player_file.php\');return false;"'.($nowType === 2?' class="crt"':'').'>'.htmlspecialchars(Language::CONTENTS).'</a></li>';
			} else if($fileType === 2) {
				$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player_playlist.php\');return false;"'.($nowType === 2?' class="crt"':'').'>'.htmlspecialchars(Language::FLV_PLAYER_TYPE_PLAY_LIST).'</a></li>';
			}
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player_menu.php\');return false;"'.($nowType === 3?' class="crt"':'').'>'.htmlspecialchars(Language::MENU_SKIN).'</a></li>';
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player_equalizer.php\');return false;"'.($nowType === 4?' class="crt"':'').'>'.htmlspecialchars(Language::EQUALIZER).'</a></li>';
		} else if($playerType === 2) {
			$str .= '<li><a href="javascript:void(0);" onclick="onClickSubmit(\'act\', \'item_player_outside.php\');return false;"'.($nowType === 5?' class="crt"':'').'>'.htmlspecialchars(Language::CONTENTS).'</a></li>';
		}
		$str .= '</ul></div>';

		return $str;
	}

	/**
	 * 詳細設定用サイドメニュータグ
	 * @param $nowType [in] 選択中メニュー番号
	 * @param $isOnlyCommonSetting [in] 共通項目以外が存在するかどうか
	 * @return string タグ文字列
	 */
	static function tagDetailSideMenu($nowType, $isOnlyCommonSetting = false) {
		$str  = '		<div class="contents_inner_side_navi">'."\n";
		$str .= '			<ul>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::ALL_COMMON_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/detail/base.php" class="mode2_side_base'.($nowType===1?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::ALL_COMMON_SETTING).'</span></a></li>'."\n";
		if(!$isOnlyCommonSetting) {
			$str .= '				<li title="'.htmlspecialchars(Language::PLAYER_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/detail/player.php" class="mode2_side_player'.($nowType===2?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::PLAYER_SETTING).'</span></a></li>'."\n";
			$str .= '				<li title="'.htmlspecialchars(Language::NEWS_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/detail/news.php" class="mode2_side_info'.($nowType===3?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::NEWS_SETTING).'</span></a></li>'."\n";
			$str .= '				<li title="'.htmlspecialchars(Language::LINK_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/detail/link.php" class="mode2_side_link'.($nowType===4?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::LINK_SETTING).'</span></a></li>'."\n";
		}
		require_once dirname(__FILE__).'/../data/parts.php';
		if(PartsInfo::isActive('slider')) {
			$str .= '				<li title="'.htmlspecialchars(Language::SLIDER_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/slider/list.php" class="mode2_side_srd'.($nowType===5?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::SLIDER_SETTING).'</span></a></li>'."\n";
		}
		if(PartsInfo::isActive('photo')) {
			$str .= '				<li title="'.htmlspecialchars(Language::PHOTO_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/photo/list.php" class="mode2_side_photo'.($nowType===6?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::PHOTO_SETTING).'</span></a></li>'."\n";
		}
		if(PartsInfo::isActive('text')) {
			$str .= '				<li title="'.htmlspecialchars(Language::TEXT_PARTS_SETTING).'"><a href="'.SYSTEM_APL_URL.'design/text/list.php" class="mode2_side_txt'.($nowType===7?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::TEXT_PARTS_SETTING).'</span></a></li>'."\n";
		}
		$str .= '			</ul>'."\n";
		$str .= '		</div>'."\n";
		return $str;
	}

	/**
	 * インストール・ログイン設定用共通CSS定義タグ
	 * @return string タグ文字列
	 */
	static function tagIntCommonCss() {
		return '<link rel="stylesheet" href="'.SYSTEM_URL.'apl/css/detail/int_common.css" type="text/css" />';
	}
	/**
	 * インストール・ログイン設定用共通下蓋枠定義タグ
	 * @return string タグ文字列
	 */
	static function tagIntContentsFooter() {
		return '<img src="'.SYSTEM_URL.'apl/image/common/bg/int_main_bgb.gif" alt="'.htmlspecialchars(Language::FOOTER).'" />';
	}
	/**
	 * インストール・ログイン設定用共通グローバルナビ枠定義タグ
	 * @return string タグ文字列
	 */
	static function tagIntGlNavi($isAdminSession = true) {
		$systemUrl = SYSTEM_URL.'apl/';

		$str  = '<div id="gl_navi">'."\n";
		$str .= '<ul>'."\n";
		if($isAdminSession) {
			$str .= '<li><a href="'.$systemUrl.'domain/index.php" class="head_sub_navi1"><span>'.htmlspecialchars(Language::DOMAIN_MANAGER).'</span></a></li>'."\n";
		}
		$str .= '<li><a href="'.$systemUrl.'account/index.php" class="head_sub_navi2"><span>'.htmlspecialchars(Language::ACCOUNT_MANAGER).'</span></a></li>'."\n";
		$str .= '<li><a href="'.$systemUrl.'system/logout.php" class="head_sub_navi3"><span>'.htmlspecialchars(Language::LOGOUT).'</span></a></li>'."\n";
		$str .= '</ul>'."\n";
		$str .= '</div>'."\n";

		return $str;

	}
	/**
	 * 詳細モード全体共通設定タイトル箇所定義タグ
	 * @return string タグ文字列
	 */
	static function mode2Base() {
		$systemUrl = SYSTEM_URL.'apl/';

		$str  = '<h4 class="h4_mode2_ti01" title="'.htmlspecialchars(Language::ALL_COMMON_SETTING).'"><span class="dis_none">'.htmlspecialchars(Language::ALL_COMMON_SETTING).'</span></h4>'."\n";
		$str .= '<p class="help_guide"><a href="javascript:void(0);" onclick="onPopupFrame(\'popup_window\', \'popup_bg\', \'frame_area\', \''.htmlspecialchars(UrlListBase::BASE_SETTING).'\');" class="help_guide_ic">'.htmlspecialchars(Language::WHAT_S_COMMON_SETTING).'</a></p>'."\n";

		$str .= HtmlUtil::tagPopupArea();

		return $str;

	}
	/**
	 * 詳細モードプレイヤー設定タイトル箇所定義タグ
	 * @return string タグ文字列
	 */
	static function mode2Player() {
		$systemUrl = SYSTEM_URL.'apl/';

		$str  = '<h4 class="h4_mode2_ti02" title="'.htmlspecialchars(Language::PLAYER_SETTING).'"><span class="dis_none">'.htmlspecialchars(Language::PLAYER_SETTING).'</span></h4>'."\n";
		$str .= '<p class="help_guide"><a href="javascript:void(0);" onclick="onPopupFrame(\'popup_window\', \'popup_bg\', \'frame_area\', \''.htmlspecialchars(UrlListBase::PLAYER_SETTING).'\');" class="help_guide_ic">'.htmlspecialchars(Language::WHAT_S_PLAYER_SETTING).'</a></p>'."\n";

		$str .= HtmlUtil::tagPopupArea();

		return $str;

	}
	/**
	 * 詳細モードお知らせ設定タイトル箇所定義タグ
	 * @return string タグ文字列
	 */
	static function mode2News() {
		$systemUrl = SYSTEM_URL.'apl/';

		$str  = '<h4 class="h4_mode2_ti03" title="'.htmlspecialchars(Language::NEWS_AREA_SETTING).'"><span class="dis_none">'.htmlspecialchars(Language::NEWS_AREA_SETTING).'</span></h4>'."\n";
		$str .= '<p class="help_guide"><a href="javascript:void(0);" onclick="onPopupFrame(\'popup_window\', \'popup_bg\', \'frame_area\', \''.htmlspecialchars(UrlListBase::NEWS_SETTING).'\');" class="help_guide_ic">'.htmlspecialchars(Language::WHAT_S_NEWS_AREA_SETTING).'</a></p>'."\n";

		$str .= HtmlUtil::tagPopupArea();

		return $str;

	}
	/**
	 * 詳細モードリンク設定タイトル箇所定義タグ
	 * @return string タグ文字列
	 */
	static function mode2Link() {
		$systemUrl = SYSTEM_URL.'apl/';

		$str  = '<h4 class="h4_mode2_ti04" title="'.htmlspecialchars(Language::LINK_ITEM_SETTING).'"><span class="dis_none">'.htmlspecialchars(Language::LINK_ITEM_SETTING).'</span></h4>'."\n";
		$str .= '<p class="help_guide"><a href="javascript:void(0);" onclick="onPopupFrame(\'popup_window\', \'popup_bg\', \'frame_area\', \''.htmlspecialchars(UrlListBase::LINK_SETTING).'\');" class="help_guide_ic">'.htmlspecialchars(Language::WHAT_S_LINK_ITEM_SETTING).'</a></p>'."\n";

		$str .= HtmlUtil::tagPopupArea();

		return $str;

	}

	/**
	 * ポップアップエリア用タグ
	 * @return string タグ文字列
	 */
	static function tagPopupArea() {
		$closeTmp = htmlspecialchars(Language::WINDOW_CLOSE);

		$str  = <<<_END_OF_STR_
<div id="popup_bg" style="visibility:hidden;"></div>
<div id="popup_window" style="visibility:hidden; display: none;">
	<p class="window_close"><a href="javascript:void(0);"  onclick="closePopupFrame('popup_window');">$closeTmp</a></p>
	<script type="text/javascript"><!--
document.write("<iframe id=\"frame_area\" src=\"javascript:void(0);\">DispArea<\/iframe>");
--></script>
</div>
_END_OF_STR_;

		return $str;
	}

	/**
	 * 管理者設定用サイドメニュータグ
	 * @param $nowType [in] 選択中メニュー番号
	 * @param $isOnlyCommonSetting [in] 共通項目以外が存在するかどうか
	 * @return string タグ文字列
	 */
	static function tagSettingSideMenu($nowType) {
		$str  = '		<div class="contents_inner_side_navi">'."\n";
		$str .= '			<ul>'."\n";
		$str .= '				<li title="'.htmlspecialchars(Language::FLASH_AREA_SETTING_SETTING).'"><a href="'.SYSTEM_APL_URL.'setting/index.php" class="setting_side_stg'.($nowType===1?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::FLASH_AREA_SETTING_SETTING).'</span></a></li>';
		$str .= '				<li title="'.htmlspecialchars(Language::BODY_TAG_SETTING).'"><a href="'.SYSTEM_APL_URL.'setting/body.php" class="setting_side_body'.($nowType===2?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::BODY_TAG_SETTING).'</span></a></li>';
		$str .= '				<li title="'.htmlspecialchars(Language::ENVIRONMENT_SETTING).'"><a href="'.SYSTEM_APL_URL.'setting/frametag.php" class="setting_side_set'.($nowType===3?'a':'').'"><span class="dis_none">'.htmlspecialchars(Language::ENVIRONMENT_SETTING).'</span></a></li>';
		$str .= '			</ul>'."\n";
		$str .= '		</div>'."\n";
		return $str;
	}

}
?>