<?php
class Utils {

	const RANDOM_STRING_BASE = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';

	/**
	 * ランダム文字列を生成する
	 * @param $length [in] 文字数
	 * @return string ランダム文字列
	 */
	static function &randomStr($length) {
		$ret = '';
		$strPosMax = strlen(Utils::RANDOM_STRING_BASE) - 1;
		for($cnt = 0; $cnt < intval($length); $cnt++) {
			$ret .= substr(Utils::RANDOM_STRING_BASE, rand(0, $strPosMax), 1);
		}

		return $ret;
	}

	/**
	 * YouTubeの埋め込み用タグからURLを抽出する
	 * @param $tagStr [in] 埋め込み用タグ
	 * @return mixed 成功：URL文字列/失敗：false
	 */
	static function gerUrlFromImplantTags($tagStr) {
		$xmlObj = simplexml_load_string('<?xml version="1.0" encoding="UTF-8"?>'.str_replace('&', '&amp;', $tagStr));
		if($xmlObj === FALSE) {
			return false;
		}

		if(isset($xmlObj->embed) && isset($xmlObj->embed['src'])) {
			return $xmlObj->embed['src'];
		} else {
			return false;
		}
	}

	/**
	 * nullが設定されることがあるbool変数を数値に変換する
	 * @param $bool [in] nullが設定されることがあるbool
	 * @return intval 1:true/0:false/-1:null
	 */
	static function nullBoolToValue($bool) {
		if(is_null($bool)) {
			return -1;
		} else if($bool) {
			return 1;
		} else {
			return 0;
		}
	}

	/**
	 * 数値をboolまたはnullに変換する
	 * @param $value [in] 1:true/0:false/-1:null
	 * @return mixed $valueの対応値
	 */
	static function valueToNullBool($value) {
		$value = intval($value);
		if($value === 1) {
			return true;
		} else if($value === -1) {
			return null;
		} else {
			return false;
		}
	}

	/**
	 * パス文字列の最後にスラッシュがなければつける
	 * @param $path [in] パス
	 * @return string スラッシュ付きパス
	 */
	static function pathSlash($path) {
		if(substr($path, strlen($path) - 1) !== '/') {
			$path .= '/';
		}
		return $path;
	}


	 /**
	 * ファイルの先頭行取得(エラー時は空文字)
	 * @param $file [in] ファイル名
	 * @return string 文字列
	 */
	static function getTopLine($file) {
		if(is_file($file)) {
			$fh=fopen($file,'r');
			if($fh != FALSE){
				if(flock($fh, LOCK_EX)){
					while (!feof($fh)) {
						return fgets($fh);
					}
					fclose($fh);
				}
			}
		}
		return '';
	}

}

?>