/* iframeをポップアップとして表示します。
 * 表示場所がhtml上にタグとして用意してある必要があります。
 *
 * 例：
 * <div id="tag_bg" style="visibility:hidden;"></div>
 * <div id="tag_window" style="visibility:hidden;">
 *	<p><a href="javascript:void(0);"  onclick="closePopupFrame('tag_window');">閉じる</a></p>
 *	<div id="frame_target"></div>
 * </div>
 *
 * tag_window:ポップアップとして表示するdivタグ
 * tag_bg:BGとして利用するdivタグ
 */

/**
 * iframeをポップアップで開く
 * @param popupId ポップアップとして表示するdivタグのid
 * @param bgId 背景として利用するdivタグのid
 * @param urlId iframeを挿入するdivタグのid
 * @param url iframeに表示するURL
 */
function onPopupFrame(popupId, bgId, urlId, url) {
	window.onscroll=function() {
		_redrawFrame(popupId);
	};
	window.onresize=function() {
		_redrawFrame(popupId);
	};

	var pObj = document.getElementById(popupId);
	pObj.style.zIndex = 100;
	pObj.style.position="absolute";
	pObj.style.filter = "alpha(opacity=0)";
	pObj.style.opacity = 0;
	pObj.style.visibility="visible";
	pObj.style.display="";
	pObj.bgId = bgId;
	pObj.urlId = urlId;

	var bgObj = document.getElementById(pObj.bgId);
	bgObj.style.zIndex = 50;
	bgObj.style.position="absolute";
	bgObj.style.filter = "alpha(opacity=0)";
	bgObj.style.opacity = 0;
	bgObj.style.visibility="visible";
	bgObj.style.display="";

	var txtObj = document.getElementById(urlId);
	txtObj.style.visibility="visible";
	txtObj.style.display="";
	txtObj.src = url;

	_setFramePos(popupId);

	_fadeIn(pObj.bgId, 70, 0);
	_fadeIn(popupId, 100, 0);
}
/**
 * ポップアップを閉じる処理
 * @param id ポップアップid
 */
function closePopupFrame(popupId) {
	window.onscroll=null;
	window.onresize=null;
	var obj = document.getElementById(popupId);
	var txtObj = document.getElementById(obj.urlId);
	txtObj.src = '';
	_fadeOut(popupId, 0, 100, 100);
	_fadeOut(obj.bgId, 0, 70, 70);
}
function _redrawFrame(id) {
	var obj = document.getElementById(id);
	_setFramePos(id);
	_fadeIn(obj.bgId, 70, 70);
	_fadeIn(id, 100, 100);
}
function _setFramePos(id) {
	var pObj = document.getElementById(id);

	var width = 0;
	var height = 0;
	var scroll = 0;
	if(document.documentElement.clientWidth) {
		width = document.documentElement.clientWidth;
		height = document.documentElement.clientHeight;
	} else if(document.body.clientWidth){
		width = document.body.clientWidth;
		height = document.body.clientHeight;
	} else {
		width = window.innerWidth;
		height = window.innerHeight;
	}
	scroll = (document.body.scrollTop || document.documentElement.scrollTop);

	var maxHeight = height;
	if (typeof document.documentElement.style.msInterpolationMode != "undefined") {
		//IE7
		if(document.documentElement.clientHeight && document.documentElement.clientHeight > maxHeight) {
			maxHeight = document.documentElement.clientHeight;
		}
		if(document.body.clientHeight && document.body.clientHeight > maxHeight) {
			maxHeight = document.body.clientHeight;
		}
		if(window.innerWidth && window.innerWidth > maxHeight) {
			maxHeight = window.innerWidth;
		}
		maxHeight -= scroll;
	}

	var bgObj = document.getElementById(pObj.bgId);
	bgObj.style.width=width+'px';
	bgObj.style.height=maxHeight+'px';
	bgObj.style.left = '0px';
	bgObj.style.top = scroll+'px';

	if(pObj.offsetWidth > width) {
		pObj.style.left = '0px';
	} else {
		pObj.style.left = ((width-pObj.offsetWidth)/2)+'px';
	}
	if(pObj.offsetHeight > height) {
		pObj.style.top = '0px';
	} else {
		pObj.style.top = scroll+((height-pObj.offsetHeight)/2)+'px';
	}
}
function _fadeIn(id, max, now) {
	var obj = document.getElementById(id);
	obj.style.visibility="visible";
	if(max > now) {
		var next = now + (max / 5);
		obj.style.filter = "alpha(opacity=" + next + ")";
		obj.style.opacity = next/100;
		setTimeout("_fadeIn('"+id+"',"+max+","+next+")", 100);
	} else {
		obj.style.filter = "alpha(opacity=" + max + ")";
		obj.style.opacity = max/100;
	}
}
function _fadeOut(id, min, start, now) {
	var obj = document.getElementById(id);
	if(min < now) {
		var next = now - ((start-min) / 5);
		obj.style.filter = "alpha(opacity=" + next + ")";
		obj.style.opacity = next/100;
		setTimeout("_fadeOut('"+id+"',"+min+","+start+","+next+")", 100);
	} else {
		obj.style.filter = "alpha(opacity=" + min + ")";
		obj.style.opacity = min/100;
		if(min <= 0) {
			obj.style.visibility="hidden";
			obj.style.display="none";
		}
	}
}